# Sistema de Certificados para Bomberos - DNBC

Sistema completo de gestión y emisión de certificados digitales para la Dirección Nacional de Bomberos Colombia.

## 🚀 Características

- **Autenticación completa** con JWT
- **Gestión de usuarios** por roles jerárquicos
- **Registro de participantes** individual y masivo
- **Creación y gestión de cursos**
- **Sistema de matrículas**
- **Módulo de calificaciones**
- **Generación de certificados PDF** con firmas digitales
- **Flujo de aprobación jerárquico**
- **Verificación de certificados** con códigos únicos
- **Reportes y estadísticas**
- **API REST completa**

## 🛠️ Tecnologías

### Frontend
- Next.js 14 (App Router)
- TypeScript
- Tailwind CSS
- Shadcn/ui
- React Hook Form

### Backend
- PHP 8.1+
- MySQL 8.0
- TCPDF (generación de PDFs)
- JWT Authentication
- RESTful API

## 📋 Requisitos

- Docker y Docker Compose
- Node.js 18+ (para desarrollo)
- PHP 8.1+ (para desarrollo local)
- MySQL 8.0+ (para desarrollo local)

## 🚀 Instalación y Configuración

### 1. Clonar el repositorio
\`\`\`bash
git clone https://github.com/tu-usuario/bomberos-certificados.git
cd bomberos-certificados
\`\`\`

### 2. Configurar variables de entorno
\`\`\`bash
cp .env.example .env
# Editar .env con tus configuraciones
\`\`\`

### 3. Ejecutar con Docker (Recomendado)
\`\`\`bash
docker-compose up -d
\`\`\`

### 4. Acceder a la aplicación
- Frontend: http://localhost:3000
- Backend API: http://localhost:8080/api
- Base de datos: localhost:3306

## 👥 Usuarios por Defecto

| Rol | Email | Contraseña |
|-----|-------|------------|
| Administrador | admin@bomberos.gov.co | password123 |
| Director Nacional | director.nacional@bomberos.gov.co | password123 |
| Educación DNBC | educacion@bomberos.gov.co | password123 |
| Coordinador | carlos.martinez@bomberos.gov.co | password123 |
| Director Escuela | laura.gomez@bomberos.gov.co | password123 |

## 🔧 Desarrollo Local

### Frontend
\`\`\`bash
npm install
npm run dev
\`\`\`

### Backend
\`\`\`bash
cd backend
composer install
php -S localhost:8080
\`\`\`

## 📁 Estructura del Proyecto

\`\`\`
├── app/                    # Frontend Next.js
├── backend/               # Backend PHP
│   ├── api/              # Endpoints de la API
│   ├── config/           # Configuración
│   ├── models/           # Modelos de datos
│   ├── utils/            # Utilidades
│   └── storage/          # Archivos generados
├── components/           # Componentes React
├── lib/                 # Librerías y utilidades
├── hooks/               # Custom hooks
└── docker-compose.yml   # Configuración Docker
\`\`\`

## 🔐 Roles y Permisos

### Administrador General
- Acceso completo al sistema
- Gestión de usuarios y escuelas
- Configuración del sistema

### Director Nacional
- Firma final de certificados
- Reportes ejecutivos
- Supervisión general

### Educación DNBC
- Validación académica
- Aprobación de contenidos
- Firma de certificados (3er nivel)

### Director de Escuela
- Gestión de su escuela
- Aprobación institucional
- Firma de certificados (2do nivel)

### Coordinador
- Gestión de cursos
- Primera firma de certificados
- Calificaciones

### Escuela
- Registro de participantes
- Consultas básicas
- Matrículas

## 📊 API Endpoints

### Autenticación
- `POST /api/auth.php` - Login/Logout
- `POST /api/auth.php?action=verify_token` - Verificar token

### Participantes
- `GET /api/participantes.php` - Listar participantes
- `POST /api/participantes.php` - Crear participante
- `PUT /api/participantes.php` - Actualizar participante
- `DELETE /api/participantes.php?id={id}` - Eliminar participante

### Cursos
- `GET /api/cursos.php` - Listar cursos
- `POST /api/cursos.php` - Crear curso
- `PUT /api/cursos.php` - Actualizar curso

### Certificados
- `GET /api/certificados.php` - Listar certificados
- `POST /api/certificados.php` - Generar certificados
- `GET /api/certificados.php?action=verificar&codigo={codigo}` - Verificar certificado

## 🔒 Seguridad

- Autenticación JWT
- Validación de roles y permisos
- Sanitización de datos
- Protección CSRF
- Logs de auditoría
- Firmas digitales con hash SHA-256

## 📈 Características de Producción

- **Escalabilidad**: Arquitectura modular
- **Seguridad**: Múltiples capas de seguridad
- **Auditoría**: Logs completos de acciones
- **Backup**: Sistema de respaldo automático
- **Monitoreo**: Logs de errores y rendimiento
- **SSL**: Certificados HTTPS
- **CDN**: Optimización de archivos estáticos

## 🚀 Despliegue en Producción

### 1. Servidor Web
\`\`\`bash
# Configurar Apache/Nginx
# Instalar PHP 8.1+ con extensiones
# Configurar MySQL 8.0+
\`\`\`

### 2. Base de Datos
\`\`\`bash
mysql -u root -p < backend/database/schema.sql
\`\`\`

### 3. Configuración
\`\`\`bash
# Configurar variables de entorno
# Configurar permisos de archivos
# Configurar SSL
\`\`\`

### 4. Optimizaciones
\`\`\`bash
# Habilitar compresión gzip
# Configurar cache
# Optimizar imágenes
\`\`\`

## 📞 Soporte

Para soporte técnico o consultas:
- Email: soporte@bomberos.gov.co
- Documentación: [Wiki del proyecto]
- Issues: [GitHub Issues]

## 📄 Licencia

Este proyecto está licenciado bajo la Licencia MIT - ver el archivo [LICENSE](LICENSE) para más detalles.

## 🤝 Contribuir

1. Fork el proyecto
2. Crear una rama para tu feature (`git checkout -b feature/AmazingFeature`)
3. Commit tus cambios (`git commit -m 'Add some AmazingFeature'`)
4. Push a la rama (`git push origin feature/AmazingFeature`)
5. Abrir un Pull Request

---

**Desarrollado para la Dirección Nacional de Bomberos Colombia**
