"use client"

import { useState } from "react"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Input } from "@/components/ui/input"
import { Table, TableBody, TableCell, TableHead, TableHeader, TableRow } from "@/components/ui/table"
import { Badge } from "@/components/ui/badge"
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select"
import {
  Dialog,
  DialogContent,
  DialogDescription,
  DialogFooter,
  DialogHeader,
  DialogTitle,
} from "@/components/ui/dialog"
import { Label } from "@/components/ui/label"
import { Textarea } from "@/components/ui/textarea"
import { useToast } from "@/components/ui/use-toast"

export default function CalificacionesPage() {
  const { toast } = useToast()

  const [cursoSeleccionado, setCursoSeleccionado] = useState("")
  const [participantes, setParticipantes] = useState([
    {
      id: 1,
      nombres: "Carlos Andrés",
      apellidos: "Pérez González",
      cedula: "12345678",
      calificacionTeorica: 85,
      calificacionPractica: 90,
      calificacionFinal: 87.5,
      estado: "Aprobado",
      observaciones: "",
    },
    {
      id: 2,
      nombres: "María Elena",
      apellidos: "Rodríguez López",
      cedula: "87654321",
      calificacionTeorica: 92,
      calificacionPractica: 88,
      calificacionFinal: 90,
      estado: "Aprobado",
      observaciones: "",
    },
    {
      id: 3,
      nombres: "Juan Carlos",
      apellidos: "Martínez Silva",
      cedula: "11223344",
      calificacionTeorica: 65,
      calificacionPractica: 70,
      calificacionFinal: 67.5,
      estado: "No Aprobado",
      observaciones: "Requiere refuerzo en técnicas básicas",
    },
  ])

  const [editandoParticipante, setEditandoParticipante] = useState<any>(null)
  const [isDialogOpen, setIsDialogOpen] = useState(false)

  const cursos = [
    { id: 1, nombre: "Técnicas de Rescate en Estructuras Colapsadas" },
    { id: 2, nombre: "Primeros Auxilios Avanzados" },
    { id: 3, nombre: "Manejo de Materiales Peligrosos" },
  ]

  const calcularCalificacionFinal = (teorica: number, practica: number) => {
    return (teorica * 0.4 + practica * 0.6).toFixed(1)
  }

  const determinarEstado = (calificacionFinal: number) => {
    return calificacionFinal >= 70 ? "Aprobado" : "No Aprobado"
  }

  const handleEditarCalificacion = (participante: any) => {
    setEditandoParticipante({ ...participante })
    setIsDialogOpen(true)
  }

  const handleGuardarCalificacion = () => {
    const calificacionFinal = Number.parseFloat(
      calcularCalificacionFinal(editandoParticipante.calificacionTeorica, editandoParticipante.calificacionPractica),
    )

    const estado = determinarEstado(calificacionFinal)

    const participanteActualizado = {
      ...editandoParticipante,
      calificacionFinal,
      estado,
    }

    setParticipantes(participantes.map((p) => (p.id === editandoParticipante.id ? participanteActualizado : p)))

    setIsDialogOpen(false)
    setEditandoParticipante(null)

    toast({
      title: "Calificación actualizada",
      description: `Las calificaciones de ${participanteActualizado.nombres} ${participanteActualizado.apellidos} han sido guardadas.`,
    })
  }

  const handleGenerarActa = () => {
    if (!cursoSeleccionado) {
      toast({
        title: "Error",
        description: "Por favor seleccione un curso.",
        variant: "destructive",
      })
      return
    }

    toast({
      title: "Acta generada",
      description: "El acta de calificaciones ha sido generada exitosamente.",
    })
  }

  const getEstadoColor = (estado: string) => {
    return estado === "Aprobado"
      ? "bg-green-100 text-green-700 hover:bg-green-100"
      : "bg-red-100 text-red-700 hover:bg-red-100"
  }

  const getCalificacionColor = (calificacion: number) => {
    if (calificacion >= 90) return "text-green-600 font-semibold"
    if (calificacion >= 80) return "text-blue-600 font-semibold"
    if (calificacion >= 70) return "text-yellow-600 font-semibold"
    return "text-red-600 font-semibold"
  }

  return (
    <div className="space-y-6">
      <div className="flex flex-col md:flex-row md:items-center md:justify-between gap-4">
        <div>
          <h1 className="text-3xl font-bold tracking-tight">Calificaciones</h1>
          <p className="text-muted-foreground">Gestione las calificaciones de los participantes</p>
        </div>
        <div className="flex gap-2">
          <Button variant="outline" onClick={handleGenerarActa}>
            <svg
              xmlns="http://www.w3.org/2000/svg"
              width="16"
              height="16"
              viewBox="0 0 24 24"
              fill="none"
              stroke="currentColor"
              strokeWidth="2"
              strokeLinecap="round"
              strokeLinejoin="round"
              className="mr-2"
            >
              <path d="M14.5 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7.5L14.5 2z" />
              <polyline points="14 2 14 8 20 8" />
            </svg>
            Generar Acta
          </Button>
          <Button className="bg-red-700 hover:bg-red-800">
            <svg
              xmlns="http://www.w3.org/2000/svg"
              width="16"
              height="16"
              viewBox="0 0 24 24"
              fill="none"
              stroke="currentColor"
              strokeWidth="2"
              strokeLinecap="round"
              strokeLinejoin="round"
              className="mr-2"
            >
              <path d="M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4" />
              <polyline points="7 10 12 15 17 10" />
              <line x1="12" x2="12" y1="15" y2="3" />
            </svg>
            Exportar Calificaciones
          </Button>
        </div>
      </div>

      <Card>
        <CardHeader>
          <CardTitle>Seleccionar Curso</CardTitle>
          <CardDescription>Elija el curso para gestionar las calificaciones</CardDescription>
        </CardHeader>
        <CardContent>
          <Select value={cursoSeleccionado} onValueChange={setCursoSeleccionado}>
            <SelectTrigger className="max-w-md">
              <SelectValue placeholder="Seleccionar curso" />
            </SelectTrigger>
            <SelectContent>
              {cursos.map((curso) => (
                <SelectItem key={curso.id} value={curso.id.toString()}>
                  {curso.nombre}
                </SelectItem>
              ))}
            </SelectContent>
          </Select>
        </CardContent>
      </Card>

      {cursoSeleccionado && (
        <Card>
          <CardHeader>
            <CardTitle>Calificaciones del Curso</CardTitle>
            <CardDescription>Gestione las calificaciones teóricas y prácticas de los participantes</CardDescription>
          </CardHeader>
          <CardContent>
            <div className="flex flex-col md:flex-row gap-4 mb-6">
              <Input placeholder="Buscar participante..." className="max-w-sm" />
              <div className="flex gap-2 ml-auto">
                <Select>
                  <SelectTrigger className="max-w-xs">
                    <SelectValue placeholder="Filtrar por estado" />
                  </SelectTrigger>
                  <SelectContent>
                    <SelectItem value="todos">Todos</SelectItem>
                    <SelectItem value="aprobado">Aprobados</SelectItem>
                    <SelectItem value="no-aprobado">No Aprobados</SelectItem>
                  </SelectContent>
                </Select>
              </div>
            </div>

            <div className="rounded-md border">
              <Table>
                <TableHeader>
                  <TableRow>
                    <TableHead>Participante</TableHead>
                    <TableHead>Cédula</TableHead>
                    <TableHead>Calificación Teórica</TableHead>
                    <TableHead>Calificación Práctica</TableHead>
                    <TableHead>Calificación Final</TableHead>
                    <TableHead>Estado</TableHead>
                    <TableHead>Acciones</TableHead>
                  </TableRow>
                </TableHeader>
                <TableBody>
                  {participantes.map((participante) => (
                    <TableRow key={participante.id}>
                      <TableCell className="font-medium">
                        {participante.nombres} {participante.apellidos}
                      </TableCell>
                      <TableCell>{participante.cedula}</TableCell>
                      <TableCell>
                        <span className={getCalificacionColor(participante.calificacionTeorica)}>
                          {participante.calificacionTeorica}/100
                        </span>
                      </TableCell>
                      <TableCell>
                        <span className={getCalificacionColor(participante.calificacionPractica)}>
                          {participante.calificacionPractica}/100
                        </span>
                      </TableCell>
                      <TableCell>
                        <span className={getCalificacionColor(participante.calificacionFinal)}>
                          {participante.calificacionFinal}/100
                        </span>
                      </TableCell>
                      <TableCell>
                        <Badge className={getEstadoColor(participante.estado)}>{participante.estado}</Badge>
                      </TableCell>
                      <TableCell>
                        <Button variant="ghost" size="icon" onClick={() => handleEditarCalificacion(participante)}>
                          <svg
                            xmlns="http://www.w3.org/2000/svg"
                            width="16"
                            height="16"
                            viewBox="0 0 24 24"
                            fill="none"
                            stroke="currentColor"
                            strokeWidth="2"
                            strokeLinecap="round"
                            strokeLinejoin="round"
                          >
                            <path d="M17 3a2.85 2.83 0 1 1 4 4L7.5 20.5 2 22l1.5-5.5Z" />
                            <path d="m15 5 4 4" />
                          </svg>
                          <span className="sr-only">Editar calificación</span>
                        </Button>
                      </TableCell>
                    </TableRow>
                  ))}
                </TableBody>
              </Table>
            </div>

            <div className="mt-6 grid grid-cols-1 md:grid-cols-4 gap-4">
              <Card>
                <CardContent className="p-4">
                  <div className="text-2xl font-bold text-green-600">
                    {participantes.filter((p) => p.estado === "Aprobado").length}
                  </div>
                  <p className="text-sm text-muted-foreground">Aprobados</p>
                </CardContent>
              </Card>
              <Card>
                <CardContent className="p-4">
                  <div className="text-2xl font-bold text-red-600">
                    {participantes.filter((p) => p.estado === "No Aprobado").length}
                  </div>
                  <p className="text-sm text-muted-foreground">No Aprobados</p>
                </CardContent>
              </Card>
              <Card>
                <CardContent className="p-4">
                  <div className="text-2xl font-bold text-blue-600">
                    {(participantes.reduce((acc, p) => acc + p.calificacionFinal, 0) / participantes.length).toFixed(1)}
                  </div>
                  <p className="text-sm text-muted-foreground">Promedio General</p>
                </CardContent>
              </Card>
              <Card>
                <CardContent className="p-4">
                  <div className="text-2xl font-bold text-purple-600">
                    {(
                      (participantes.filter((p) => p.estado === "Aprobado").length / participantes.length) *
                      100
                    ).toFixed(1)}
                    %
                  </div>
                  <p className="text-sm text-muted-foreground">Tasa de Aprobación</p>
                </CardContent>
              </Card>
            </div>
          </CardContent>
        </Card>
      )}

      <Dialog open={isDialogOpen} onOpenChange={setIsDialogOpen}>
        <DialogContent className="max-w-2xl">
          <DialogHeader>
            <DialogTitle>Editar Calificaciones</DialogTitle>
            <DialogDescription>Modifique las calificaciones del participante</DialogDescription>
          </DialogHeader>
          {editandoParticipante && (
            <div className="space-y-4">
              <div className="grid grid-cols-2 gap-4">
                <div>
                  <Label>Participante</Label>
                  <p className="font-medium">
                    {editandoParticipante.nombres} {editandoParticipante.apellidos}
                  </p>
                </div>
                <div>
                  <Label>Cédula</Label>
                  <p className="font-medium">{editandoParticipante.cedula}</p>
                </div>
              </div>

              <div className="grid grid-cols-2 gap-4">
                <div>
                  <Label htmlFor="calificacionTeorica">Calificación Teórica (40%)</Label>
                  <Input
                    id="calificacionTeorica"
                    type="number"
                    min="0"
                    max="100"
                    value={editandoParticipante.calificacionTeorica}
                    onChange={(e) =>
                      setEditandoParticipante({
                        ...editandoParticipante,
                        calificacionTeorica: Number.parseInt(e.target.value) || 0,
                      })
                    }
                  />
                </div>
                <div>
                  <Label htmlFor="calificacionPractica">Calificación Práctica (60%)</Label>
                  <Input
                    id="calificacionPractica"
                    type="number"
                    min="0"
                    max="100"
                    value={editandoParticipante.calificacionPractica}
                    onChange={(e) =>
                      setEditandoParticipante({
                        ...editandoParticipante,
                        calificacionPractica: Number.parseInt(e.target.value) || 0,
                      })
                    }
                  />
                </div>
              </div>

              <div className="bg-gray-50 p-4 rounded-lg">
                <div className="grid grid-cols-2 gap-4">
                  <div>
                    <Label>Calificación Final</Label>
                    <p className="text-2xl font-bold">
                      {calcularCalificacionFinal(
                        editandoParticipante.calificacionTeorica,
                        editandoParticipante.calificacionPractica,
                      )}
                      /100
                    </p>
                  </div>
                  <div>
                    <Label>Estado</Label>
                    <Badge
                      className={getEstadoColor(
                        determinarEstado(
                          Number.parseFloat(
                            calcularCalificacionFinal(
                              editandoParticipante.calificacionTeorica,
                              editandoParticipante.calificacionPractica,
                            ),
                          ),
                        ),
                      )}
                    >
                      {determinarEstado(
                        Number.parseFloat(
                          calcularCalificacionFinal(
                            editandoParticipante.calificacionTeorica,
                            editandoParticipante.calificacionPractica,
                          ),
                        ),
                      )}
                    </Badge>
                  </div>
                </div>
              </div>

              <div>
                <Label htmlFor="observaciones">Observaciones</Label>
                <Textarea
                  id="observaciones"
                  value={editandoParticipante.observaciones}
                  onChange={(e) =>
                    setEditandoParticipante({
                      ...editandoParticipante,
                      observaciones: e.target.value,
                    })
                  }
                  placeholder="Observaciones adicionales sobre el desempeño del participante..."
                  rows={3}
                />
              </div>
            </div>
          )}
          <DialogFooter>
            <Button variant="outline" onClick={() => setIsDialogOpen(false)}>
              Cancelar
            </Button>
            <Button onClick={handleGuardarCalificacion} className="bg-red-700 hover:bg-red-800">
              Guardar Calificaciones
            </Button>
          </DialogFooter>
        </DialogContent>
      </Dialog>
    </div>
  )
}
