"use client"

import { useState } from "react"
import { useRouter } from "next/navigation"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Label } from "@/components/ui/label"
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select"
import { Checkbox } from "@/components/ui/checkbox"
import { Table, TableBody, TableCell, TableHead, TableHeader, TableRow } from "@/components/ui/table"
import { useToast } from "@/components/ui/use-toast"

export default function GenerarCertificadosPage() {
  const router = useRouter()
  const { toast } = useToast()

  const [cursoSeleccionado, setCursoSeleccionado] = useState("")
  const [participantesSeleccionados, setParticipantesSeleccionados] = useState<string[]>([])
  const [opcionesCertificado, setOpcionesCertificado] = useState({
    incluirCalificacion: true,
    incluirFechas: true,
    incluirCodigoQR: true,
    incluirFirmas: true,
    enviarPorCorreo: false,
  })
  const [plantillaSeleccionada, setPlantillaSeleccionada] = useState("estandar")
  const [vistaPrevia, setVistaPrevia] = useState(false)

  const cursos = [
    {
      id: "1",
      nombre: "Técnicas de Rescate en Estructuras Colapsadas",
      fechaInicio: "2023-05-15",
      fechaFin: "2023-06-30",
    },
    { id: "2", nombre: "Primeros Auxilios Avanzados", fechaInicio: "2023-06-02", fechaFin: "2023-06-15" },
    { id: "3", nombre: "Manejo de Materiales Peligrosos", fechaInicio: "2023-06-10", fechaFin: "2023-07-25" },
  ]

  const participantes = [
    { id: "1", nombre: "Carlos Andrés Pérez", cedula: "12345678", calificacion: 85, estado: "Aprobado" },
    { id: "2", nombre: "María Elena Rodríguez", cedula: "87654321", calificacion: 92, estado: "Aprobado" },
    { id: "3", nombre: "Juan Carlos Martínez", cedula: "11223344", calificacion: 65, estado: "No Aprobado" },
    { id: "4", nombre: "Ana Sofía López", cedula: "55667788", calificacion: 95, estado: "Aprobado" },
    { id: "5", nombre: "Pedro José Ramírez", cedula: "99887766", calificacion: 78, estado: "Aprobado" },
  ]

  const plantillas = [
    { id: "estandar", nombre: "Plantilla Estándar", descripcion: "Diseño oficial de la DNBC" },
    { id: "moderna", nombre: "Plantilla Moderna", descripcion: "Diseño moderno con elementos gráficos" },
    { id: "minimalista", nombre: "Plantilla Minimalista", descripcion: "Diseño simple y elegante" },
  ]

  const handleToggleParticipante = (participanteId: string) => {
    setParticipantesSeleccionados((prev) =>
      prev.includes(participanteId) ? prev.filter((id) => id !== participanteId) : [...prev, participanteId],
    )
  }

  const handleSelectAll = () => {
    if (participantesSeleccionados.length === participantes.filter((p) => p.estado === "Aprobado").length) {
      setParticipantesSeleccionados([])
    } else {
      setParticipantesSeleccionados(participantes.filter((p) => p.estado === "Aprobado").map((p) => p.id))
    }
  }

  const handleGenerarCertificados = () => {
    if (participantesSeleccionados.length === 0) {
      toast({
        title: "Error",
        description: "Debe seleccionar al menos un participante.",
        variant: "destructive",
      })
      return
    }

    toast({
      title: "Certificados generados",
      description: `Se han generado ${participantesSeleccionados.length} certificados exitosamente.`,
    })

    // Redirigir a la página de certificados
    router.push("/dashboard/certificados")
  }

  const handleVistaPrevia = () => {
    if (participantesSeleccionados.length === 0) {
      toast({
        title: "Error",
        description: "Debe seleccionar al menos un participante para la vista previa.",
        variant: "destructive",
      })
      return
    }

    setVistaPrevia(true)
  }

  return (
    <div className="space-y-6">
      <div className="flex items-center gap-4">
        <Button variant="ghost" onClick={() => router.back()}>
          <svg
            xmlns="http://www.w3.org/2000/svg"
            width="16"
            height="16"
            viewBox="0 0 24 24"
            fill="none"
            stroke="currentColor"
            strokeWidth="2"
            strokeLinecap="round"
            strokeLinejoin="round"
            className="mr-2"
          >
            <path d="m12 19-7-7 7-7" />
            <path d="M19 12H5" />
          </svg>
          Volver
        </Button>
        <div>
          <h1 className="text-3xl font-bold tracking-tight">Generar Certificados</h1>
          <p className="text-muted-foreground">Genere certificados para los participantes de un curso</p>
        </div>
      </div>

      <div className="grid grid-cols-1 md:grid-cols-3 gap-6">
        <div className="md:col-span-2 space-y-6">
          <Card>
            <CardHeader>
              <CardTitle>Seleccionar Curso</CardTitle>
              <CardDescription>Elija el curso para generar los certificados</CardDescription>
            </CardHeader>
            <CardContent>
              <Select value={cursoSeleccionado} onValueChange={setCursoSeleccionado}>
                <SelectTrigger>
                  <SelectValue placeholder="Seleccionar curso" />
                </SelectTrigger>
                <SelectContent>
                  {cursos.map((curso) => (
                    <SelectItem key={curso.id} value={curso.id}>
                      {curso.nombre}
                    </SelectItem>
                  ))}
                </SelectContent>
              </Select>

              {cursoSeleccionado && (
                <div className="mt-4 grid grid-cols-2 gap-4">
                  <div>
                    <Label className="text-sm text-muted-foreground">Fecha de Inicio</Label>
                    <p className="font-medium">{cursos.find((c) => c.id === cursoSeleccionado)?.fechaInicio}</p>
                  </div>
                  <div>
                    <Label className="text-sm text-muted-foreground">Fecha de Finalización</Label>
                    <p className="font-medium">{cursos.find((c) => c.id === cursoSeleccionado)?.fechaFin}</p>
                  </div>
                </div>
              )}
            </CardContent>
          </Card>

          {cursoSeleccionado && (
            <Card>
              <CardHeader>
                <CardTitle>Seleccionar Participantes</CardTitle>
                <CardDescription>Elija los participantes para generar los certificados</CardDescription>
              </CardHeader>
              <CardContent>
                <div className="flex items-center justify-between mb-4">
                  <Button variant="outline" size="sm" onClick={handleSelectAll}>
                    {participantesSeleccionados.length === participantes.filter((p) => p.estado === "Aprobado").length
                      ? "Deseleccionar Todos"
                      : "Seleccionar Todos"}
                  </Button>
                  <p className="text-sm text-muted-foreground">
                    {participantesSeleccionados.length} de {participantes.filter((p) => p.estado === "Aprobado").length}{" "}
                    seleccionados
                  </p>
                </div>

                <div className="border rounded-md">
                  <Table>
                    <TableHeader>
                      <TableRow>
                        <TableHead className="w-12"></TableHead>
                        <TableHead>Nombre</TableHead>
                        <TableHead>Cédula</TableHead>
                        <TableHead>Calificación</TableHead>
                        <TableHead>Estado</TableHead>
                      </TableRow>
                    </TableHeader>
                    <TableBody>
                      {participantes.map((participante) => (
                        <TableRow key={participante.id}>
                          <TableCell>
                            <Checkbox
                              checked={participantesSeleccionados.includes(participante.id)}
                              onCheckedChange={() => handleToggleParticipante(participante.id)}
                              disabled={participante.estado !== "Aprobado"}
                            />
                          </TableCell>
                          <TableCell className="font-medium">{participante.nombre}</TableCell>
                          <TableCell>{participante.cedula}</TableCell>
                          <TableCell>{participante.calificacion}/100</TableCell>
                          <TableCell>
                            <span
                              className={`inline-flex items-center rounded-full px-2.5 py-0.5 text-xs font-semibold ${
                                participante.estado === "Aprobado"
                                  ? "bg-green-100 text-green-700"
                                  : "bg-red-100 text-red-700"
                              }`}
                            >
                              {participante.estado}
                            </span>
                          </TableCell>
                        </TableRow>
                      ))}
                    </TableBody>
                  </Table>
                </div>
              </CardContent>
            </Card>
          )}
        </div>

        <div className="space-y-6">
          <Card>
            <CardHeader>
              <CardTitle>Configuración del Certificado</CardTitle>
              <CardDescription>Personalice las opciones del certificado</CardDescription>
            </CardHeader>
            <CardContent className="space-y-4">
              <div>
                <Label htmlFor="plantilla">Plantilla</Label>
                <Select value={plantillaSeleccionada} onValueChange={setPlantillaSeleccionada}>
                  <SelectTrigger>
                    <SelectValue placeholder="Seleccionar plantilla" />
                  </SelectTrigger>
                  <SelectContent>
                    {plantillas.map((plantilla) => (
                      <SelectItem key={plantilla.id} value={plantilla.id}>
                        {plantilla.nombre}
                      </SelectItem>
                    ))}
                  </SelectContent>
                </Select>
                <p className="text-xs text-muted-foreground mt-1">
                  {plantillas.find((p) => p.id === plantillaSeleccionada)?.descripcion}
                </p>
              </div>

              <div className="space-y-3">
                <Label>Opciones del Certificado</Label>
                <div className="space-y-2">
                  <div className="flex items-center space-x-2">
                    <Checkbox
                      id="incluirCalificacion"
                      checked={opcionesCertificado.incluirCalificacion}
                      onCheckedChange={(checked) =>
                        setOpcionesCertificado({ ...opcionesCertificado, incluirCalificacion: !!checked })
                      }
                    />
                    <Label htmlFor="incluirCalificacion">Incluir calificación</Label>
                  </div>
                  <div className="flex items-center space-x-2">
                    <Checkbox
                      id="incluirFechas"
                      checked={opcionesCertificado.incluirFechas}
                      onCheckedChange={(checked) =>
                        setOpcionesCertificado({ ...opcionesCertificado, incluirFechas: !!checked })
                      }
                    />
                    <Label htmlFor="incluirFechas">Incluir fechas del curso</Label>
                  </div>
                  <div className="flex items-center space-x-2">
                    <Checkbox
                      id="incluirCodigoQR"
                      checked={opcionesCertificado.incluirCodigoQR}
                      onCheckedChange={(checked) =>
                        setOpcionesCertificado({ ...opcionesCertificado, incluirCodigoQR: !!checked })
                      }
                    />
                    <Label htmlFor="incluirCodigoQR">Incluir código QR</Label>
                  </div>
                  <div className="flex items-center space-x-2">
                    <Checkbox
                      id="incluirFirmas"
                      checked={opcionesCertificado.incluirFirmas}
                      onCheckedChange={(checked) =>
                        setOpcionesCertificado({ ...opcionesCertificado, incluirFirmas: !!checked })
                      }
                    />
                    <Label htmlFor="incluirFirmas">Incluir firmas digitales</Label>
                  </div>
                  <div className="flex items-center space-x-2">
                    <Checkbox
                      id="enviarPorCorreo"
                      checked={opcionesCertificado.enviarPorCorreo}
                      onCheckedChange={(checked) =>
                        setOpcionesCertificado({ ...opcionesCertificado, enviarPorCorreo: !!checked })
                      }
                    />
                    <Label htmlFor="enviarPorCorreo">Enviar por correo electrónico</Label>
                  </div>
                </div>
              </div>

              <div className="space-y-2">
                <Button
                  variant="outline"
                  className="w-full"
                  onClick={handleVistaPrevia}
                  disabled={!cursoSeleccionado || participantesSeleccionados.length === 0}
                >
                  <svg
                    xmlns="http://www.w3.org/2000/svg"
                    width="16"
                    height="16"
                    viewBox="0 0 24 24"
                    fill="none"
                    stroke="currentColor"
                    strokeWidth="2"
                    strokeLinecap="round"
                    strokeLinejoin="round"
                    className="mr-2"
                  >
                    <path d="M2 12s3-7 10-7 10 7 10 7-3 7-10 7-10-7-10-7Z" />
                    <circle cx="12" cy="12" r="3" />
                  </svg>
                  Vista Previa
                </Button>
                <Button
                  className="w-full bg-red-700 hover:bg-red-800"
                  onClick={handleGenerarCertificados}
                  disabled={!cursoSeleccionado || participantesSeleccionados.length === 0}
                >
                  <svg
                    xmlns="http://www.w3.org/2000/svg"
                    width="16"
                    height="16"
                    viewBox="0 0 24 24"
                    fill="none"
                    stroke="currentColor"
                    strokeWidth="2"
                    strokeLinecap="round"
                    strokeLinejoin="round"
                    className="mr-2"
                  >
                    <path d="M14.5 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7.5L14.5 2z" />
                    <polyline points="14 2 14 8 20 8" />
                  </svg>
                  Generar Certificados ({participantesSeleccionados.length})
                </Button>
              </div>
            </CardContent>
          </Card>

          {vistaPrevia && (
            <Card>
              <CardHeader>
                <CardTitle>Vista Previa</CardTitle>
                <CardDescription>Previsualización del certificado</CardDescription>
              </CardHeader>
              <CardContent>
                <div className="border-2 border-dashed border-gray-300 p-6 rounded-lg bg-gray-50">
                  <div className="text-center space-y-4">
                    <div className="bg-red-700 text-white p-2 rounded">
                      <h3 className="font-bold">DIRECCIÓN NACIONAL DE BOMBEROS COLOMBIA</h3>
                    </div>
                    <h2 className="text-xl font-bold">CERTIFICADO DE PARTICIPACIÓN</h2>
                    <p className="text-sm">Se certifica que</p>
                    <p className="text-lg font-semibold">
                      {participantes.find((p) => p.id === participantesSeleccionados[0])?.nombre ||
                        "[Nombre del Participante]"}
                    </p>
                    <p className="text-sm">participó exitosamente en el curso</p>
                    <p className="font-semibold">
                      {cursos.find((c) => c.id === cursoSeleccionado)?.nombre || "[Nombre del Curso]"}
                    </p>
                    {opcionesCertificado.incluirFechas && (
                      <p className="text-sm">
                        Realizado del {cursos.find((c) => c.id === cursoSeleccionado)?.fechaInicio} al{" "}
                        {cursos.find((c) => c.id === cursoSeleccionado)?.fechaFin}
                      </p>
                    )}
                    {opcionesCertificado.incluirCalificacion && (
                      <p className="text-sm">
                        Calificación obtenida:{" "}
                        {participantes.find((p) => p.id === participantesSeleccionados[0])?.calificacion || 0}/100
                      </p>
                    )}
                    {opcionesCertificado.incluirCodigoQR && (
                      <div className="flex justify-center">
                        <div className="w-16 h-16 bg-gray-300 flex items-center justify-center text-xs">QR</div>
                      </div>
                    )}
                    {opcionesCertificado.incluirFirmas && (
                      <div className="grid grid-cols-2 gap-4 mt-8">
                        <div className="text-center">
                          <div className="border-t border-gray-400 pt-2">
                            <p className="text-xs">Coordinador</p>
                          </div>
                        </div>
                        <div className="text-center">
                          <div className="border-t border-gray-400 pt-2">
                            <p className="text-xs">Director Nacional</p>
                          </div>
                        </div>
                      </div>
                    )}
                  </div>
                </div>
              </CardContent>
            </Card>
          )}
        </div>
      </div>
    </div>
  )
}
