"use client"

import { useState } from "react"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Input } from "@/components/ui/input"
import { Table, TableBody, TableCell, TableHead, TableHeader, TableRow } from "@/components/ui/table"
import { Badge } from "@/components/ui/badge"
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs"
import { useToast } from "@/components/ui/use-toast"

export default function CertificadosPage() {
  const { toast } = useToast()

  const [certificados] = useState([
    {
      id: 1,
      participante: "Carlos Andrés Pérez",
      curso: "Técnicas de Rescate en Estructuras Colapsadas",
      codigo: "CERT-2023-001",
      fechaEmision: "2023-06-15",
      estado: "Pendiente Coordinador",
      calificacion: 85,
      firmas: {
        coordinador: false,
        directorEscuela: false,
        educacionDNBC: false,
        directorNacional: false,
      },
    },
    {
      id: 2,
      participante: "María Elena Rodríguez",
      curso: "Primeros Auxilios Avanzados",
      codigo: "CERT-2023-002",
      fechaEmision: "2023-06-10",
      estado: "Pendiente Director Escuela",
      calificacion: 92,
      firmas: {
        coordinador: true,
        directorEscuela: false,
        educacionDNBC: false,
        directorNacional: false,
      },
    },
    {
      id: 3,
      participante: "Juan Carlos Martínez",
      curso: "Manejo de Materiales Peligrosos",
      codigo: "CERT-2023-003",
      fechaEmision: "2023-06-05",
      estado: "Pendiente Educación DNBC",
      calificacion: 88,
      firmas: {
        coordinador: true,
        directorEscuela: true,
        educacionDNBC: false,
        directorNacional: false,
      },
    },
    {
      id: 4,
      participante: "Ana Sofía López",
      curso: "Técnicas de Extinción de Incendios",
      codigo: "CERT-2023-004",
      fechaEmision: "2023-05-28",
      estado: "Completado",
      calificacion: 95,
      firmas: {
        coordinador: true,
        directorEscuela: true,
        educacionDNBC: true,
        directorNacional: true,
      },
    },
  ])

  const [actas] = useState([
    {
      id: 1,
      curso: "Técnicas de Rescate en Estructuras Colapsadas",
      tipo: "Acta de Calificaciones",
      fechaCreacion: "2023-06-15",
      estado: "Pendiente Coordinador",
      participantes: 24,
    },
    {
      id: 2,
      curso: "Primeros Auxilios Avanzados",
      tipo: "Acta de Finalización",
      fechaCreacion: "2023-06-10",
      estado: "Pendiente Director Escuela",
      participantes: 18,
    },
  ])

  const handleFirmar = (id: number, tipo: string) => {
    toast({
      title: "Documento firmado",
      description: `El ${tipo} ha sido firmado exitosamente.`,
    })
  }

  const handleGenerarPDF = (id: number, tipo: string) => {
    toast({
      title: "PDF generado",
      description: `El ${tipo} ha sido generado y está listo para descargar.`,
    })
  }

  const getEstadoColor = (estado: string) => {
    switch (estado) {
      case "Completado":
        return "bg-green-100 text-green-700 hover:bg-green-100"
      case "Pendiente Coordinador":
        return "bg-yellow-100 text-yellow-700 hover:bg-yellow-100"
      case "Pendiente Director Escuela":
        return "bg-blue-100 text-blue-700 hover:bg-blue-100"
      case "Pendiente Educación DNBC":
        return "bg-purple-100 text-purple-700 hover:bg-purple-100"
      case "Pendiente Director Nacional":
        return "bg-orange-100 text-orange-700 hover:bg-orange-100"
      default:
        return "bg-gray-100 text-gray-700 hover:bg-gray-100"
    }
  }

  return (
    <div className="space-y-6">
      <div className="flex flex-col md:flex-row md:items-center md:justify-between gap-4">
        <div>
          <h1 className="text-3xl font-bold tracking-tight">Gestión de Certificados y Documentos</h1>
          <p className="text-muted-foreground">Administre certificados, actas e informes del sistema</p>
        </div>
        <div className="flex gap-2">
          <Button variant="outline">
            <svg
              xmlns="http://www.w3.org/2000/svg"
              width="16"
              height="16"
              viewBox="0 0 24 24"
              fill="none"
              stroke="currentColor"
              strokeWidth="2"
              strokeLinecap="round"
              strokeLinejoin="round"
              className="mr-2"
            >
              <path d="M3 3v18h18" />
              <path d="m19 9-5 5-4-4-3 3" />
            </svg>
            Generar Reporte
          </Button>
          <Button className="bg-red-700 hover:bg-red-800">
            <svg
              xmlns="http://www.w3.org/2000/svg"
              width="16"
              height="16"
              viewBox="0 0 24 24"
              fill="none"
              stroke="currentColor"
              strokeWidth="2"
              strokeLinecap="round"
              strokeLinejoin="round"
              className="mr-2"
            >
              <path d="M14.5 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7.5L14.5 2z" />
              <polyline points="14 2 14 8 20 8" />
            </svg>
            Generar Certificados
          </Button>
        </div>
      </div>

      <Tabs defaultValue="certificados" className="space-y-4">
        <TabsList>
          <TabsTrigger value="certificados">Certificados</TabsTrigger>
          <TabsTrigger value="actas">Actas e Informes</TabsTrigger>
          <TabsTrigger value="firmas">Estado de Firmas</TabsTrigger>
        </TabsList>

        <TabsContent value="certificados">
          <Card>
            <CardHeader>
              <CardTitle>Certificados</CardTitle>
              <CardDescription>Lista de certificados generados y su estado de firma</CardDescription>
            </CardHeader>
            <CardContent>
              <div className="flex flex-col md:flex-row gap-4 mb-6">
                <Input placeholder="Buscar por participante o código..." className="max-w-sm" />
                <div className="flex gap-2 ml-auto">
                  <Button variant="outline">
                    <svg
                      xmlns="http://www.w3.org/2000/svg"
                      width="16"
                      height="16"
                      viewBox="0 0 24 24"
                      fill="none"
                      stroke="currentColor"
                      strokeWidth="2"
                      strokeLinecap="round"
                      strokeLinejoin="round"
                      className="mr-2"
                    >
                      <path d="M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4" />
                      <polyline points="7 10 12 15 17 10" />
                      <line x1="12" x2="12" y1="15" y2="3" />
                    </svg>
                    Exportar
                  </Button>
                </div>
              </div>

              <div className="rounded-md border">
                <Table>
                  <TableHeader>
                    <TableRow>
                      <TableHead>Participante</TableHead>
                      <TableHead>Curso</TableHead>
                      <TableHead>Código</TableHead>
                      <TableHead>Calificación</TableHead>
                      <TableHead>Fecha Emisión</TableHead>
                      <TableHead>Estado</TableHead>
                      <TableHead>Acciones</TableHead>
                    </TableRow>
                  </TableHeader>
                  <TableBody>
                    {certificados.map((certificado) => (
                      <TableRow key={certificado.id}>
                        <TableCell className="font-medium">{certificado.participante}</TableCell>
                        <TableCell>{certificado.curso}</TableCell>
                        <TableCell>{certificado.codigo}</TableCell>
                        <TableCell>
                          <Badge variant="outline">{certificado.calificacion}/100</Badge>
                        </TableCell>
                        <TableCell>{certificado.fechaEmision}</TableCell>
                        <TableCell>
                          <Badge className={getEstadoColor(certificado.estado)}>{certificado.estado}</Badge>
                        </TableCell>
                        <TableCell>
                          <div className="flex items-center gap-2">
                            <Button variant="ghost" size="icon">
                              <svg
                                xmlns="http://www.w3.org/2000/svg"
                                width="16"
                                height="16"
                                viewBox="0 0 24 24"
                                fill="none"
                                stroke="currentColor"
                                strokeWidth="2"
                                strokeLinecap="round"
                                strokeLinejoin="round"
                              >
                                <path d="M2 12s3-7 10-7 10 7 10 7-3 7-10 7-10-7-10-7Z" />
                                <circle cx="12" cy="12" r="3" />
                              </svg>
                              <span className="sr-only">Ver</span>
                            </Button>
                            {certificado.estado !== "Completado" && (
                              <Button
                                variant="ghost"
                                size="icon"
                                className="text-red-700"
                                onClick={() => handleFirmar(certificado.id, "certificado")}
                              >
                                <svg
                                  xmlns="http://www.w3.org/2000/svg"
                                  width="16"
                                  height="16"
                                  viewBox="0 0 24 24"
                                  fill="none"
                                  stroke="currentColor"
                                  strokeWidth="2"
                                  strokeLinecap="round"
                                  strokeLinejoin="round"
                                >
                                  <path d="m12 19 7-7 3 3-7 7-3-3z" />
                                  <path d="m18 13-1.5-7.5L2 2l3.5 14.5L13 18l5-5z" />
                                  <path d="m2 2 7.586 7.586" />
                                  <circle cx="11" cy="11" r="2" />
                                </svg>
                                <span className="sr-only">Firmar</span>
                              </Button>
                            )}
                            <Button
                              variant="ghost"
                              size="icon"
                              className="text-blue-700"
                              onClick={() => handleGenerarPDF(certificado.id, "certificado")}
                            >
                              <svg
                                xmlns="http://www.w3.org/2000/svg"
                                width="16"
                                height="16"
                                viewBox="0 0 24 24"
                                fill="none"
                                stroke="currentColor"
                                strokeWidth="2"
                                strokeLinecap="round"
                                strokeLinejoin="round"
                              >
                                <path d="M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4" />
                                <polyline points="7 10 12 15 17 10" />
                                <line x1="12" x2="12" y1="15" y2="3" />
                              </svg>
                              <span className="sr-only">Descargar PDF</span>
                            </Button>
                          </div>
                        </TableCell>
                      </TableRow>
                    ))}
                  </TableBody>
                </Table>
              </div>
            </CardContent>
          </Card>
        </TabsContent>

        <TabsContent value="actas">
          <Card>
            <CardHeader>
              <CardTitle>Actas e Informes</CardTitle>
              <CardDescription>Documentos oficiales generados por curso</CardDescription>
            </CardHeader>
            <CardContent>
              <div className="flex flex-col md:flex-row gap-4 mb-6">
                <Input placeholder="Buscar por curso..." className="max-w-sm" />
                <div className="flex gap-2 ml-auto">
                  <Button variant="outline">
                    <svg
                      xmlns="http://www.w3.org/2000/svg"
                      width="16"
                      height="16"
                      viewBox="0 0 24 24"
                      fill="none"
                      stroke="currentColor"
                      strokeWidth="2"
                      strokeLinecap="round"
                      strokeLinejoin="round"
                      className="mr-2"
                    >
                      <path d="M5 12h14" />
                      <path d="M12 5v14" />
                    </svg>
                    Generar Acta
                  </Button>
                </div>
              </div>

              <div className="rounded-md border">
                <Table>
                  <TableHeader>
                    <TableRow>
                      <TableHead>Curso</TableHead>
                      <TableHead>Tipo de Documento</TableHead>
                      <TableHead>Participantes</TableHead>
                      <TableHead>Fecha Creación</TableHead>
                      <TableHead>Estado</TableHead>
                      <TableHead>Acciones</TableHead>
                    </TableRow>
                  </TableHeader>
                  <TableBody>
                    {actas.map((acta) => (
                      <TableRow key={acta.id}>
                        <TableCell className="font-medium">{acta.curso}</TableCell>
                        <TableCell>{acta.tipo}</TableCell>
                        <TableCell>{acta.participantes}</TableCell>
                        <TableCell>{acta.fechaCreacion}</TableCell>
                        <TableCell>
                          <Badge className={getEstadoColor(acta.estado)}>{acta.estado}</Badge>
                        </TableCell>
                        <TableCell>
                          <div className="flex items-center gap-2">
                            <Button variant="ghost" size="icon">
                              <svg
                                xmlns="http://www.w3.org/2000/svg"
                                width="16"
                                height="16"
                                viewBox="0 0 24 24"
                                fill="none"
                                stroke="currentColor"
                                strokeWidth="2"
                                strokeLinecap="round"
                                strokeLinejoin="round"
                              >
                                <path d="M2 12s3-7 10-7 10 7 10 7-3 7-10 7-10-7-10-7Z" />
                                <circle cx="12" cy="12" r="3" />
                              </svg>
                              <span className="sr-only">Ver</span>
                            </Button>
                            <Button
                              variant="ghost"
                              size="icon"
                              className="text-red-700"
                              onClick={() => handleFirmar(acta.id, "acta")}
                            >
                              <svg
                                xmlns="http://www.w3.org/2000/svg"
                                width="16"
                                height="16"
                                viewBox="0 0 24 24"
                                fill="none"
                                stroke="currentColor"
                                strokeWidth="2"
                                strokeLinecap="round"
                                strokeLinejoin="round"
                              >
                                <path d="m12 19 7-7 3 3-7 7-3-3z" />
                                <path d="m18 13-1.5-7.5L2 2l3.5 14.5L13 18l5-5z" />
                                <path d="m2 2 7.586 7.586" />
                                <circle cx="11" cy="11" r="2" />
                              </svg>
                              <span className="sr-only">Firmar</span>
                            </Button>
                            <Button
                              variant="ghost"
                              size="icon"
                              className="text-blue-700"
                              onClick={() => handleGenerarPDF(acta.id, "acta")}
                            >
                              <svg
                                xmlns="http://www.w3.org/2000/svg"
                                width="16"
                                height="16"
                                viewBox="0 0 24 24"
                                fill="none"
                                stroke="currentColor"
                                strokeWidth="2"
                                strokeLinecap="round"
                                strokeLinejoin="round"
                              >
                                <path d="M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4" />
                                <polyline points="7 10 12 15 17 10" />
                                <line x1="12" x2="12" y1="15" y2="3" />
                              </svg>
                              <span className="sr-only">Descargar PDF</span>
                            </Button>
                          </div>
                        </TableCell>
                      </TableRow>
                    ))}
                  </TableBody>
                </Table>
              </div>
            </CardContent>
          </Card>
        </TabsContent>

        <TabsContent value="firmas">
          <Card>
            <CardHeader>
              <CardTitle>Estado del Flujo de Firmas</CardTitle>
              <CardDescription>Seguimiento del proceso jerárquico de firmas</CardDescription>
            </CardHeader>
            <CardContent>
              <div className="space-y-6">
                {certificados.map((certificado) => (
                  <div key={certificado.id} className="border rounded-lg p-4">
                    <div className="flex justify-between items-start mb-4">
                      <div>
                        <h3 className="font-semibold">{certificado.participante}</h3>
                        <p className="text-sm text-muted-foreground">{certificado.curso}</p>
                        <p className="text-sm text-muted-foreground">Código: {certificado.codigo}</p>
                      </div>
                      <Badge className={getEstadoColor(certificado.estado)}>{certificado.estado}</Badge>
                    </div>

                    <div className="grid grid-cols-1 md:grid-cols-4 gap-4">
                      <div className="flex items-center gap-3">
                        <div
                          className={`w-8 h-8 rounded-full flex items-center justify-center ${
                            certificado.firmas.coordinador ? "bg-green-100" : "bg-gray-100"
                          }`}
                        >
                          {certificado.firmas.coordinador ? (
                            <svg
                              xmlns="http://www.w3.org/2000/svg"
                              width="16"
                              height="16"
                              viewBox="0 0 24 24"
                              fill="none"
                              stroke="currentColor"
                              strokeWidth="2"
                              strokeLinecap="round"
                              strokeLinejoin="round"
                              className="text-green-600"
                            >
                              <polyline points="20 6 9 17 4 12" />
                            </svg>
                          ) : (
                            <span className="text-gray-400 text-sm">1</span>
                          )}
                        </div>
                        <div>
                          <p className="text-sm font-medium">Coordinador</p>
                          <p className="text-xs text-muted-foreground">
                            {certificado.firmas.coordinador ? "Firmado" : "Pendiente"}
                          </p>
                        </div>
                      </div>

                      <div className="flex items-center gap-3">
                        <div
                          className={`w-8 h-8 rounded-full flex items-center justify-center ${
                            certificado.firmas.directorEscuela ? "bg-green-100" : "bg-gray-100"
                          }`}
                        >
                          {certificado.firmas.directorEscuela ? (
                            <svg
                              xmlns="http://www.w3.org/2000/svg"
                              width="16"
                              height="16"
                              viewBox="0 0 24 24"
                              fill="none"
                              stroke="currentColor"
                              strokeWidth="2"
                              strokeLinecap="round"
                              strokeLinejoin="round"
                              className="text-green-600"
                            >
                              <polyline points="20 6 9 17 4 12" />
                            </svg>
                          ) : (
                            <span className="text-gray-400 text-sm">2</span>
                          )}
                        </div>
                        <div>
                          <p className="text-sm font-medium">Director Escuela</p>
                          <p className="text-xs text-muted-foreground">
                            {certificado.firmas.directorEscuela ? "Firmado" : "Pendiente"}
                          </p>
                        </div>
                      </div>

                      <div className="flex items-center gap-3">
                        <div
                          className={`w-8 h-8 rounded-full flex items-center justify-center ${
                            certificado.firmas.educacionDNBC ? "bg-green-100" : "bg-gray-100"
                          }`}
                        >
                          {certificado.firmas.educacionDNBC ? (
                            <svg
                              xmlns="http://www.w3.org/2000/svg"
                              width="16"
                              height="16"
                              viewBox="0 0 24 24"
                              fill="none"
                              stroke="currentColor"
                              strokeWidth="2"
                              strokeLinecap="round"
                              strokeLinejoin="round"
                              className="text-green-600"
                            >
                              <polyline points="20 6 9 17 4 12" />
                            </svg>
                          ) : (
                            <span className="text-gray-400 text-sm">3</span>
                          )}
                        </div>
                        <div>
                          <p className="text-sm font-medium">Educación DNBC</p>
                          <p className="text-xs text-muted-foreground">
                            {certificado.firmas.educacionDNBC ? "Aprobado" : "Pendiente"}
                          </p>
                        </div>
                      </div>

                      <div className="flex items-center gap-3">
                        <div
                          className={`w-8 h-8 rounded-full flex items-center justify-center ${
                            certificado.firmas.directorNacional ? "bg-green-100" : "bg-gray-100"
                          }`}
                        >
                          {certificado.firmas.directorNacional ? (
                            <svg
                              xmlns="http://www.w3.org/2000/svg"
                              width="16"
                              height="16"
                              viewBox="0 0 24 24"
                              fill="none"
                              stroke="currentColor"
                              strokeWidth="2"
                              strokeLinecap="round"
                              strokeLinejoin="round"
                              className="text-green-600"
                            >
                              <polyline points="20 6 9 17 4 12" />
                            </svg>
                          ) : (
                            <span className="text-gray-400 text-sm">4</span>
                          )}
                        </div>
                        <div>
                          <p className="text-sm font-medium">Director Nacional</p>
                          <p className="text-xs text-muted-foreground">
                            {certificado.firmas.directorNacional ? "Firmado" : "Pendiente"}
                          </p>
                        </div>
                      </div>
                    </div>
                  </div>
                ))}
              </div>
            </CardContent>
          </Card>
        </TabsContent>
      </Tabs>
    </div>
  )
}
