"use client"

import type React from "react"

import { useState } from "react"
import { useRouter } from "next/navigation"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Input } from "@/components/ui/input"
import { Label } from "@/components/ui/label"
import { Textarea } from "@/components/ui/textarea"
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select"
import { useToast } from "@/components/ui/use-toast"

export default function CrearCursoPage() {
  const router = useRouter()
  const { toast } = useToast()

  const [formData, setFormData] = useState({
    nombre: "",
    codigo: "",
    descripcion: "",
    coordinador: "",
    numeroRegistro: "",
    fechaInicio: "",
    fechaFin: "",
    duracionHoras: "",
    modalidad: "",
    contenidoTematico: "",
    objetivos: "",
    metodologia: "",
    evaluacion: "",
    requisitos: "",
  })

  const coordinadores = [
    { id: 1, nombre: "Carlos Martínez" },
    { id: 2, nombre: "Laura Gómez" },
    { id: 3, nombre: "Andrés López" },
    { id: 4, nombre: "María Rodríguez" },
    { id: 5, nombre: "Juan Pérez" },
  ]

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault()

    // Simulación de creación del curso
    toast({
      title: "Curso creado exitosamente",
      description: `El curso "${formData.nombre}" ha sido registrado en el sistema.`,
    })

    // Redirigir a la lista de cursos
    router.push("/dashboard/cursos")
  }

  return (
    <div className="space-y-6">
      <div className="flex items-center gap-4">
        <Button variant="ghost" onClick={() => router.back()}>
          <svg
            xmlns="http://www.w3.org/2000/svg"
            width="16"
            height="16"
            viewBox="0 0 24 24"
            fill="none"
            stroke="currentColor"
            strokeWidth="2"
            strokeLinecap="round"
            strokeLinejoin="round"
            className="mr-2"
          >
            <path d="m12 19-7-7 7-7" />
            <path d="M19 12H5" />
          </svg>
          Volver
        </Button>
        <div>
          <h1 className="text-3xl font-bold tracking-tight">Crear Nuevo Curso</h1>
          <p className="text-muted-foreground">Complete la información del curso de formación</p>
        </div>
      </div>

      <form onSubmit={handleSubmit} className="space-y-6">
        <Card>
          <CardHeader>
            <CardTitle>Información Básica</CardTitle>
            <CardDescription>Datos principales del curso</CardDescription>
          </CardHeader>
          <CardContent className="space-y-4">
            <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
              <div>
                <Label htmlFor="nombre">Nombre del Curso *</Label>
                <Input
                  id="nombre"
                  value={formData.nombre}
                  onChange={(e) => setFormData({ ...formData, nombre: e.target.value })}
                  placeholder="Ej: Técnicas de Rescate en Estructuras Colapsadas"
                  required
                />
              </div>
              <div>
                <Label htmlFor="codigo">Código del Curso *</Label>
                <Input
                  id="codigo"
                  value={formData.codigo}
                  onChange={(e) => setFormData({ ...formData, codigo: e.target.value })}
                  placeholder="Ej: TREC-2023-01"
                  required
                />
              </div>
            </div>

            <div>
              <Label htmlFor="descripcion">Descripción</Label>
              <Textarea
                id="descripcion"
                value={formData.descripcion}
                onChange={(e) => setFormData({ ...formData, descripcion: e.target.value })}
                placeholder="Descripción general del curso..."
                rows={3}
              />
            </div>

            <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
              <div>
                <Label htmlFor="coordinador">Coordinador *</Label>
                <Select
                  value={formData.coordinador}
                  onValueChange={(value) => setFormData({ ...formData, coordinador: value })}
                >
                  <SelectTrigger>
                    <SelectValue placeholder="Seleccionar coordinador" />
                  </SelectTrigger>
                  <SelectContent>
                    {coordinadores.map((coordinador) => (
                      <SelectItem key={coordinador.id} value={coordinador.nombre}>
                        {coordinador.nombre}
                      </SelectItem>
                    ))}
                  </SelectContent>
                </Select>
              </div>
              <div>
                <Label htmlFor="numeroRegistro">Número de Registro *</Label>
                <Input
                  id="numeroRegistro"
                  value={formData.numeroRegistro}
                  onChange={(e) => setFormData({ ...formData, numeroRegistro: e.target.value })}
                  placeholder="Ej: REG-2023-001"
                  required
                />
              </div>
            </div>
          </CardContent>
        </Card>

        <Card>
          <CardHeader>
            <CardTitle>Programación</CardTitle>
            <CardDescription>Fechas y duración del curso</CardDescription>
          </CardHeader>
          <CardContent className="space-y-4">
            <div className="grid grid-cols-1 md:grid-cols-3 gap-4">
              <div>
                <Label htmlFor="fechaInicio">Fecha de Inicio *</Label>
                <Input
                  id="fechaInicio"
                  type="date"
                  value={formData.fechaInicio}
                  onChange={(e) => setFormData({ ...formData, fechaInicio: e.target.value })}
                  required
                />
              </div>
              <div>
                <Label htmlFor="fechaFin">Fecha de Finalización *</Label>
                <Input
                  id="fechaFin"
                  type="date"
                  value={formData.fechaFin}
                  onChange={(e) => setFormData({ ...formData, fechaFin: e.target.value })}
                  required
                />
              </div>
              <div>
                <Label htmlFor="duracionHoras">Duración (Horas) *</Label>
                <Input
                  id="duracionHoras"
                  type="number"
                  value={formData.duracionHoras}
                  onChange={(e) => setFormData({ ...formData, duracionHoras: e.target.value })}
                  placeholder="40"
                  required
                />
              </div>
            </div>

            <div>
              <Label htmlFor="modalidad">Modalidad *</Label>
              <Select
                value={formData.modalidad}
                onValueChange={(value) => setFormData({ ...formData, modalidad: value })}
              >
                <SelectTrigger>
                  <SelectValue placeholder="Seleccionar modalidad" />
                </SelectTrigger>
                <SelectContent>
                  <SelectItem value="presencial">Presencial</SelectItem>
                  <SelectItem value="virtual">Virtual</SelectItem>
                  <SelectItem value="mixta">Mixta</SelectItem>
                </SelectContent>
              </Select>
            </div>
          </CardContent>
        </Card>

        <Card>
          <CardHeader>
            <CardTitle>Contenido Académico</CardTitle>
            <CardDescription>Información detallada del contenido del curso</CardDescription>
          </CardHeader>
          <CardContent className="space-y-4">
            <div>
              <Label htmlFor="contenidoTematico">Contenido Temático *</Label>
              <Textarea
                id="contenidoTematico"
                value={formData.contenidoTematico}
                onChange={(e) => setFormData({ ...formData, contenidoTematico: e.target.value })}
                placeholder="Detalle los temas que se abordarán en el curso..."
                rows={4}
                required
              />
            </div>

            <div>
              <Label htmlFor="objetivos">Objetivos</Label>
              <Textarea
                id="objetivos"
                value={formData.objetivos}
                onChange={(e) => setFormData({ ...formData, objetivos: e.target.value })}
                placeholder="Objetivos generales y específicos del curso..."
                rows={3}
              />
            </div>

            <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
              <div>
                <Label htmlFor="metodologia">Metodología</Label>
                <Textarea
                  id="metodologia"
                  value={formData.metodologia}
                  onChange={(e) => setFormData({ ...formData, metodologia: e.target.value })}
                  placeholder="Metodología de enseñanza..."
                  rows={3}
                />
              </div>
              <div>
                <Label htmlFor="evaluacion">Sistema de Evaluación</Label>
                <Textarea
                  id="evaluacion"
                  value={formData.evaluacion}
                  onChange={(e) => setFormData({ ...formData, evaluacion: e.target.value })}
                  placeholder="Criterios y métodos de evaluación..."
                  rows={3}
                />
              </div>
            </div>

            <div>
              <Label htmlFor="requisitos">Requisitos de Ingreso</Label>
              <Textarea
                id="requisitos"
                value={formData.requisitos}
                onChange={(e) => setFormData({ ...formData, requisitos: e.target.value })}
                placeholder="Requisitos que deben cumplir los participantes..."
                rows={2}
              />
            </div>
          </CardContent>
        </Card>

        <div className="flex justify-end gap-4">
          <Button type="button" variant="outline" onClick={() => router.back()}>
            Cancelar
          </Button>
          <Button type="submit" className="bg-red-700 hover:bg-red-800">
            Crear Curso
          </Button>
        </div>
      </form>
    </div>
  )
}
