import Link from "next/link"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Input } from "@/components/ui/input"
import { Table, TableBody, TableCell, TableHead, TableHeader, TableRow } from "@/components/ui/table"
import { Badge } from "@/components/ui/badge"

export default function CursosPage() {
  // Datos de ejemplo - en una implementación real vendrían del backend
  const cursos = [
    {
      id: 1,
      nombre: "Técnicas de Rescate en Estructuras Colapsadas",
      codigo: "TREC-2023-01",
      coordinador: "Carlos Martínez",
      fechaInicio: "15/05/2023",
      fechaFin: "30/06/2023",
      participantes: 24,
      estado: "En curso",
    },
    {
      id: 2,
      nombre: "Primeros Auxilios Avanzados",
      codigo: "PAA-2023-02",
      coordinador: "Laura Gómez",
      fechaInicio: "02/06/2023",
      fechaFin: "15/06/2023",
      participantes: 18,
      estado: "Finalizado",
    },
    {
      id: 3,
      nombre: "Manejo de Materiales Peligrosos",
      codigo: "MMP-2023-03",
      coordinador: "Andrés López",
      fechaInicio: "10/06/2023",
      fechaFin: "25/07/2023",
      participantes: 15,
      estado: "En curso",
    },
    {
      id: 4,
      nombre: "Técnicas de Extinción de Incendios",
      codigo: "TEI-2023-04",
      coordinador: "María Rodríguez",
      fechaInicio: "20/06/2023",
      fechaFin: "30/07/2023",
      participantes: 22,
      estado: "Programado",
    },
    {
      id: 5,
      nombre: "Rescate Acuático",
      codigo: "RA-2023-05",
      coordinador: "Juan Pérez",
      fechaInicio: "05/07/2023",
      fechaFin: "20/08/2023",
      participantes: 12,
      estado: "Programado",
    },
  ]

  return (
    <div className="space-y-6">
      <div className="flex flex-col md:flex-row md:items-center md:justify-between gap-4">
        <div>
          <h1 className="text-3xl font-bold tracking-tight">Gestión de Cursos</h1>
          <p className="text-muted-foreground">Administre los cursos de formación para bomberos</p>
        </div>
        <Button className="bg-red-700 hover:bg-red-800">
          <svg
            xmlns="http://www.w3.org/2000/svg"
            width="16"
            height="16"
            viewBox="0 0 24 24"
            fill="none"
            stroke="currentColor"
            strokeWidth="2"
            strokeLinecap="round"
            strokeLinejoin="round"
            className="mr-2"
          >
            <path d="M5 12h14" />
            <path d="M12 5v14" />
          </svg>
          Crear Curso
        </Button>
      </div>

      <Card>
        <CardHeader>
          <CardTitle>Cursos</CardTitle>
          <CardDescription>Lista de todos los cursos registrados en el sistema</CardDescription>
        </CardHeader>
        <CardContent>
          <div className="flex flex-col md:flex-row gap-4 mb-6">
            <Input placeholder="Buscar curso..." className="max-w-sm" />
            <div className="flex gap-2 ml-auto">
              <Button variant="outline">
                <svg
                  xmlns="http://www.w3.org/2000/svg"
                  width="16"
                  height="16"
                  viewBox="0 0 24 24"
                  fill="none"
                  stroke="currentColor"
                  strokeWidth="2"
                  strokeLinecap="round"
                  strokeLinejoin="round"
                  className="mr-2"
                >
                  <path d="M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4" />
                  <polyline points="7 10 12 15 17 10" />
                  <line x1="12" x2="12" y1="15" y2="3" />
                </svg>
                Exportar
              </Button>
              <Button variant="outline">
                <svg
                  xmlns="http://www.w3.org/2000/svg"
                  width="16"
                  height="16"
                  viewBox="0 0 24 24"
                  fill="none"
                  stroke="currentColor"
                  strokeWidth="2"
                  strokeLinecap="round"
                  strokeLinejoin="round"
                  className="mr-2"
                >
                  <path d="M3 3v18h18" />
                  <path d="m19 9-5 5-4-4-3 3" />
                </svg>
                Reportes
              </Button>
            </div>
          </div>

          <div className="rounded-md border">
            <Table>
              <TableHeader>
                <TableRow>
                  <TableHead>Nombre del Curso</TableHead>
                  <TableHead>Código</TableHead>
                  <TableHead>Coordinador</TableHead>
                  <TableHead>Fecha Inicio</TableHead>
                  <TableHead>Fecha Fin</TableHead>
                  <TableHead>Participantes</TableHead>
                  <TableHead>Estado</TableHead>
                  <TableHead>Acciones</TableHead>
                </TableRow>
              </TableHeader>
              <TableBody>
                {cursos.map((curso) => (
                  <TableRow key={curso.id}>
                    <TableCell className="font-medium">{curso.nombre}</TableCell>
                    <TableCell>{curso.codigo}</TableCell>
                    <TableCell>{curso.coordinador}</TableCell>
                    <TableCell>{curso.fechaInicio}</TableCell>
                    <TableCell>{curso.fechaFin}</TableCell>
                    <TableCell>{curso.participantes}</TableCell>
                    <TableCell>
                      <Badge
                        className={
                          curso.estado === "En curso"
                            ? "bg-blue-100 text-blue-700 hover:bg-blue-100"
                            : curso.estado === "Finalizado"
                              ? "bg-green-100 text-green-700 hover:bg-green-100"
                              : "bg-yellow-100 text-yellow-700 hover:bg-yellow-100"
                        }
                      >
                        {curso.estado}
                      </Badge>
                    </TableCell>
                    <TableCell>
                      <div className="flex items-center gap-2">
                        <Button variant="ghost" size="icon" asChild>
                          <Link href={`/dashboard/cursos/${curso.id}`}>
                            <svg
                              xmlns="http://www.w3.org/2000/svg"
                              width="16"
                              height="16"
                              viewBox="0 0 24 24"
                              fill="none"
                              stroke="currentColor"
                              strokeWidth="2"
                              strokeLinecap="round"
                              strokeLinejoin="round"
                            >
                              <path d="M2 12s3-7 10-7 10 7 10 7-3 7-10 7-10-7-10-7Z" />
                              <circle cx="12" cy="12" r="3" />
                            </svg>
                            <span className="sr-only">Ver</span>
                          </Link>
                        </Button>
                        <Button variant="ghost" size="icon" asChild>
                          <Link href={`/dashboard/cursos/${curso.id}/editar`}>
                            <svg
                              xmlns="http://www.w3.org/2000/svg"
                              width="16"
                              height="16"
                              viewBox="0 0 24 24"
                              fill="none"
                              stroke="currentColor"
                              strokeWidth="2"
                              strokeLinecap="round"
                              strokeLinejoin="round"
                            >
                              <path d="M17 3a2.85 2.83 0 1 1 4 4L7.5 20.5 2 22l1.5-5.5Z" />
                              <path d="m15 5 4 4" />
                            </svg>
                            <span className="sr-only">Editar</span>
                          </Link>
                        </Button>
                        <Button variant="ghost" size="icon" className="text-red-700">
                          <svg
                            xmlns="http://www.w3.org/2000/svg"
                            width="16"
                            height="16"
                            viewBox="0 0 24 24"
                            fill="none"
                            stroke="currentColor"
                            strokeWidth="2"
                            strokeLinecap="round"
                            strokeLinejoin="round"
                          >
                            <path d="M3 6h18" />
                            <path d="M19 6v14c0 1-1 2-2 2H7c-1 0-2-1-2-2V6" />
                            <path d="M8 6V4c0-1 1-2 2-2h4c0 1 1 2 2 2v2" />
                          </svg>
                          <span className="sr-only">Eliminar</span>
                        </Button>
                      </div>
                    </TableCell>
                  </TableRow>
                ))}
              </TableBody>
            </Table>
          </div>
        </CardContent>
      </Card>
    </div>
  )
}
