"use client"

import { useState } from "react"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Input } from "@/components/ui/input"
import { Table, TableBody, TableCell, TableHead, TableHeader, TableRow } from "@/components/ui/table"
import { Badge } from "@/components/ui/badge"
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select"
import {
  Dialog,
  DialogContent,
  DialogDescription,
  DialogFooter,
  DialogHeader,
  DialogTitle,
  DialogTrigger,
} from "@/components/ui/dialog"
import { Checkbox } from "@/components/ui/checkbox"
import { useToast } from "@/components/ui/use-toast"

export default function MatriculaPage() {
  const { toast } = useToast()

  const [cursoSeleccionado, setCursoSeleccionado] = useState("")
  const [isDialogOpen, setIsDialogOpen] = useState(false)
  const [participantesSeleccionados, setParticipantesSeleccionados] = useState<string[]>([])

  const cursos = [
    {
      id: "1",
      nombre: "Técnicas de Rescate en Estructuras Colapsadas",
      fechaInicio: "2023-07-15",
      cupos: 30,
      matriculados: 24,
    },
    { id: "2", nombre: "Primeros Auxilios Avanzados", fechaInicio: "2023-08-10", cupos: 25, matriculados: 18 },
    { id: "3", nombre: "Manejo de Materiales Peligrosos", fechaInicio: "2023-09-05", cupos: 20, matriculados: 15 },
  ]

  const participantes = [
    { id: "1", nombre: "Carlos Andrés Pérez", cedula: "12345678", institucion: "Bomberos Bogotá" },
    { id: "2", nombre: "María Elena Rodríguez", cedula: "87654321", institucion: "Bomberos Medellín" },
    { id: "3", nombre: "Juan Carlos Martínez", cedula: "11223344", institucion: "Bomberos Cali" },
    { id: "4", nombre: "Ana Sofía López", cedula: "55667788", institucion: "Bomberos Barranquilla" },
    { id: "5", nombre: "Pedro José Ramírez", cedula: "99887766", institucion: "Bomberos Cartagena" },
  ]

  const [matriculados, setMatriculados] = useState([
    { id: "1", participanteId: "1", cursoId: "1", fechaMatricula: "2023-06-10", estado: "Activo" },
    { id: "2", participanteId: "2", cursoId: "1", fechaMatricula: "2023-06-12", estado: "Activo" },
    { id: "3", participanteId: "3", cursoId: "2", fechaMatricula: "2023-07-05", estado: "Activo" },
  ])

  const handleMatricular = () => {
    if (participantesSeleccionados.length === 0) {
      toast({
        title: "Error",
        description: "Debe seleccionar al menos un participante.",
        variant: "destructive",
      })
      return
    }

    const nuevasMatriculas = participantesSeleccionados.map((participanteId) => ({
      id: `${matriculados.length + 1}`,
      participanteId,
      cursoId: cursoSeleccionado,
      fechaMatricula: new Date().toISOString().split("T")[0],
      estado: "Activo",
    }))

    setMatriculados([...matriculados, ...nuevasMatriculas])
    setIsDialogOpen(false)
    setParticipantesSeleccionados([])

    toast({
      title: "Matrícula exitosa",
      description: `Se han matriculado ${nuevasMatriculas.length} participantes al curso.`,
    })
  }

  const handleToggleParticipante = (participanteId: string) => {
    setParticipantesSeleccionados((prev) =>
      prev.includes(participanteId) ? prev.filter((id) => id !== participanteId) : [...prev, participanteId],
    )
  }

  const getParticipanteById = (id: string) => {
    return participantes.find((p) => p.id === id)
  }

  const getCursoById = (id: string) => {
    return cursos.find((c) => c.id === id)
  }

  const getMatriculadosPorCurso = (cursoId: string) => {
    return matriculados.filter((m) => m.cursoId === cursoId)
  }

  const handleCancelarMatricula = (matriculaId: string) => {
    setMatriculados(matriculados.map((m) => (m.id === matriculaId ? { ...m, estado: "Cancelado" } : m)))

    toast({
      title: "Matrícula cancelada",
      description: "La matrícula ha sido cancelada exitosamente.",
    })
  }

  return (
    <div className="space-y-6">
      <div className="flex flex-col md:flex-row md:items-center md:justify-between gap-4">
        <div>
          <h1 className="text-3xl font-bold tracking-tight">Matrícula de Participantes</h1>
          <p className="text-muted-foreground">Gestione la matrícula de participantes en los cursos</p>
        </div>
      </div>

      <Card>
        <CardHeader>
          <CardTitle>Seleccionar Curso</CardTitle>
          <CardDescription>Elija el curso para gestionar las matrículas</CardDescription>
        </CardHeader>
        <CardContent>
          <div className="flex flex-col md:flex-row gap-4">
            <Select value={cursoSeleccionado} onValueChange={setCursoSeleccionado} className="flex-1">
              <SelectTrigger>
                <SelectValue placeholder="Seleccionar curso" />
              </SelectTrigger>
              <SelectContent>
                {cursos.map((curso) => (
                  <SelectItem key={curso.id} value={curso.id}>
                    {curso.nombre}
                  </SelectItem>
                ))}
              </SelectContent>
            </Select>

            <Dialog open={isDialogOpen} onOpenChange={setIsDialogOpen}>
              <DialogTrigger asChild>
                <Button className="bg-red-700 hover:bg-red-800" disabled={!cursoSeleccionado}>
                  <svg
                    xmlns="http://www.w3.org/2000/svg"
                    width="16"
                    height="16"
                    viewBox="0 0 24 24"
                    fill="none"
                    stroke="currentColor"
                    strokeWidth="2"
                    strokeLinecap="round"
                    strokeLinejoin="round"
                    className="mr-2"
                  >
                    <path d="M5 12h14" />
                    <path d="M12 5v14" />
                  </svg>
                  Matricular Participantes
                </Button>
              </DialogTrigger>
              <DialogContent className="max-w-3xl">
                <DialogHeader>
                  <DialogTitle>Matricular Participantes</DialogTitle>
                  <DialogDescription>Seleccione los participantes que desea matricular en el curso</DialogDescription>
                </DialogHeader>
                <div className="space-y-4">
                  <div className="flex items-center justify-between">
                    <div>
                      <h3 className="font-medium">Curso: {getCursoById(cursoSeleccionado)?.nombre}</h3>
                      <p className="text-sm text-muted-foreground">
                        Fecha de inicio: {getCursoById(cursoSeleccionado)?.fechaInicio}
                      </p>
                    </div>
                    <div className="text-right">
                      <p className="text-sm">
                        Cupos disponibles:{" "}
                        {(getCursoById(cursoSeleccionado)?.cupos || 0) -
                          (getCursoById(cursoSeleccionado)?.matriculados || 0)}
                      </p>
                      <p className="text-sm text-muted-foreground">
                        Total de cupos: {getCursoById(cursoSeleccionado)?.cupos}
                      </p>
                    </div>
                  </div>

                  <Input placeholder="Buscar participante..." className="mb-4" />

                  <div className="border rounded-md">
                    <Table>
                      <TableHeader>
                        <TableRow>
                          <TableHead className="w-12"></TableHead>
                          <TableHead>Nombre</TableHead>
                          <TableHead>Cédula</TableHead>
                          <TableHead>Institución</TableHead>
                        </TableRow>
                      </TableHeader>
                      <TableBody>
                        {participantes
                          .filter(
                            (p) =>
                              !matriculados.some(
                                (m) =>
                                  m.participanteId === p.id && m.cursoId === cursoSeleccionado && m.estado === "Activo",
                              ),
                          )
                          .map((participante) => (
                            <TableRow key={participante.id}>
                              <TableCell>
                                <Checkbox
                                  checked={participantesSeleccionados.includes(participante.id)}
                                  onCheckedChange={() => handleToggleParticipante(participante.id)}
                                />
                              </TableCell>
                              <TableCell className="font-medium">{participante.nombre}</TableCell>
                              <TableCell>{participante.cedula}</TableCell>
                              <TableCell>{participante.institucion}</TableCell>
                            </TableRow>
                          ))}
                      </TableBody>
                    </Table>
                  </div>

                  <div className="flex items-center justify-between">
                    <p className="text-sm">{participantesSeleccionados.length} participantes seleccionados</p>
                  </div>
                </div>
                <DialogFooter>
                  <Button variant="outline" onClick={() => setIsDialogOpen(false)}>
                    Cancelar
                  </Button>
                  <Button onClick={handleMatricular} className="bg-red-700 hover:bg-red-800">
                    Matricular Participantes
                  </Button>
                </DialogFooter>
              </DialogContent>
            </Dialog>
          </div>
        </CardContent>
      </Card>

      {cursoSeleccionado && (
        <Card>
          <CardHeader>
            <CardTitle>Participantes Matriculados</CardTitle>
            <CardDescription>
              Lista de participantes matriculados en {getCursoById(cursoSeleccionado)?.nombre}
            </CardDescription>
          </CardHeader>
          <CardContent>
            <div className="flex flex-col md:flex-row gap-4 mb-6">
              <Input placeholder="Buscar participante..." className="max-w-sm" />
              <div className="flex gap-2 ml-auto">
                <Button variant="outline">
                  <svg
                    xmlns="http://www.w3.org/2000/svg"
                    width="16"
                    height="16"
                    viewBox="0 0 24 24"
                    fill="none"
                    stroke="currentColor"
                    strokeWidth="2"
                    strokeLinecap="round"
                    strokeLinejoin="round"
                    className="mr-2"
                  >
                    <path d="M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4" />
                    <polyline points="7 10 12 15 17 10" />
                    <line x1="12" x2="12" y1="15" y2="3" />
                  </svg>
                  Exportar Lista
                </Button>
              </div>
            </div>

            <div className="rounded-md border">
              <Table>
                <TableHeader>
                  <TableRow>
                    <TableHead>Participante</TableHead>
                    <TableHead>Cédula</TableHead>
                    <TableHead>Institución</TableHead>
                    <TableHead>Fecha Matrícula</TableHead>
                    <TableHead>Estado</TableHead>
                    <TableHead>Acciones</TableHead>
                  </TableRow>
                </TableHeader>
                <TableBody>
                  {getMatriculadosPorCurso(cursoSeleccionado).map((matricula) => {
                    const participante = getParticipanteById(matricula.participanteId)
                    if (!participante) return null

                    return (
                      <TableRow key={matricula.id}>
                        <TableCell className="font-medium">{participante.nombre}</TableCell>
                        <TableCell>{participante.cedula}</TableCell>
                        <TableCell>{participante.institucion}</TableCell>
                        <TableCell>{matricula.fechaMatricula}</TableCell>
                        <TableCell>
                          <Badge
                            className={
                              matricula.estado === "Activo"
                                ? "bg-green-100 text-green-700 hover:bg-green-100"
                                : "bg-red-100 text-red-700 hover:bg-red-100"
                            }
                          >
                            {matricula.estado}
                          </Badge>
                        </TableCell>
                        <TableCell>
                          <div className="flex items-center gap-2">
                            {matricula.estado === "Activo" && (
                              <Button
                                variant="ghost"
                                size="icon"
                                className="text-red-700"
                                onClick={() => handleCancelarMatricula(matricula.id)}
                              >
                                <svg
                                  xmlns="http://www.w3.org/2000/svg"
                                  width="16"
                                  height="16"
                                  viewBox="0 0 24 24"
                                  fill="none"
                                  stroke="currentColor"
                                  strokeWidth="2"
                                  strokeLinecap="round"
                                  strokeLinejoin="round"
                                >
                                  <path d="M18 6 6 18" />
                                  <path d="m6 6 12 12" />
                                </svg>
                                <span className="sr-only">Cancelar matrícula</span>
                              </Button>
                            )}
                            <Button variant="ghost" size="icon">
                              <svg
                                xmlns="http://www.w3.org/2000/svg"
                                width="16"
                                height="16"
                                viewBox="0 0 24 24"
                                fill="none"
                                stroke="currentColor"
                                strokeWidth="2"
                                strokeLinecap="round"
                                strokeLinejoin="round"
                              >
                                <path d="M14.5 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7.5L14.5 2z" />
                                <polyline points="14 2 14 8 20 8" />
                              </svg>
                              <span className="sr-only">Ver detalles</span>
                            </Button>
                          </div>
                        </TableCell>
                      </TableRow>
                    )
                  })}
                </TableBody>
              </Table>
            </div>

            <div className="mt-6 grid grid-cols-1 md:grid-cols-3 gap-4">
              <Card>
                <CardContent className="p-4">
                  <div className="text-2xl font-bold text-blue-600">
                    {getMatriculadosPorCurso(cursoSeleccionado).filter((m) => m.estado === "Activo").length}
                  </div>
                  <p className="text-sm text-muted-foreground">Participantes Activos</p>
                </CardContent>
              </Card>
              <Card>
                <CardContent className="p-4">
                  <div className="text-2xl font-bold text-red-600">
                    {getMatriculadosPorCurso(cursoSeleccionado).filter((m) => m.estado === "Cancelado").length}
                  </div>
                  <p className="text-sm text-muted-foreground">Matrículas Canceladas</p>
                </CardContent>
              </Card>
              <Card>
                <CardContent className="p-4">
                  <div className="text-2xl font-bold text-green-600">
                    {(getCursoById(cursoSeleccionado)?.cupos || 0) -
                      getMatriculadosPorCurso(cursoSeleccionado).filter((m) => m.estado === "Activo").length}
                  </div>
                  <p className="text-sm text-muted-foreground">Cupos Disponibles</p>
                </CardContent>
              </Card>
            </div>
          </CardContent>
        </Card>
      )}
    </div>
  )
}
