import Link from "next/link"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Button } from "@/components/ui/button"

export default function Dashboard() {
  return (
    <div className="space-y-6">
      <div className="flex flex-col md:flex-row md:items-center md:justify-between gap-4">
        <div>
          <h1 className="text-3xl font-bold tracking-tight">Panel de Control</h1>
          <p className="text-muted-foreground">Bienvenido al sistema de gestión de certificados para bomberos.</p>
        </div>
        <Button className="bg-red-700 hover:bg-red-800">
          <svg
            xmlns="http://www.w3.org/2000/svg"
            width="16"
            height="16"
            viewBox="0 0 24 24"
            fill="none"
            stroke="currentColor"
            strokeWidth="2"
            strokeLinecap="round"
            strokeLinejoin="round"
            className="mr-2"
          >
            <path d="M11 12H3" />
            <path d="m16 7 5 5-5 5" />
            <path d="M21 12H11" />
            <path d="M3 3v18" />
          </svg>
          Nuevo Curso
        </Button>
      </div>

      <div className="grid gap-4 md:grid-cols-2 lg:grid-cols-4">
        <Card>
          <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
            <CardTitle className="text-sm font-medium">Cursos Activos</CardTitle>
            <svg
              xmlns="http://www.w3.org/2000/svg"
              width="16"
              height="16"
              viewBox="0 0 24 24"
              fill="none"
              stroke="currentColor"
              strokeWidth="2"
              strokeLinecap="round"
              strokeLinejoin="round"
              className="text-red-700"
            >
              <path d="M2 3h6a4 4 0 0 1 4 4v14a3 3 0 0 0-3-3H2z" />
              <path d="M22 3h-6a4 4 0 0 0-4 4v14a3 3 0 0 1 3-3h7z" />
            </svg>
          </CardHeader>
          <CardContent>
            <div className="text-2xl font-bold">12</div>
            <p className="text-xs text-muted-foreground">+2 desde el mes pasado</p>
          </CardContent>
        </Card>
        <Card>
          <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
            <CardTitle className="text-sm font-medium">Participantes</CardTitle>
            <svg
              xmlns="http://www.w3.org/2000/svg"
              width="16"
              height="16"
              viewBox="0 0 24 24"
              fill="none"
              stroke="currentColor"
              strokeWidth="2"
              strokeLinecap="round"
              strokeLinejoin="round"
              className="text-red-700"
            >
              <path d="M16 21v-2a4 4 0 0 0-4-4H6a4 4 0 0 0-4 4v2" />
              <circle cx="9" cy="7" r="4" />
              <path d="M22 21v-2a4 4 0 0 0-3-3.87" />
              <path d="M16 3.13a4 4 0 0 1 0 7.75" />
            </svg>
          </CardHeader>
          <CardContent>
            <div className="text-2xl font-bold">245</div>
            <p className="text-xs text-muted-foreground">+18 desde el mes pasado</p>
          </CardContent>
        </Card>
        <Card>
          <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
            <CardTitle className="text-sm font-medium">Certificados Emitidos</CardTitle>
            <svg
              xmlns="http://www.w3.org/2000/svg"
              width="16"
              height="16"
              viewBox="0 0 24 24"
              fill="none"
              stroke="currentColor"
              strokeWidth="2"
              strokeLinecap="round"
              strokeLinejoin="round"
              className="text-red-700"
            >
              <path d="M12 22a5 5 0 0 1-3-9" />
              <path d="M11 1 3 9a2 2 0 0 0 0 2.83L13 21.9a2 2 0 0 0 2.83 0l8-8a2 2 0 0 0 0-2.83L15 3" />
              <circle cx="6.5" cy="6.5" r="1.5" />
            </svg>
          </CardHeader>
          <CardContent>
            <div className="text-2xl font-bold">189</div>
            <p className="text-xs text-muted-foreground">+32 desde el mes pasado</p>
          </CardContent>
        </Card>
        <Card>
          <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
            <CardTitle className="text-sm font-medium">Pendientes de Firma</CardTitle>
            <svg
              xmlns="http://www.w3.org/2000/svg"
              width="16"
              height="16"
              viewBox="0 0 24 24"
              fill="none"
              stroke="currentColor"
              strokeWidth="2"
              strokeLinecap="round"
              strokeLinejoin="round"
              className="text-red-700"
            >
              <path d="M14.5 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7.5L14.5 2z" />
              <polyline points="14 2 14 8 20 8" />
              <path d="M16 13v4" />
              <path d="M8 13v4" />
              <path d="M12 15v2" />
            </svg>
          </CardHeader>
          <CardContent>
            <div className="text-2xl font-bold">8</div>
            <p className="text-xs text-muted-foreground">-3 desde el mes pasado</p>
          </CardContent>
        </Card>
      </div>

      <div className="grid gap-4 md:grid-cols-2 lg:grid-cols-7">
        <Card className="col-span-4">
          <CardHeader>
            <CardTitle>Cursos Recientes</CardTitle>
            <CardDescription>Últimos cursos creados en el sistema</CardDescription>
          </CardHeader>
          <CardContent>
            <div className="space-y-4">
              {[
                {
                  id: 1,
                  nombre: "Técnicas de Rescate en Estructuras Colapsadas",
                  fecha: "15/05/2023",
                  participantes: 24,
                  estado: "En curso",
                },
                {
                  id: 2,
                  nombre: "Primeros Auxilios Avanzados",
                  fecha: "02/06/2023",
                  participantes: 18,
                  estado: "Finalizado",
                },
                {
                  id: 3,
                  nombre: "Manejo de Materiales Peligrosos",
                  fecha: "10/06/2023",
                  participantes: 15,
                  estado: "En curso",
                },
                {
                  id: 4,
                  nombre: "Técnicas de Extinción de Incendios",
                  fecha: "20/06/2023",
                  participantes: 22,
                  estado: "Programado",
                },
              ].map((curso) => (
                <div key={curso.id} className="flex items-center justify-between border-b pb-4">
                  <div>
                    <p className="font-medium">{curso.nombre}</p>
                    <div className="flex items-center gap-2 text-sm text-muted-foreground">
                      <span>Fecha: {curso.fecha}</span>
                      <span>•</span>
                      <span>{curso.participantes} participantes</span>
                    </div>
                  </div>
                  <div>
                    <span
                      className={`inline-flex items-center rounded-full px-2.5 py-0.5 text-xs font-semibold ${
                        curso.estado === "En curso"
                          ? "bg-blue-50 text-blue-700"
                          : curso.estado === "Finalizado"
                            ? "bg-green-50 text-green-700"
                            : "bg-yellow-50 text-yellow-700"
                      }`}
                    >
                      {curso.estado}
                    </span>
                  </div>
                </div>
              ))}
            </div>
            <div className="mt-4 text-center">
              <Button variant="link" asChild>
                <Link href="/dashboard/cursos">Ver todos los cursos</Link>
              </Button>
            </div>
          </CardContent>
        </Card>
        <Card className="col-span-3">
          <CardHeader>
            <CardTitle>Documentos Pendientes</CardTitle>
            <CardDescription>Documentos que requieren su firma</CardDescription>
          </CardHeader>
          <CardContent>
            <div className="space-y-4">
              {[
                {
                  id: 1,
                  tipo: "Certificado",
                  curso: "Primeros Auxilios Avanzados",
                  fecha: "05/06/2023",
                },
                {
                  id: 2,
                  tipo: "Acta",
                  curso: "Técnicas de Rescate en Estructuras Colapsadas",
                  fecha: "18/05/2023",
                },
                {
                  id: 3,
                  tipo: "Certificado",
                  curso: "Manejo de Materiales Peligrosos",
                  fecha: "12/06/2023",
                },
              ].map((doc) => (
                <div key={doc.id} className="flex items-center justify-between border-b pb-4">
                  <div className="flex items-center gap-3">
                    <div className="bg-red-100 p-2 rounded-full">
                      {doc.tipo === "Certificado" ? (
                        <svg
                          xmlns="http://www.w3.org/2000/svg"
                          width="16"
                          height="16"
                          viewBox="0 0 24 24"
                          fill="none"
                          stroke="currentColor"
                          strokeWidth="2"
                          strokeLinecap="round"
                          strokeLinejoin="round"
                          className="text-red-700"
                        >
                          <path d="M12 22a5 5 0 0 1-3-9" />
                          <path d="M11 1 3 9a2 2 0 0 0 0 2.83L13 21.9a2 2 0 0 0 2.83 0l8-8a2 2 0 0 0 0-2.83L15 3" />
                          <circle cx="6.5" cy="6.5" r="1.5" />
                        </svg>
                      ) : (
                        <svg
                          xmlns="http://www.w3.org/2000/svg"
                          width="16"
                          height="16"
                          viewBox="0 0 24 24"
                          fill="none"
                          stroke="currentColor"
                          strokeWidth="2"
                          strokeLinecap="round"
                          strokeLinejoin="round"
                          className="text-red-700"
                        >
                          <path d="M14.5 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7.5L14.5 2z" />
                          <polyline points="14 2 14 8 20 8" />
                          <line x1="16" x2="8" y1="13" y2="13" />
                          <line x1="16" x2="8" y1="17" y2="17" />
                          <line x1="10" x2="8" y1="9" y2="9" />
                        </svg>
                      )}
                    </div>
                    <div>
                      <p className="font-medium">{doc.tipo}</p>
                      <p className="text-sm text-muted-foreground">{doc.curso}</p>
                    </div>
                  </div>
                  <Button size="sm" className="bg-red-700 hover:bg-red-800">
                    Firmar
                  </Button>
                </div>
              ))}
            </div>
            <div className="mt-4 text-center">
              <Button variant="link" asChild>
                <Link href="/dashboard/certificados">Ver todos los documentos</Link>
              </Button>
            </div>
          </CardContent>
        </Card>
      </div>
    </div>
  )
}
