"use client"

import type React from "react"

import { useState } from "react"
import Link from "next/link"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Input } from "@/components/ui/input"
import { Table, TableBody, TableCell, TableHead, TableHeader, TableRow } from "@/components/ui/table"
import { Badge } from "@/components/ui/badge"
import {
  Dialog,
  DialogContent,
  DialogDescription,
  DialogFooter,
  DialogHeader,
  DialogTitle,
  DialogTrigger,
} from "@/components/ui/dialog"
import { Label } from "@/components/ui/label"
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select"
import { useToast } from "@/components/ui/use-toast"

export default function ParticipantesPage() {
  const [participantes, setParticipantes] = useState([
    {
      id: 1,
      nombres: "Carlos Andrés",
      apellidos: "Pérez González",
      cedula: "12345678",
      correo: "carlos.perez@bomberos.gov.co",
      institucion: "Bomberos Bogotá",
      celular: "3001234567",
      genero: "Masculino",
      estado: "Activo",
      cursosMatriculados: 2,
    },
    {
      id: 2,
      nombres: "María Elena",
      apellidos: "Rodríguez López",
      cedula: "87654321",
      correo: "maria.rodriguez@bomberos.gov.co",
      institucion: "Bomberos Medellín",
      celular: "3009876543",
      genero: "Femenino",
      estado: "Activo",
      cursosMatriculados: 1,
    },
    {
      id: 3,
      nombres: "Juan Carlos",
      apellidos: "Martínez Silva",
      cedula: "11223344",
      correo: "juan.martinez@bomberos.gov.co",
      institucion: "Bomberos Cali",
      celular: "3005566778",
      genero: "Masculino",
      estado: "Inactivo",
      cursosMatriculados: 0,
    },
  ])

  const [isDialogOpen, setIsDialogOpen] = useState(false)
  const [isBulkUploadOpen, setIsBulkUploadOpen] = useState(false)
  const [formData, setFormData] = useState({
    nombres: "",
    apellidos: "",
    cedula: "",
    correo: "",
    institucion: "",
    celular: "",
    genero: "",
    fotografia: null as File | null,
  })

  const { toast } = useToast()

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault()

    const nuevoParticipante = {
      id: participantes.length + 1,
      ...formData,
      estado: "Activo",
      cursosMatriculados: 0,
    }

    setParticipantes([...participantes, nuevoParticipante])
    setIsDialogOpen(false)
    setFormData({
      nombres: "",
      apellidos: "",
      cedula: "",
      correo: "",
      institucion: "",
      celular: "",
      genero: "",
      fotografia: null,
    })

    toast({
      title: "Participante registrado",
      description: "El participante ha sido registrado exitosamente.",
    })
  }

  const handleBulkUpload = (e: React.FormEvent) => {
    e.preventDefault()
    // Simulación de carga masiva
    toast({
      title: "Carga masiva completada",
      description: "Se han registrado 25 participantes desde el archivo Excel.",
    })
    setIsBulkUploadOpen(false)
  }

  return (
    <div className="space-y-6">
      <div className="flex flex-col md:flex-row md:items-center md:justify-between gap-4">
        <div>
          <h1 className="text-3xl font-bold tracking-tight">Gestión de Participantes</h1>
          <p className="text-muted-foreground">Administre los participantes registrados en el sistema</p>
        </div>
        <div className="flex gap-2">
          <Dialog open={isBulkUploadOpen} onOpenChange={setIsBulkUploadOpen}>
            <DialogTrigger asChild>
              <Button variant="outline">
                <svg
                  xmlns="http://www.w3.org/2000/svg"
                  width="16"
                  height="16"
                  viewBox="0 0 24 24"
                  fill="none"
                  stroke="currentColor"
                  strokeWidth="2"
                  strokeLinecap="round"
                  strokeLinejoin="round"
                  className="mr-2"
                >
                  <path d="M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4" />
                  <polyline points="17 8 12 3 7 8" />
                  <line x1="12" x2="12" y1="3" y2="15" />
                </svg>
                Carga Masiva
              </Button>
            </DialogTrigger>
            <DialogContent>
              <DialogHeader>
                <DialogTitle>Carga Masiva de Participantes</DialogTitle>
                <DialogDescription>
                  Suba un archivo Excel con los datos de los participantes para registrarlos en lote.
                </DialogDescription>
              </DialogHeader>
              <form onSubmit={handleBulkUpload}>
                <div className="space-y-4">
                  <div>
                    <Label htmlFor="archivo">Archivo Excel</Label>
                    <Input id="archivo" type="file" accept=".xlsx,.xls" required />
                    <p className="text-sm text-muted-foreground mt-1">
                      El archivo debe contener las columnas: Nombres, Apellidos, Cédula, Correo, Institución, Celular,
                      Género
                    </p>
                  </div>
                  <div className="bg-blue-50 p-4 rounded-lg">
                    <h4 className="font-medium text-blue-900 mb-2">Formato requerido:</h4>
                    <ul className="text-sm text-blue-800 space-y-1">
                      <li>• Nombres (texto)</li>
                      <li>• Apellidos (texto)</li>
                      <li>• Cédula (número)</li>
                      <li>• Correo (email válido)</li>
                      <li>• Institución (texto)</li>
                      <li>• Celular (número)</li>
                      <li>• Género (Masculino/Femenino)</li>
                    </ul>
                  </div>
                </div>
                <DialogFooter className="mt-6">
                  <Button type="button" variant="outline" onClick={() => setIsBulkUploadOpen(false)}>
                    Cancelar
                  </Button>
                  <Button type="submit" className="bg-red-700 hover:bg-red-800">
                    Cargar Participantes
                  </Button>
                </DialogFooter>
              </form>
            </DialogContent>
          </Dialog>

          <Dialog open={isDialogOpen} onOpenChange={setIsDialogOpen}>
            <DialogTrigger asChild>
              <Button className="bg-red-700 hover:bg-red-800">
                <svg
                  xmlns="http://www.w3.org/2000/svg"
                  width="16"
                  height="16"
                  viewBox="0 0 24 24"
                  fill="none"
                  stroke="currentColor"
                  strokeWidth="2"
                  strokeLinecap="round"
                  strokeLinejoin="round"
                  className="mr-2"
                >
                  <path d="M5 12h14" />
                  <path d="M12 5v14" />
                </svg>
                Registrar Participante
              </Button>
            </DialogTrigger>
            <DialogContent className="max-w-2xl">
              <DialogHeader>
                <DialogTitle>Registrar Nuevo Participante</DialogTitle>
                <DialogDescription>
                  Complete todos los campos requeridos para registrar un nuevo participante.
                </DialogDescription>
              </DialogHeader>
              <form onSubmit={handleSubmit}>
                <div className="grid grid-cols-2 gap-4">
                  <div>
                    <Label htmlFor="nombres">Nombres *</Label>
                    <Input
                      id="nombres"
                      value={formData.nombres}
                      onChange={(e) => setFormData({ ...formData, nombres: e.target.value })}
                      required
                    />
                  </div>
                  <div>
                    <Label htmlFor="apellidos">Apellidos *</Label>
                    <Input
                      id="apellidos"
                      value={formData.apellidos}
                      onChange={(e) => setFormData({ ...formData, apellidos: e.target.value })}
                      required
                    />
                  </div>
                  <div>
                    <Label htmlFor="cedula">Cédula *</Label>
                    <Input
                      id="cedula"
                      value={formData.cedula}
                      onChange={(e) => setFormData({ ...formData, cedula: e.target.value })}
                      required
                    />
                  </div>
                  <div>
                    <Label htmlFor="correo">Correo Electrónico *</Label>
                    <Input
                      id="correo"
                      type="email"
                      value={formData.correo}
                      onChange={(e) => setFormData({ ...formData, correo: e.target.value })}
                      required
                    />
                  </div>
                  <div>
                    <Label htmlFor="institucion">Institución *</Label>
                    <Input
                      id="institucion"
                      value={formData.institucion}
                      onChange={(e) => setFormData({ ...formData, institucion: e.target.value })}
                      required
                    />
                  </div>
                  <div>
                    <Label htmlFor="celular">Celular *</Label>
                    <Input
                      id="celular"
                      value={formData.celular}
                      onChange={(e) => setFormData({ ...formData, celular: e.target.value })}
                      required
                    />
                  </div>
                  <div>
                    <Label htmlFor="genero">Género *</Label>
                    <Select
                      value={formData.genero}
                      onValueChange={(value) => setFormData({ ...formData, genero: value })}
                    >
                      <SelectTrigger>
                        <SelectValue placeholder="Seleccionar género" />
                      </SelectTrigger>
                      <SelectContent>
                        <SelectItem value="Masculino">Masculino</SelectItem>
                        <SelectItem value="Femenino">Femenino</SelectItem>
                      </SelectContent>
                    </Select>
                  </div>
                  <div>
                    <Label htmlFor="fotografia">Fotografía</Label>
                    <Input
                      id="fotografia"
                      type="file"
                      accept="image/*"
                      onChange={(e) => setFormData({ ...formData, fotografia: e.target.files?.[0] || null })}
                    />
                  </div>
                </div>
                <DialogFooter className="mt-6">
                  <Button type="button" variant="outline" onClick={() => setIsDialogOpen(false)}>
                    Cancelar
                  </Button>
                  <Button type="submit" className="bg-red-700 hover:bg-red-800">
                    Registrar Participante
                  </Button>
                </DialogFooter>
              </form>
            </DialogContent>
          </Dialog>
        </div>
      </div>

      <Card>
        <CardHeader>
          <CardTitle>Participantes Registrados</CardTitle>
          <CardDescription>Lista de todos los participantes en el sistema</CardDescription>
        </CardHeader>
        <CardContent>
          <div className="flex flex-col md:flex-row gap-4 mb-6">
            <Input placeholder="Buscar por nombre, cédula o correo..." className="max-w-sm" />
            <div className="flex gap-2 ml-auto">
              <Button variant="outline">
                <svg
                  xmlns="http://www.w3.org/2000/svg"
                  width="16"
                  height="16"
                  viewBox="0 0 24 24"
                  fill="none"
                  stroke="currentColor"
                  strokeWidth="2"
                  strokeLinecap="round"
                  strokeLinejoin="round"
                  className="mr-2"
                >
                  <path d="M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4" />
                  <polyline points="7 10 12 15 17 10" />
                  <line x1="12" x2="12" y1="15" y2="3" />
                </svg>
                Exportar
              </Button>
            </div>
          </div>

          <div className="rounded-md border">
            <Table>
              <TableHeader>
                <TableRow>
                  <TableHead>Nombre Completo</TableHead>
                  <TableHead>Cédula</TableHead>
                  <TableHead>Correo</TableHead>
                  <TableHead>Institución</TableHead>
                  <TableHead>Celular</TableHead>
                  <TableHead>Estado</TableHead>
                  <TableHead>Cursos</TableHead>
                  <TableHead>Acciones</TableHead>
                </TableRow>
              </TableHeader>
              <TableBody>
                {participantes.map((participante) => (
                  <TableRow key={participante.id}>
                    <TableCell className="font-medium">
                      {participante.nombres} {participante.apellidos}
                    </TableCell>
                    <TableCell>{participante.cedula}</TableCell>
                    <TableCell>{participante.correo}</TableCell>
                    <TableCell>{participante.institucion}</TableCell>
                    <TableCell>{participante.celular}</TableCell>
                    <TableCell>
                      <Badge
                        className={
                          participante.estado === "Activo"
                            ? "bg-green-100 text-green-700 hover:bg-green-100"
                            : "bg-red-100 text-red-700 hover:bg-red-100"
                        }
                      >
                        {participante.estado}
                      </Badge>
                    </TableCell>
                    <TableCell>{participante.cursosMatriculados}</TableCell>
                    <TableCell>
                      <div className="flex items-center gap-2">
                        <Button variant="ghost" size="icon" asChild>
                          <Link href={`/dashboard/participantes/${participante.id}`}>
                            <svg
                              xmlns="http://www.w3.org/2000/svg"
                              width="16"
                              height="16"
                              viewBox="0 0 24 24"
                              fill="none"
                              stroke="currentColor"
                              strokeWidth="2"
                              strokeLinecap="round"
                              strokeLinejoin="round"
                            >
                              <path d="M2 12s3-7 10-7 10 7 10 7-3 7-10 7-10-7-10-7Z" />
                              <circle cx="12" cy="12" r="3" />
                            </svg>
                            <span className="sr-only">Ver</span>
                          </Link>
                        </Button>
                        <Button variant="ghost" size="icon">
                          <svg
                            xmlns="http://www.w3.org/2000/svg"
                            width="16"
                            height="16"
                            viewBox="0 0 24 24"
                            fill="none"
                            stroke="currentColor"
                            strokeWidth="2"
                            strokeLinecap="round"
                            strokeLinejoin="round"
                          >
                            <path d="M17 3a2.85 2.83 0 1 1 4 4L7.5 20.5 2 22l1.5-5.5Z" />
                            <path d="m15 5 4 4" />
                          </svg>
                          <span className="sr-only">Editar</span>
                        </Button>
                        <Button variant="ghost" size="icon" className="text-blue-700">
                          <svg
                            xmlns="http://www.w3.org/2000/svg"
                            width="16"
                            height="16"
                            viewBox="0 0 24 24"
                            fill="none"
                            stroke="currentColor"
                            strokeWidth="2"
                            strokeLinecap="round"
                            strokeLinejoin="round"
                          >
                            <path d="M16 21v-2a4 4 0 0 0-4-4H6a4 4 0 0 0-4 4v2" />
                            <circle cx="9" cy="7" r="4" />
                            <path d="M22 21v-2a4 4 0 0 0-3-3.87" />
                            <path d="M16 3.13a4 4 0 0 1 0 7.75" />
                          </svg>
                          <span className="sr-only">Matricular</span>
                        </Button>
                      </div>
                    </TableCell>
                  </TableRow>
                ))}
              </TableBody>
            </Table>
          </div>
        </CardContent>
      </Card>
    </div>
  )
}
