"use client"

import { useState } from "react"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select"
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs"
import { useToast } from "@/components/ui/use-toast"
import { Label } from "@/components/ui/label"
import { Input } from "@/components/ui/input"
import { Checkbox } from "@/components/ui/checkbox"

export default function ReportesPage() {
  const { toast } = useToast()

  const [tipoReporte, setTipoReporte] = useState("")
  const [formatoReporte, setFormatoReporte] = useState("pdf")
  const [periodoReporte, setPeriodoReporte] = useState("")
  const [filtros, setFiltros] = useState({
    escuela: "",
    curso: "",
    estado: "",
    fechaInicio: "",
    fechaFin: "",
  })

  const [opcionesReporte, setOpcionesReporte] = useState({
    incluirGraficos: true,
    incluirTablas: true,
    incluirResumenEjecutivo: true,
    incluirDetalleParticipantes: false,
    incluirCalificaciones: false,
    incluirFirmas: true,
  })

  const handleGenerarReporte = () => {
    if (!tipoReporte) {
      toast({
        title: "Error",
        description: "Por favor seleccione un tipo de reporte.",
        variant: "destructive",
      })
      return
    }

    toast({
      title: "Reporte generado",
      description: `El reporte de ${tipoReporte} ha sido generado en formato ${formatoReporte.toUpperCase()}.`,
    })
  }

  return (
    <div className="space-y-6">
      <div className="flex flex-col md:flex-row md:items-center md:justify-between gap-4">
        <div>
          <h1 className="text-3xl font-bold tracking-tight">Reportes y Estadísticas</h1>
          <p className="text-muted-foreground">Genere reportes y visualice estadísticas del sistema</p>
        </div>
      </div>

      <Tabs defaultValue="reportes" className="space-y-4">
        <TabsList>
          <TabsTrigger value="reportes">Reportes</TabsTrigger>
          <TabsTrigger value="estadisticas">Estadísticas</TabsTrigger>
          <TabsTrigger value="dashboard">Dashboard</TabsTrigger>
        </TabsList>

        <TabsContent value="reportes">
          <div className="grid grid-cols-1 md:grid-cols-3 gap-6">
            <Card className="md:col-span-1">
              <CardHeader>
                <CardTitle>Configuración del Reporte</CardTitle>
                <CardDescription>Seleccione el tipo de reporte y los filtros</CardDescription>
              </CardHeader>
              <CardContent className="space-y-4">
                <div>
                  <Label htmlFor="tipoReporte">Tipo de Reporte</Label>
                  <Select value={tipoReporte} onValueChange={setTipoReporte}>
                    <SelectTrigger>
                      <SelectValue placeholder="Seleccionar tipo de reporte" />
                    </SelectTrigger>
                    <SelectContent>
                      <SelectItem value="certificados">Certificados Emitidos</SelectItem>
                      <SelectItem value="cursos">Cursos Realizados</SelectItem>
                      <SelectItem value="participantes">Participantes por Curso</SelectItem>
                      <SelectItem value="calificaciones">Calificaciones</SelectItem>
                      <SelectItem value="instituciones">Instituciones Participantes</SelectItem>
                    </SelectContent>
                  </Select>
                </div>

                <div>
                  <Label htmlFor="formatoReporte">Formato de Salida</Label>
                  <Select value={formatoReporte} onValueChange={setFormatoReporte}>
                    <SelectTrigger>
                      <SelectValue placeholder="Seleccionar formato" />
                    </SelectTrigger>
                    <SelectContent>
                      <SelectItem value="pdf">PDF</SelectItem>
                      <SelectItem value="excel">Excel</SelectItem>
                      <SelectItem value="csv">CSV</SelectItem>
                    </SelectContent>
                  </Select>
                </div>

                <div>
                  <Label htmlFor="periodoReporte">Periodo</Label>
                  <Select value={periodoReporte} onValueChange={setPeriodoReporte}>
                    <SelectTrigger>
                      <SelectValue placeholder="Seleccionar periodo" />
                    </SelectTrigger>
                    <SelectContent>
                      <SelectItem value="ultimo_mes">Último Mes</SelectItem>
                      <SelectItem value="ultimo_trimestre">Último Trimestre</SelectItem>
                      <SelectItem value="ultimo_semestre">Último Semestre</SelectItem>
                      <SelectItem value="ultimo_año">Último Año</SelectItem>
                      <SelectItem value="personalizado">Personalizado</SelectItem>
                    </SelectContent>
                  </Select>
                </div>

                {periodoReporte === "personalizado" && (
                  <div className="grid grid-cols-2 gap-4">
                    <div>
                      <Label htmlFor="fechaInicio">Fecha Inicio</Label>
                      <Input
                        id="fechaInicio"
                        type="date"
                        value={filtros.fechaInicio}
                        onChange={(e) => setFiltros({ ...filtros, fechaInicio: e.target.value })}
                      />
                    </div>
                    <div>
                      <Label htmlFor="fechaFin">Fecha Fin</Label>
                      <Input
                        id="fechaFin"
                        type="date"
                        value={filtros.fechaFin}
                        onChange={(e) => setFiltros({ ...filtros, fechaFin: e.target.value })}
                      />
                    </div>
                  </div>
                )}

                <div>
                  <Label htmlFor="escuela">Escuela/Dependencia</Label>
                  <Select value={filtros.escuela} onValueChange={(value) => setFiltros({ ...filtros, escuela: value })}>
                    <SelectTrigger>
                      <SelectValue placeholder="Todas las escuelas" />
                    </SelectTrigger>
                    <SelectContent>
                      <SelectItem value="todas">Todas las escuelas</SelectItem>
                      <SelectItem value="escuela_nacional">Escuela Nacional de Bomberos</SelectItem>
                      <SelectItem value="escuela_bogota">Escuela Regional Bogotá</SelectItem>
                      <SelectItem value="escuela_medellin">Escuela Regional Medellín</SelectItem>
                    </SelectContent>
                  </Select>
                </div>

                <div className="space-y-2">
                  <Label>Opciones del Reporte</Label>
                  <div className="space-y-2">
                    <div className="flex items-center space-x-2">
                      <Checkbox
                        id="incluirGraficos"
                        checked={opcionesReporte.incluirGraficos}
                        onCheckedChange={(checked) =>
                          setOpcionesReporte({ ...opcionesReporte, incluirGraficos: !!checked })
                        }
                      />
                      <Label htmlFor="incluirGraficos">Incluir gráficos</Label>
                    </div>
                    <div className="flex items-center space-x-2">
                      <Checkbox
                        id="incluirTablas"
                        checked={opcionesReporte.incluirTablas}
                        onCheckedChange={(checked) =>
                          setOpcionesReporte({ ...opcionesReporte, incluirTablas: !!checked })
                        }
                      />
                      <Label htmlFor="incluirTablas">Incluir tablas de datos</Label>
                    </div>
                    <div className="flex items-center space-x-2">
                      <Checkbox
                        id="incluirResumenEjecutivo"
                        checked={opcionesReporte.incluirResumenEjecutivo}
                        onCheckedChange={(checked) =>
                          setOpcionesReporte({ ...opcionesReporte, incluirResumenEjecutivo: !!checked })
                        }
                      />
                      <Label htmlFor="incluirResumenEjecutivo">Incluir resumen ejecutivo</Label>
                    </div>
                    <div className="flex items-center space-x-2">
                      <Checkbox
                        id="incluirDetalleParticipantes"
                        checked={opcionesReporte.incluirDetalleParticipantes}
                        onCheckedChange={(checked) =>
                          setOpcionesReporte({ ...opcionesReporte, incluirDetalleParticipantes: !!checked })
                        }
                      />
                      <Label htmlFor="incluirDetalleParticipantes">Incluir detalle de participantes</Label>
                    </div>
                    <div className="flex items-center space-x-2">
                      <Checkbox
                        id="incluirCalificaciones"
                        checked={opcionesReporte.incluirCalificaciones}
                        onCheckedChange={(checked) =>
                          setOpcionesReporte({ ...opcionesReporte, incluirCalificaciones: !!checked })
                        }
                      />
                      <Label htmlFor="incluirCalificaciones">Incluir calificaciones</Label>
                    </div>
                    <div className="flex items-center space-x-2">
                      <Checkbox
                        id="incluirFirmas"
                        checked={opcionesReporte.incluirFirmas}
                        onCheckedChange={(checked) =>
                          setOpcionesReporte({ ...opcionesReporte, incluirFirmas: !!checked })
                        }
                      />
                      <Label htmlFor="incluirFirmas">Incluir firmas digitales</Label>
                    </div>
                  </div>
                </div>

                <Button
                  onClick={handleGenerarReporte}
                  className="w-full bg-red-700 hover:bg-red-800"
                  disabled={!tipoReporte}
                >
                  <svg
                    xmlns="http://www.w3.org/2000/svg"
                    width="16"
                    height="16"
                    viewBox="0 0 24 24"
                    fill="none"
                    stroke="currentColor"
                    strokeWidth="2"
                    strokeLinecap="round"
                    strokeLinejoin="round"
                    className="mr-2"
                  >
                    <path d="M14.5 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7.5L14.5 2z" />
                    <polyline points="14 2 14 8 20 8" />
                  </svg>
                  Generar Reporte
                </Button>
              </CardContent>
            </Card>

            <Card className="md:col-span-2">
              <CardHeader>
                <CardTitle>Vista Previa del Reporte</CardTitle>
                <CardDescription>Visualización preliminar del reporte seleccionado</CardDescription>
              </CardHeader>
              <CardContent>
                {!tipoReporte ? (
                  <div className="flex flex-col items-center justify-center h-80 text-center">
                    <svg
                      xmlns="http://www.w3.org/2000/svg"
                      width="64"
                      height="64"
                      viewBox="0 0 24 24"
                      fill="none"
                      stroke="currentColor"
                      strokeWidth="2"
                      strokeLinecap="round"
                      strokeLinejoin="round"
                      className="text-muted-foreground mb-4"
                    >
                      <path d="M14.5 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7.5L14.5 2z" />
                      <polyline points="14 2 14 8 20 8" />
                    </svg>
                    <h3 className="text-lg font-medium">Seleccione un tipo de reporte</h3>
                    <p className="text-sm text-muted-foreground mt-2">La vista previa del reporte se mostrará aquí</p>
                  </div>
                ) : (
                  <div className="space-y-6">
                    <div className="border rounded-lg p-4">
                      <h3 className="text-lg font-semibold mb-2">
                        Reporte de{" "}
                        {tipoReporte === "certificados"
                          ? "Certificados Emitidos"
                          : tipoReporte === "cursos"
                            ? "Cursos Realizados"
                            : tipoReporte === "participantes"
                              ? "Participantes por Curso"
                              : tipoReporte === "calificaciones"
                                ? "Calificaciones"
                                : "Instituciones Participantes"}
                      </h3>
                      <p className="text-sm text-muted-foreground">
                        Periodo:{" "}
                        {periodoReporte === "ultimo_mes"
                          ? "Último Mes"
                          : periodoReporte === "ultimo_trimestre"
                            ? "Último Trimestre"
                            : periodoReporte === "ultimo_semestre"
                              ? "Último Semestre"
                              : periodoReporte === "ultimo_año"
                                ? "Último Año"
                                : periodoReporte === "personalizado"
                                  ? `${filtros.fechaInicio} a ${filtros.fechaFin}`
                                  : "Todo el periodo"}
                      </p>
                      <p className="text-sm text-muted-foreground">
                        Escuela:{" "}
                        {filtros.escuela === "todas"
                          ? "Todas las escuelas"
                          : filtros.escuela === "escuela_nacional"
                            ? "Escuela Nacional de Bomberos"
                            : filtros.escuela === "escuela_bogota"
                              ? "Escuela Regional Bogotá"
                              : filtros.escuela === "escuela_medellin"
                                ? "Escuela Regional Medellín"
                                : "Todas las escuelas"}
                      </p>
                    </div>

                    {opcionesReporte.incluirResumenEjecutivo && (
                      <div>
                        <h4 className="text-md font-medium mb-2">Resumen Ejecutivo</h4>
                        <div className="bg-gray-50 p-4 rounded-lg">
                          <p className="text-sm">
                            Este reporte presenta un análisis detallado de{" "}
                            {tipoReporte === "certificados"
                              ? "los certificados emitidos"
                              : tipoReporte === "cursos"
                                ? "los cursos realizados"
                                : tipoReporte === "participantes"
                                  ? "los participantes por curso"
                                  : tipoReporte === "calificaciones"
                                    ? "las calificaciones obtenidas"
                                    : "las instituciones participantes"}{" "}
                            durante el periodo seleccionado. Se incluyen métricas clave y tendencias observadas.
                          </p>
                        </div>
                      </div>
                    )}

                    {opcionesReporte.incluirGraficos && (
                      <div>
                        <h4 className="text-md font-medium mb-2">Gráficos</h4>
                        <div className="grid grid-cols-2 gap-4">
                          <div className="bg-gray-50 p-4 rounded-lg h-40 flex items-center justify-center">
                            <p className="text-sm text-muted-foreground">Gráfico de barras</p>
                          </div>
                          <div className="bg-gray-50 p-4 rounded-lg h-40 flex items-center justify-center">
                            <p className="text-sm text-muted-foreground">Gráfico circular</p>
                          </div>
                        </div>
                      </div>
                    )}

                    {opcionesReporte.incluirTablas && (
                      <div>
                        <h4 className="text-md font-medium mb-2">Datos Tabulares</h4>
                        <div className="bg-gray-50 p-4 rounded-lg">
                          <div className="border rounded-md">
                            <div className="grid grid-cols-4 gap-4 p-2 font-medium bg-gray-100">
                              <div>Columna 1</div>
                              <div>Columna 2</div>
                              <div>Columna 3</div>
                              <div>Columna 4</div>
                            </div>
                            <div className="grid grid-cols-4 gap-4 p-2 border-t">
                              <div>Dato 1</div>
                              <div>Dato 2</div>
                              <div>Dato 3</div>
                              <div>Dato 4</div>
                            </div>
                            <div className="grid grid-cols-4 gap-4 p-2 border-t">
                              <div>Dato 5</div>
                              <div>Dato 6</div>
                              <div>Dato 7</div>
                              <div>Dato 8</div>
                            </div>
                          </div>
                        </div>
                      </div>
                    )}
                  </div>
                )}
              </CardContent>
            </Card>
          </div>
        </TabsContent>

        <TabsContent value="estadisticas">
          <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
            <Card>
              <CardHeader>
                <CardTitle>Estadísticas de Cursos</CardTitle>
                <CardDescription>Métricas sobre los cursos realizados</CardDescription>
              </CardHeader>
              <CardContent>
                <div className="space-y-4">
                  <div className="grid grid-cols-2 gap-4">
                    <div className="bg-gray-50 p-4 rounded-lg">
                      <p className="text-sm text-muted-foreground">Total de Cursos</p>
                      <p className="text-2xl font-bold">24</p>
                    </div>
                    <div className="bg-gray-50 p-4 rounded-lg">
                      <p className="text-sm text-muted-foreground">Participantes Totales</p>
                      <p className="text-2xl font-bold">487</p>
                    </div>
                    <div className="bg-gray-50 p-4 rounded-lg">
                      <p className="text-sm text-muted-foreground">Promedio de Participantes</p>
                      <p className="text-2xl font-bold">20.3</p>
                    </div>
                    <div className="bg-gray-50 p-4 rounded-lg">
                      <p className="text-sm text-muted-foreground">Tasa de Aprobación</p>
                      <p className="text-2xl font-bold">92%</p>
                    </div>
                  </div>

                  <div className="bg-gray-50 p-4 rounded-lg h-60 flex items-center justify-center">
                    <p className="text-sm text-muted-foreground">Gráfico de tendencia de cursos por mes</p>
                  </div>
                </div>
              </CardContent>
            </Card>

            <Card>
              <CardHeader>
                <CardTitle>Estadísticas de Certificados</CardTitle>
                <CardDescription>Métricas sobre los certificados emitidos</CardDescription>
              </CardHeader>
              <CardContent>
                <div className="space-y-4">
                  <div className="grid grid-cols-2 gap-4">
                    <div className="bg-gray-50 p-4 rounded-lg">
                      <p className="text-sm text-muted-foreground">Certificados Emitidos</p>
                      <p className="text-2xl font-bold">412</p>
                    </div>
                    <div className="bg-gray-50 p-4 rounded-lg">
                      <p className="text-sm text-muted-foreground">Pendientes de Firma</p>
                      <p className="text-2xl font-bold">18</p>
                    </div>
                    <div className="bg-gray-50 p-4 rounded-lg">
                      <p className="text-sm text-muted-foreground">Tiempo Promedio de Emisión</p>
                      <p className="text-2xl font-bold">3.2 días</p>
                    </div>
                    <div className="bg-gray-50 p-4 rounded-lg">
                      <p className="text-sm text-muted-foreground">Verificaciones Realizadas</p>
                      <p className="text-2xl font-bold">156</p>
                    </div>
                  </div>

                  <div className="bg-gray-50 p-4 rounded-lg h-60 flex items-center justify-center">
                    <p className="text-sm text-muted-foreground">Gráfico de certificados por tipo de curso</p>
                  </div>
                </div>
              </CardContent>
            </Card>

            <Card className="md:col-span-2">
              <CardHeader>
                <CardTitle>Distribución Geográfica</CardTitle>
                <CardDescription>Distribución de participantes por región</CardDescription>
              </CardHeader>
              <CardContent>
                <div className="h-80 bg-gray-50 rounded-lg flex items-center justify-center">
                  <p className="text-sm text-muted-foreground">Mapa de Colombia con distribución de participantes</p>
                </div>
              </CardContent>
            </Card>
          </div>
        </TabsContent>

        <TabsContent value="dashboard">
          <Card>
            <CardHeader>
              <CardTitle>Dashboard Ejecutivo</CardTitle>
              <CardDescription>Resumen general del sistema</CardDescription>
            </CardHeader>
            <CardContent>
              <div className="space-y-6">
                <div className="grid grid-cols-1 md:grid-cols-4 gap-4">
                  <Card>
                    <CardContent className="p-4">
                      <div className="flex items-center justify-between">
                        <div>
                          <p className="text-sm text-muted-foreground">Cursos Activos</p>
                          <p className="text-2xl font-bold">12</p>
                        </div>
                        <div className="bg-red-100 p-2 rounded-full">
                          <svg
                            xmlns="http://www.w3.org/2000/svg"
                            width="20"
                            height="20"
                            viewBox="0 0 24 24"
                            fill="none"
                            stroke="currentColor"
                            strokeWidth="2"
                            strokeLinecap="round"
                            strokeLinejoin="round"
                            className="text-red-700"
                          >
                            <path d="M2 3h6a4 4 0 0 1 4 4v14a3 3 0 0 0-3-3H2z" />
                            <path d="M22 3h-6a4 4 0 0 0-4 4v14a3 3 0 0 1 3-3h7z" />
                          </svg>
                        </div>
                      </div>
                      <div className="mt-2 text-xs text-green-600">+2 desde el mes pasado</div>
                    </CardContent>
                  </Card>
                  <Card>
                    <CardContent className="p-4">
                      <div className="flex items-center justify-between">
                        <div>
                          <p className="text-sm text-muted-foreground">Participantes</p>
                          <p className="text-2xl font-bold">245</p>
                        </div>
                        <div className="bg-blue-100 p-2 rounded-full">
                          <svg
                            xmlns="http://www.w3.org/2000/svg"
                            width="20"
                            height="20"
                            viewBox="0 0 24 24"
                            fill="none"
                            stroke="currentColor"
                            strokeWidth="2"
                            strokeLinecap="round"
                            strokeLinejoin="round"
                            className="text-blue-700"
                          >
                            <path d="M16 21v-2a4 4 0 0 0-4-4H6a4 4 0 0 0-4 4v2" />
                            <circle cx="9" cy="7" r="4" />
                            <path d="M22 21v-2a4 4 0 0 0-3-3.87" />
                            <path d="M16 3.13a4 4 0 0 1 0 7.75" />
                          </svg>
                        </div>
                      </div>
                      <div className="mt-2 text-xs text-green-600">+18 desde el mes pasado</div>
                    </CardContent>
                  </Card>
                  <Card>
                    <CardContent className="p-4">
                      <div className="flex items-center justify-between">
                        <div>
                          <p className="text-sm text-muted-foreground">Certificados</p>
                          <p className="text-2xl font-bold">189</p>
                        </div>
                        <div className="bg-green-100 p-2 rounded-full">
                          <svg
                            xmlns="http://www.w3.org/2000/svg"
                            width="20"
                            height="20"
                            viewBox="0 0 24 24"
                            fill="none"
                            stroke="currentColor"
                            strokeWidth="2"
                            strokeLinecap="round"
                            strokeLinejoin="round"
                            className="text-green-700"
                          >
                            <path d="M12 22a5 5 0 0 1-3-9" />
                            <path d="M11 1 3 9a2 2 0 0 0 0 2.83L13 21.9a2 2 0 0 0 2.83 0l8-8a2 2 0 0 0 0-2.83L15 3" />
                            <circle cx="6.5" cy="6.5" r="1.5" />
                          </svg>
                        </div>
                      </div>
                      <div className="mt-2 text-xs text-green-600">+32 desde el mes pasado</div>
                    </CardContent>
                  </Card>
                  <Card>
                    <CardContent className="p-4">
                      <div className="flex items-center justify-between">
                        <div>
                          <p className="text-sm text-muted-foreground">Pendientes</p>
                          <p className="text-2xl font-bold">8</p>
                        </div>
                        <div className="bg-yellow-100 p-2 rounded-full">
                          <svg
                            xmlns="http://www.w3.org/2000/svg"
                            width="20"
                            height="20"
                            viewBox="0 0 24 24"
                            fill="none"
                            stroke="currentColor"
                            strokeWidth="2"
                            strokeLinecap="round"
                            strokeLinejoin="round"
                            className="text-yellow-700"
                          >
                            <path d="M14.5 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7.5L14.5 2z" />
                            <polyline points="14 2 14 8 20 8" />
                            <path d="M16 13v4" />
                            <path d="M8 13v4" />
                            <path d="M12 15v2" />
                          </svg>
                        </div>
                      </div>
                      <div className="mt-2 text-xs text-red-600">-3 desde el mes pasado</div>
                    </CardContent>
                  </Card>
                </div>

                <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                  <div className="bg-gray-50 p-4 rounded-lg h-80 flex items-center justify-center">
                    <p className="text-sm text-muted-foreground">Gráfico de tendencias anuales</p>
                  </div>
                  <div className="bg-gray-50 p-4 rounded-lg h-80 flex items-center justify-center">
                    <p className="text-sm text-muted-foreground">Distribución por tipo de curso</p>
                  </div>
                </div>

                <div className="bg-gray-50 p-4 rounded-lg">
                  <h3 className="font-medium mb-2">Actividad Reciente</h3>
                  <div className="space-y-3">
                    {[
                      { accion: "Certificado emitido", usuario: "Carlos Martínez", tiempo: "hace 2 horas" },
                      { accion: "Curso creado", usuario: "Laura Gómez", tiempo: "hace 5 horas" },
                      { accion: "Participante registrado", usuario: "Andrés López", tiempo: "hace 1 día" },
                      { accion: "Documento firmado", usuario: "María Rodríguez", tiempo: "hace 1 día" },
                    ].map((actividad, index) => (
                      <div key={index} className="flex items-center justify-between border-b pb-2">
                        <div>
                          <p className="font-medium">{actividad.accion}</p>
                          <p className="text-sm text-muted-foreground">Por {actividad.usuario}</p>
                        </div>
                        <p className="text-xs text-muted-foreground">{actividad.tiempo}</p>
                      </div>
                    ))}
                  </div>
                </div>
              </div>
            </CardContent>
          </Card>
        </TabsContent>
      </Tabs>
    </div>
  )
}
