"use client"

import type React from "react"

import { useState } from "react"
import Link from "next/link"
import { Button } from "@/components/ui/button"
import { Input } from "@/components/ui/input"
import { Label } from "@/components/ui/label"
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/components/ui/card"
import { Alert, AlertDescription, AlertTitle } from "@/components/ui/alert"

export default function VerificarCertificado() {
  const [codigo, setCodigo] = useState("")
  const [isLoading, setIsLoading] = useState(false)
  const [resultado, setResultado] = useState<null | {
    valido: boolean
    certificado?: {
      nombre: string
      curso: string
      fecha: string
      codigo: string
    }
  }>(null)

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault()
    setIsLoading(true)

    // Simulación de verificación - esto se conectaría con el backend PHP
    setTimeout(() => {
      setIsLoading(false)

      // Simulamos un certificado válido para demostración
      if (codigo.length > 5) {
        setResultado({
          valido: true,
          certificado: {
            nombre: "Carlos Andrés Pérez",
            curso: "Técnicas de Rescate en Estructuras Colapsadas",
            fecha: "15/05/2023",
            codigo: codigo,
          },
        })
      } else {
        setResultado({
          valido: false,
        })
      }
    }, 1500)
  }

  return (
    <div className="min-h-screen flex flex-col">
      <header className="bg-red-700 text-white py-4">
        <div className="container mx-auto px-4 flex justify-between items-center">
          <Link href="/" className="flex items-center gap-2">
            <svg
              xmlns="http://www.w3.org/2000/svg"
              width="24"
              height="24"
              viewBox="0 0 24 24"
              fill="none"
              stroke="currentColor"
              strokeWidth="2"
              strokeLinecap="round"
              strokeLinejoin="round"
              className="lucide lucide-flame"
            >
              <path d="M8.5 14.5A2.5 2.5 0 0 0 11 12c0-1.38-.5-2-1-3-1.072-2.143-.224-4.054 2-6 .5 2.5 2 4.9 4 6.5 2 1.6 3 3.5 3 5.5a7 7 0 1 1-14 0c0-1.153.433-2.294 1-3a2.5 2.5 0 0 0 2.5 2.5z" />
            </svg>
            <span className="font-bold text-xl">DNBC</span>
          </Link>
          <nav className="hidden md:flex gap-6">
            <Link href="/login" className="hover:underline">
              Iniciar Sesión
            </Link>
          </nav>
        </div>
      </header>

      <main className="flex-1 container mx-auto px-4 py-12">
        <div className="max-w-2xl mx-auto">
          <h1 className="text-3xl font-bold text-center mb-8">Verificación de Certificados</h1>

          <Card>
            <CardHeader>
              <CardTitle>Verificar Autenticidad</CardTitle>
              <CardDescription>Ingrese el código único del certificado para verificar su autenticidad</CardDescription>
            </CardHeader>
            <form onSubmit={handleSubmit}>
              <CardContent className="space-y-4">
                <div className="space-y-2">
                  <Label htmlFor="codigo">Código de Verificación</Label>
                  <Input
                    id="codigo"
                    placeholder="Ej: ABC123XYZ"
                    value={codigo}
                    onChange={(e) => setCodigo(e.target.value)}
                    required
                  />
                </div>
              </CardContent>
              <CardFooter>
                <Button type="submit" className="w-full bg-red-700 hover:bg-red-800" disabled={isLoading}>
                  {isLoading ? (
                    <div className="flex items-center gap-2">
                      <svg
                        className="animate-spin h-4 w-4 text-white"
                        xmlns="http://www.w3.org/2000/svg"
                        fill="none"
                        viewBox="0 0 24 24"
                      >
                        <circle
                          className="opacity-25"
                          cx="12"
                          cy="12"
                          r="10"
                          stroke="currentColor"
                          strokeWidth="4"
                        ></circle>
                        <path
                          className="opacity-75"
                          fill="currentColor"
                          d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"
                        ></path>
                      </svg>
                      <span>Verificando...</span>
                    </div>
                  ) : (
                    "Verificar Certificado"
                  )}
                </Button>
              </CardFooter>
            </form>
          </Card>

          {resultado && (
            <div className="mt-8">
              {resultado.valido ? (
                <Card className="border-green-500">
                  <CardHeader className="bg-green-50">
                    <div className="flex items-center gap-2">
                      <svg
                        xmlns="http://www.w3.org/2000/svg"
                        width="24"
                        height="24"
                        viewBox="0 0 24 24"
                        fill="none"
                        stroke="currentColor"
                        strokeWidth="2"
                        strokeLinecap="round"
                        strokeLinejoin="round"
                        className="text-green-600"
                      >
                        <path d="M22 11.08V12a10 10 0 1 1-5.93-9.14" />
                        <polyline points="22 4 12 14.01 9 11.01" />
                      </svg>
                      <CardTitle className="text-green-700">Certificado Válido</CardTitle>
                    </div>
                    <CardDescription>
                      El certificado ha sido verificado correctamente en nuestra base de datos
                    </CardDescription>
                  </CardHeader>
                  <CardContent className="pt-6">
                    <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
                      <div>
                        <p className="text-sm font-medium text-gray-500">Nombre del Participante</p>
                        <p className="font-semibold">{resultado.certificado?.nombre}</p>
                      </div>
                      <div>
                        <p className="text-sm font-medium text-gray-500">Curso</p>
                        <p className="font-semibold">{resultado.certificado?.curso}</p>
                      </div>
                      <div>
                        <p className="text-sm font-medium text-gray-500">Fecha de Emisión</p>
                        <p className="font-semibold">{resultado.certificado?.fecha}</p>
                      </div>
                      <div>
                        <p className="text-sm font-medium text-gray-500">Código de Verificación</p>
                        <p className="font-semibold">{resultado.certificado?.codigo}</p>
                      </div>
                    </div>
                  </CardContent>
                </Card>
              ) : (
                <Alert variant="destructive">
                  <svg
                    xmlns="http://www.w3.org/2000/svg"
                    width="24"
                    height="24"
                    viewBox="0 0 24 24"
                    fill="none"
                    stroke="currentColor"
                    strokeWidth="2"
                    strokeLinecap="round"
                    strokeLinejoin="round"
                    className="lucide lucide-alert-circle"
                  >
                    <circle cx="12" cy="12" r="10" />
                    <line x1="12" x2="12" y1="8" y2="12" />
                    <line x1="12" x2="12.01" y1="16" y2="16" />
                  </svg>
                  <AlertTitle>Certificado No Válido</AlertTitle>
                  <AlertDescription>
                    El código ingresado no corresponde a ningún certificado en nuestra base de datos. Por favor,
                    verifique el código e intente nuevamente.
                  </AlertDescription>
                </Alert>
              )}
            </div>
          )}
        </div>
      </main>

      <footer className="bg-gray-900 text-white py-6">
        <div className="container mx-auto px-4 text-center">
          <p className="flex items-center justify-center gap-2 mb-2">
            <svg
              xmlns="http://www.w3.org/2000/svg"
              width="20"
              height="20"
              viewBox="0 0 24 24"
              fill="none"
              stroke="currentColor"
              strokeWidth="2"
              strokeLinecap="round"
              strokeLinejoin="round"
              className="lucide lucide-flame"
            >
              <path d="M8.5 14.5A2.5 2.5 0 0 0 11 12c0-1.38-.5-2-1-3-1.072-2.143-.224-4.054 2-6 .5 2.5 2 4.9 4 6.5 2 1.6 3 3.5 3 5.5a7 7 0 1 1-14 0c0-1.153.433-2.294 1-3a2.5 2.5 0 0 0 2.5 2.5z" />
            </svg>
            <span className="font-bold">Dirección Nacional de Bomberos Colombia</span>
          </p>
          <p className="text-sm text-gray-400">© {new Date().getFullYear()} Todos los derechos reservados</p>
        </div>
      </footer>
    </div>
  )
}
