<?php
header('Content-Type: application/json');
header('Access-Control-Allow-Origin: *');
header('Access-Control-Allow-Methods: GET, POST, PUT, DELETE, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type, Authorization');

if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    exit(0);
}

// Configuración de base de datos
$host = 'localhost';
$dbname = 'wwesib_bomberos_certificados';
$username = 'wwesib_bomberos_certificados';
$password = 'Serrano10$';

try {
    $pdo = new PDO("mysql:host=$host;dbname=$dbname;charset=utf8mb4", $username, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch(PDOException $e) {
    echo json_encode(['success' => false, 'message' => 'Error de conexión: ' . $e->getMessage()]);
    exit;
}

$method = $_SERVER['REQUEST_METHOD'];

switch($method) {
    case 'GET':
        if (isset($_GET['curso_id'])) {
            // Obtener calificaciones de un curso específico
            $stmt = $pdo->prepare("
                SELECT cal.*, p.nombre, p.apellido, p.cedula, c.nombre as curso_nombre
                FROM calificaciones cal
                JOIN participantes p ON cal.participante_id = p.id
                JOIN cursos c ON cal.curso_id = c.id
                WHERE cal.curso_id = ?
                ORDER BY cal.nota_final DESC
            ");
            $stmt->execute([$_GET['curso_id']]);
        } else {
            // Obtener todas las calificaciones
            $stmt = $pdo->query("
                SELECT cal.*, p.nombre, p.apellido, p.cedula, c.nombre as curso_nombre
                FROM calificaciones cal
                JOIN participantes p ON cal.participante_id = p.id
                JOIN cursos c ON cal.curso_id = c.id
                ORDER BY cal.fecha_calificacion DESC
            ");
        }
        
        $calificaciones = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        echo json_encode([
            'success' => true,
            'message' => 'Calificaciones obtenidas correctamente',
            'count' => count($calificaciones),
            'data' => $calificaciones
        ]);
        break;
        
    case 'POST':
        $input = json_decode(file_get_contents('php://input'), true);
        
        if (!isset($input['participante_id']) || !isset($input['curso_id']) || !isset($input['nota_final'])) {
            echo json_encode(['success' => false, 'message' => 'Datos incompletos']);
            exit;
        }
        
        $estado = $input['nota_final'] >= 70 ? 'aprobado' : 'reprobado';
        
        $stmt = $pdo->prepare("
            INSERT INTO calificaciones (participante_id, curso_id, nota_teorica, nota_practica, nota_final, estado, fecha_calificacion)
            VALUES (?, ?, ?, ?, ?, ?, NOW())
            ON DUPLICATE KEY UPDATE
            nota_teorica = VALUES(nota_teorica),
            nota_practica = VALUES(nota_practica),
            nota_final = VALUES(nota_final),
            estado = VALUES(estado),
            fecha_calificacion = NOW()
        ");
        
        if ($stmt->execute([
            $input['participante_id'],
            $input['curso_id'],
            $input['nota_teorica'] ?? null,
            $input['nota_practica'] ?? null,
            $input['nota_final'],
            $estado
        ])) {
            echo json_encode([
                'success' => true,
                'message' => 'Calificación registrada correctamente',
                'estado' => $estado
            ]);
        } else {
            echo json_encode(['success' => false, 'message' => 'Error al registrar calificación']);
        }
        break;
        
    default:
        echo json_encode(['success' => false, 'message' => 'Método no permitido']);
        break;
}
?>
