<?php
header('Content-Type: application/json');
header('Access-Control-Allow-Origin: *');
header('Access-Control-Allow-Methods: GET, POST, PUT, DELETE, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type, Authorization');

if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    exit(0);
}

// Configuración de base de datos
$host = 'localhost';
$dbname = 'wwesib_bomberos_certificados';
$username = 'wwesib_bomberos_certificados';
$password = 'Serrano10$';

try {
    $pdo = new PDO("mysql:host=$host;dbname=$dbname;charset=utf8mb4", $username, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch(PDOException $e) {
    echo json_encode(['success' => false, 'message' => 'Error de conexión: ' . $e->getMessage()]);
    exit;
}

$method = $_SERVER['REQUEST_METHOD'];

switch($method) {
    case 'GET':
        if (isset($_GET['id'])) {
            // Obtener certificado específico
            $stmt = $pdo->prepare("
                SELECT c.*, p.nombre, p.apellido, p.cedula, cur.nombre as curso_nombre, cur.duracion_horas
                FROM certificados c
                JOIN participantes p ON c.participante_id = p.id
                JOIN cursos cur ON c.curso_id = cur.id
                WHERE c.id = ?
            ");
            $stmt->execute([$_GET['id']]);
            $certificado = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if ($certificado) {
                echo json_encode(['success' => true, 'data' => $certificado]);
            } else {
                echo json_encode(['success' => false, 'message' => 'Certificado no encontrado']);
            }
        } else {
            // Obtener todos los certificados
            $stmt = $pdo->query("
                SELECT c.*, p.nombre, p.apellido, p.cedula, cur.nombre as curso_nombre
                FROM certificados c
                JOIN participantes p ON c.participante_id = p.id
                JOIN cursos cur ON c.curso_id = cur.id
                ORDER BY c.fecha_emision DESC
            ");
            $certificados = $stmt->fetchAll(PDO::FETCH_ASSOC);
            
            echo json_encode([
                'success' => true,
                'message' => 'Certificados obtenidos correctamente',
                'count' => count($certificados),
                'data' => $certificados
            ]);
        }
        break;
        
    case 'POST':
        $input = json_decode(file_get_contents('php://input'), true);
        
        if (!isset($input['participante_id']) || !isset($input['curso_id'])) {
            echo json_encode(['success' => false, 'message' => 'Datos incompletos']);
            exit;
        }
        
        // Generar código único
        $codigo = 'CERT-' . date('Y') . '-' . str_pad(rand(1, 9999), 4, '0', STR_PAD_LEFT);
        
        $stmt = $pdo->prepare("
            INSERT INTO certificados (participante_id, curso_id, codigo, fecha_emision, estado)
            VALUES (?, ?, ?, NOW(), 'pendiente')
        ");
        
        if ($stmt->execute([$input['participante_id'], $input['curso_id'], $codigo])) {
            $id = $pdo->lastInsertId();
            echo json_encode([
                'success' => true,
                'message' => 'Certificado creado correctamente',
                'id' => $id,
                'codigo' => $codigo
            ]);
        } else {
            echo json_encode(['success' => false, 'message' => 'Error al crear certificado']);
        }
        break;
        
    default:
        echo json_encode(['success' => false, 'message' => 'Método no permitido']);
        break;
}
?>
