<?php
// Script de diagnóstico completo
echo "<h1>🔍 Diagnóstico del Sistema</h1>";

// 1. Verificar PHP
echo "<h2>1. Información de PHP</h2>";
echo "<p>Versión PHP: " . phpversion() . "</p>";
echo "<p>Extensiones disponibles:</p>";
echo "<ul>";
$extensions = ['pdo', 'pdo_mysql', 'json', 'mbstring'];
foreach ($extensions as $ext) {
    $status = extension_loaded($ext) ? '✅' : '❌';
    echo "<li>$status $ext</li>";
}
echo "</ul>";

// 2. Verificar conexión a base de datos
echo "<h2>2. Conexión a Base de Datos</h2>";
try {
    include_once '../config/database.php';
    $conn = getConnection();
    echo "<p>✅ Conexión exitosa</p>";
    
    // Verificar tablas
    $stmt = $conn->query("SHOW TABLES");
    $tables = $stmt->fetchAll(PDO::FETCH_COLUMN);
    echo "<p>📊 Tablas encontradas: " . count($tables) . "</p>";
    echo "<ul>";
    foreach ($tables as $table) {
        echo "<li>$table</li>";
    }
    echo "</ul>";
    
} catch (Exception $e) {
    echo "<p>❌ Error de conexión: " . $e->getMessage() . "</p>";
}

// 3. Verificar permisos de archivos
echo "<h2>3. Permisos de Archivos</h2>";
$files = ['../config/database.php', 'auth.php', 'participantes.php', 'cursos.php'];
foreach ($files as $file) {
    if (file_exists($file)) {
        $perms = substr(sprintf('%o', fileperms($file)), -4);
        echo "<p>✅ $file - Permisos: $perms</p>";
    } else {
        echo "<p>❌ $file - No encontrado</p>";
    }
}

// 4. Verificar logs de error
echo "<h2>4. Configuración del Servidor</h2>";
echo "<p>Error Reporting: " . (error_reporting() ? 'Activado' : 'Desactivado') . "</p>";
echo "<p>Display Errors: " . (ini_get('display_errors') ? 'Activado' : 'Desactivado') . "</p>";
echo "<p>Log Errors: " . (ini_get('log_errors') ? 'Activado' : 'Desactivado') . "</p>";

echo "<h2>5. Variables del Servidor</h2>";
echo "<p>SERVER_SOFTWARE: " . ($_SERVER['SERVER_SOFTWARE'] ?? 'No disponible') . "</p>";
echo "<p>DOCUMENT_ROOT: " . ($_SERVER['DOCUMENT_ROOT'] ?? 'No disponible') . "</p>";
?>
