<?php
header('Content-Type: application/json');
header('Access-Control-Allow-Origin: *');
header('Access-Control-Allow-Methods: GET, POST, PUT, DELETE, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type, Authorization');

if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    exit(0);
}

// Configuración de base de datos
$host = 'localhost';
$dbname = 'wwesib_bomberos_certificados';
$username = 'wwesib_bomberos_certificados';
$password = 'Serrano10$';

try {
    $pdo = new PDO("mysql:host=$host;dbname=$dbname;charset=utf8mb4", $username, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch(PDOException $e) {
    echo json_encode(['success' => false, 'message' => 'Error de conexión: ' . $e->getMessage()]);
    exit;
}

$method = $_SERVER['REQUEST_METHOD'];

switch($method) {
    case 'GET':
        if (isset($_GET['curso_id'])) {
            // Obtener matrículas de un curso específico
            $stmt = $pdo->prepare("
                SELECT m.*, p.nombre, p.apellido, p.cedula, p.email, c.nombre as curso_nombre
                FROM matriculas m
                JOIN participantes p ON m.participante_id = p.id
                JOIN cursos c ON m.curso_id = c.id
                WHERE m.curso_id = ?
                ORDER BY m.fecha_matricula DESC
            ");
            $stmt->execute([$_GET['curso_id']]);
        } else {
            // Obtener todas las matrículas
            $stmt = $pdo->query("
                SELECT m.*, p.nombre, p.apellido, p.cedula, c.nombre as curso_nombre
                FROM matriculas m
                JOIN participantes p ON m.participante_id = p.id
                JOIN cursos c ON m.curso_id = c.id
                ORDER BY m.fecha_matricula DESC
            ");
        }
        
        $matriculas = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        echo json_encode([
            'success' => true,
            'message' => 'Matrículas obtenidas correctamente',
            'count' => count($matriculas),
            'data' => $matriculas
        ]);
        break;
        
    case 'POST':
        $input = json_decode(file_get_contents('php://input'), true);
        
        if (!isset($input['participante_id']) || !isset($input['curso_id'])) {
            echo json_encode(['success' => false, 'message' => 'Datos incompletos']);
            exit;
        }
        
        // Verificar si ya está matriculado
        $stmt = $pdo->prepare("SELECT id FROM matriculas WHERE participante_id = ? AND curso_id = ?");
        $stmt->execute([$input['participante_id'], $input['curso_id']]);
        
        if ($stmt->fetch()) {
            echo json_encode(['success' => false, 'message' => 'El participante ya está matriculado en este curso']);
            exit;
        }
        
        $stmt = $pdo->prepare("
            INSERT INTO matriculas (participante_id, curso_id, fecha_matricula, estado)
            VALUES (?, ?, NOW(), 'activa')
        ");
        
        if ($stmt->execute([$input['participante_id'], $input['curso_id']])) {
            echo json_encode([
                'success' => true,
                'message' => 'Matrícula creada correctamente',
                'id' => $pdo->lastInsertId()
            ]);
        } else {
            echo json_encode(['success' => false, 'message' => 'Error al crear matrícula']);
        }
        break;
        
    default:
        echo json_encode(['success' => false, 'message' => 'Método no permitido']);
        break;
}
?>
