<?php
// API de participantes simple
header('Content-Type: application/json');
header('Access-Control-Allow-Origin: *');
header('Access-Control-Allow-Methods: GET, POST, PUT, DELETE, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type, Authorization');

if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    exit(0);
}

include_once '../config/database.php';

$method = $_SERVER['REQUEST_METHOD'];

try {
    $conn = getConnection();
    
    switch ($method) {
        case 'GET':
            if (isset($_GET['id'])) {
                // Obtener un participante específico
                $stmt = $conn->prepare("SELECT * FROM participantes WHERE id = ?");
                $stmt->execute([$_GET['id']]);
                $participante = $stmt->fetch(PDO::FETCH_ASSOC);
                
                if ($participante) {
                    echo json_encode(['success' => true, 'data' => $participante]);
                } else {
                    echo json_encode(['success' => false, 'message' => 'Participante no encontrado']);
                }
            } else {
                // Obtener todos los participantes
                $stmt = $conn->query("SELECT * FROM participantes ORDER BY apellidos, nombres");
                $participantes = $stmt->fetchAll(PDO::FETCH_ASSOC);
                echo json_encode(['success' => true, 'data' => $participantes]);
            }
            break;
            
        case 'POST':
            $input = json_decode(file_get_contents('php://input'), true);
            
            if (!isset($input['nombres']) || !isset($input['apellidos']) || !isset($input['documento'])) {
                echo json_encode(['success' => false, 'message' => 'Datos incompletos']);
                break;
            }
            
            $stmt = $conn->prepare("INSERT INTO participantes (nombres, apellidos, documento, tipo_documento, email, telefono) VALUES (?, ?, ?, ?, ?, ?)");
            
            if ($stmt->execute([
                $input['nombres'],
                $input['apellidos'],
                $input['documento'],
                $input['tipo_documento'] ?? 'CC',
                $input['email'] ?? '',
                $input['telefono'] ?? ''
            ])) {
                echo json_encode(['success' => true, 'message' => 'Participante creado exitosamente', 'id' => $conn->lastInsertId()]);
            } else {
                echo json_encode(['success' => false, 'message' => 'Error al crear participante']);
            }
            break;
            
        case 'PUT':
            $input = json_decode(file_get_contents('php://input'), true);
            
            if (!isset($input['id'])) {
                echo json_encode(['success' => false, 'message' => 'ID requerido']);
                break;
            }
            
            $stmt = $conn->prepare("UPDATE participantes SET nombres=?, apellidos=?, documento=?, tipo_documento=?, email=?, telefono=? WHERE id=?");
            
            if ($stmt->execute([
                $input['nombres'],
                $input['apellidos'],
                $input['documento'],
                $input['tipo_documento'],
                $input['email'],
                $input['telefono'],
                $input['id']
            ])) {
                echo json_encode(['success' => true, 'message' => 'Participante actualizado exitosamente']);
            } else {
                echo json_encode(['success' => false, 'message' => 'Error al actualizar participante']);
            }
            break;
            
        case 'DELETE':
            if (!isset($_GET['id'])) {
                echo json_encode(['success' => false, 'message' => 'ID requerido']);
                break;
            }
            
            $stmt = $conn->prepare("DELETE FROM participantes WHERE id = ?");
            
            if ($stmt->execute([$_GET['id']])) {
                echo json_encode(['success' => true, 'message' => 'Participante eliminado exitosamente']);
            } else {
                echo json_encode(['success' => false, 'message' => 'Error al eliminar participante']);
            }
            break;
            
        default:
            echo json_encode(['success' => false, 'message' => 'Método no permitido']);
    }
    
} catch (Exception $e) {
    echo json_encode(['success' => false, 'message' => 'Error: ' . $e->getMessage()]);
}
?>
