<?php
// SISTEMA SIMPLE DE CERTIFICADOS - VERSIÓN CORREGIDA
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Configuración de base de datos
$host = 'localhost';
$dbname = 'wwesib_bomberos_certificados';
$username = 'wwesib_bomberos_certificados';
$password = 'Serrano10$';

// Conectar a la base de datos
try {
    $pdo = new PDO("mysql:host=$host;dbname=$dbname;charset=utf8mb4", $username, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    $conexion_ok = true;
} catch(PDOException $e) {
    $conexion_ok = false;
    $error_conexion = $e->getMessage();
}

// Procesar formularios
$mensaje = '';
if ($_POST && $conexion_ok) {
    if ($_POST['accion'] == 'participante') {
        try {
            $stmt = $pdo->prepare("INSERT INTO participantes (cedula, nombre, apellido, email, telefono, genero) VALUES (?, ?, ?, ?, ?, ?)");
            $stmt->execute([$_POST['cedula'], $_POST['nombre'], $_POST['apellido'], $_POST['email'], $_POST['telefono'], $_POST['genero']]);
            $mensaje = "✅ Participante creado exitosamente";
        } catch(Exception $e) {
            $mensaje = "❌ Error: " . $e->getMessage();
        }
    }
    
    if ($_POST['accion'] == 'curso') {
        try {
            $stmt = $pdo->prepare("INSERT INTO cursos (nombre, descripcion, duracion_horas, fecha_inicio, instructor) VALUES (?, ?, ?, ?, ?)");
            $stmt->execute([$_POST['nombre'], $_POST['descripcion'], $_POST['duracion'], $_POST['fecha_inicio'], $_POST['instructor']]);
            $mensaje = "✅ Curso creado exitosamente";
        } catch(Exception $e) {
            $mensaje = "❌ Error: " . $e->getMessage();
        }
    }
    
    if ($_POST['accion'] == 'certificado') {
        try {
            $codigo = 'CERT-' . date('Y') . '-' . str_pad(rand(1, 9999), 4, '0', STR_PAD_LEFT);
            $stmt = $pdo->prepare("INSERT INTO certificados (participante_id, curso_id, codigo, fecha_emision, estado) VALUES (?, ?, ?, NOW(), 'emitido')");
            $stmt->execute([$_POST['participante_id'], $_POST['curso_id'], $codigo]);
            $mensaje = "✅ Certificado generado: $codigo";
        } catch(Exception $e) {
            $mensaje = "❌ Error: " . $e->getMessage();
        }
    }
}

// Obtener datos
$participantes = [];
$cursos = [];
$certificados = [];

if ($conexion_ok) {
    try {
        $participantes = $pdo->query("SELECT * FROM participantes ORDER BY nombre")->fetchAll();
        $cursos = $pdo->query("SELECT * FROM cursos ORDER BY id DESC")->fetchAll();
        
        // Consulta corregida para certificados
        $certificados = $pdo->query("
            SELECT cert.*, p.nombre as participante_nombre, p.apellido, c.nombre as curso_nombre 
            FROM certificados cert 
            LEFT JOIN participantes p ON cert.participante_id = p.id 
            LEFT JOIN cursos c ON cert.curso_id = c.id 
            ORDER BY cert.fecha_emision DESC
        ")->fetchAll();
    } catch(Exception $e) {
        // Si hay error, intentar consulta más simple
        try {
            $certificados = $pdo->query("SELECT * FROM certificados ORDER BY fecha_emision DESC")->fetchAll();
        } catch(Exception $e2) {
            $mensaje = "❌ Error al obtener certificados: " . $e2->getMessage();
        }
    }
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Sistema de Certificados ESIBOC</title>
    <style>
        body { font-family: Arial, sans-serif; margin: 0; padding: 20px; background: #f5f5f5; }
        .container { max-width: 1200px; margin: 0 auto; }
        .header { background: #2c3e50; color: white; padding: 20px; text-align: center; margin-bottom: 20px; border-radius: 8px; }
        .section { background: white; padding: 20px; margin-bottom: 20px; border-radius: 8px; box-shadow: 0 2px 4px rgba(0,0,0,0.1); }
        .form-group { margin-bottom: 15px; }
        .form-group label { display: block; margin-bottom: 5px; font-weight: bold; color: #333; }
        .form-group input, .form-group select, .form-group textarea { width: 100%; padding: 10px; border: 1px solid #ddd; border-radius: 4px; box-sizing: border-box; }
        .btn { padding: 12px 24px; background: #27ae60; color: white; border: none; cursor: pointer; border-radius: 4px; font-size: 16px; }
        .btn:hover { background: #229954; }
        .btn-secondary { background: #3498db; }
        .btn-secondary:hover { background: #2980b9; }
        table { width: 100%; border-collapse: collapse; margin-top: 15px; }
        th, td { padding: 12px; text-align: left; border-bottom: 1px solid #ddd; }
        th { background: #f8f9fa; font-weight: bold; }
        .mensaje { padding: 15px; margin-bottom: 20px; border-radius: 5px; font-weight: bold; }
        .mensaje.exito { background: #d4edda; color: #155724; border: 1px solid #c3e6cb; }
        .mensaje.error { background: #f8d7da; color: #721c24; border: 1px solid #f5c6cb; }
        .grid { display: grid; grid-template-columns: 1fr 1fr; gap: 20px; }
        .stats { display: grid; grid-template-columns: repeat(auto-fit, minmax(200px, 1fr)); gap: 15px; margin-bottom: 20px; }
        .stat-card { background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); color: white; padding: 20px; border-radius: 8px; text-align: center; }
        .stat-number { font-size: 2em; font-weight: bold; }
        .stat-label { font-size: 0.9em; opacity: 0.9; }
        @media (max-width: 768px) { .grid { grid-template-columns: 1fr; } }
    </style>
</head>
<body>
    <div class="container">
        <div class="header">
            <h1>🔥 Sistema de Certificados ESIBOC</h1>
            <p>Escuela Internacional de Bomberos del Oriente Colombiano</p>
        </div>

        <!-- ESTADÍSTICAS -->
        <div class="stats">
            <div class="stat-card">
                <div class="stat-number"><?php echo count($participantes); ?></div>
                <div class="stat-label">Participantes</div>
            </div>
            <div class="stat-card">
                <div class="stat-number"><?php echo count($cursos); ?></div>
                <div class="stat-label">Cursos</div>
            </div>
            <div class="stat-card">
                <div class="stat-number"><?php echo count($certificados); ?></div>
                <div class="stat-label">Certificados</div>
            </div>
        </div>

        <?php if (!$conexion_ok): ?>
            <div class="mensaje error">
                ❌ Error de conexión a la base de datos: <?php echo $error_conexion; ?>
            </div>
        <?php else: ?>
            <div class="mensaje exito">
                ✅ Conexión a la base de datos exitosa
            </div>
        <?php endif; ?>

        <?php if ($mensaje): ?>
            <div class="mensaje <?php echo strpos($mensaje, '✅') !== false ? 'exito' : 'error'; ?>">
                <?php echo $mensaje; ?>
            </div>
        <?php endif; ?>

        <!-- PARTICIPANTES -->
        <div class="section">
            <h2>👥 Gestión de Participantes</h2>
            <div class="grid">
                <div>
                    <h3>Nuevo Participante</h3>
                    <form method="POST">
                        <input type="hidden" name="accion" value="participante">
                        <div class="form-group">
                            <label>Cédula:</label>
                            <input type="text" name="cedula" required placeholder="Ej: 12345678">
                        </div>
                        <div class="form-group">
                            <label>Nombre:</label>
                            <input type="text" name="nombre" required placeholder="Ej: Juan Carlos">
                        </div>
                        <div class="form-group">
                            <label>Apellido:</label>
                            <input type="text" name="apellido" required placeholder="Ej: Pérez López">
                        </div>
                        <div class="form-group">
                            <label>Email:</label>
                            <input type="email" name="email" placeholder="Ej: juan@email.com">
                        </div>
                        <div class="form-group">
                            <label>Teléfono:</label>
                            <input type="text" name="telefono" placeholder="Ej: 3001234567">
                        </div>
                        <div class="form-group">
                            <label>Género:</label>
                            <select name="genero">
                                <option value="M">Masculino</option>
                                <option value="F">Femenino</option>
                            </select>
                        </div>
                        <button type="submit" class="btn">Crear Participante</button>
                    </form>
                </div>
                <div>
                    <h3>Lista de Participantes (<?php echo count($participantes); ?>)</h3>
                    <div style="max-height: 400px; overflow-y: auto;">
                        <table>
                            <tr><th>Cédula</th><th>Nombre Completo</th><th>Email</th></tr>
                            <?php foreach ($participantes as $p): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($p['cedula']); ?></td>
                                    <td><?php echo htmlspecialchars($p['nombre'] . ' ' . $p['apellido']); ?></td>
                                    <td><?php echo htmlspecialchars($p['email']); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </table>
                    </div>
                </div>
            </div>
        </div>

        <!-- CURSOS -->
        <div class="section">
            <h2>📚 Gestión de Cursos</h2>
            <div class="grid">
                <div>
                    <h3>Nuevo Curso</h3>
                    <form method="POST">
                        <input type="hidden" name="accion" value="curso">
                        <div class="form-group">
                            <label>Nombre del Curso:</label>
                            <input type="text" name="nombre" required placeholder="Ej: Primeros Auxilios Básicos">
                        </div>
                        <div class="form-group">
                            <label>Descripción:</label>
                            <textarea name="descripcion" rows="3" placeholder="Descripción del curso..."></textarea>
                        </div>
                        <div class="form-group">
                            <label>Duración (horas):</label>
                            <input type="number" name="duracion" required placeholder="Ej: 40">
                        </div>
                        <div class="form-group">
                            <label>Fecha de Inicio:</label>
                            <input type="date" name="fecha_inicio" required>
                        </div>
                        <div class="form-group">
                            <label>Instructor:</label>
                            <input type="text" name="instructor" placeholder="Ej: Dr. Carlos Martínez">
                        </div>
                        <button type="submit" class="btn">Crear Curso</button>
                    </form>
                </div>
                <div>
                    <h3>Lista de Cursos (<?php echo count($cursos); ?>)</h3>
                    <div style="max-height: 400px; overflow-y: auto;">
                        <table>
                            <tr><th>Nombre</th><th>Duración</th><th>Instructor</th><th>Fecha</th></tr>
                            <?php foreach ($cursos as $c): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($c['nombre']); ?></td>
                                    <td><?php echo $c['duracion_horas']; ?>h</td>
                                    <td><?php echo htmlspecialchars($c['instructor']); ?></td>
                                    <td><?php echo $c['fecha_inicio']; ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </table>
                    </div>
                </div>
            </div>
        </div>

        <!-- CERTIFICADOS -->
        <div class="section">
            <h2>🏆 Gestión de Certificados</h2>
            <div class="grid">
                <div>
                    <h3>Generar Certificado</h3>
                    <form method="POST">
                        <input type="hidden" name="accion" value="certificado">
                        <div class="form-group">
                            <label>Participante:</label>
                            <select name="participante_id" required>
                                <option value="">Seleccionar participante...</option>
                                <?php foreach ($participantes as $p): ?>
                                    <option value="<?php echo $p['id']; ?>">
                                        <?php echo htmlspecialchars($p['nombre'] . ' ' . $p['apellido'] . ' (' . $p['cedula'] . ')'); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="form-group">
                            <label>Curso:</label>
                            <select name="curso_id" required>
                                <option value="">Seleccionar curso...</option>
                                <?php foreach ($cursos as $c): ?>
                                    <option value="<?php echo $c['id']; ?>">
                                        <?php echo htmlspecialchars($c['nombre'] . ' (' . $c['duracion_horas'] . 'h)'); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <button type="submit" class="btn">Generar Certificado</button>
                    </form>
                </div>
                <div>
                    <h3>Lista de Certificados (<?php echo count($certificados); ?>)</h3>
                    <div style="max-height: 400px; overflow-y: auto;">
                        <table>
                            <tr><th>Código</th><th>Participante</th><th>Curso</th><th>Fecha</th></tr>
                            <?php foreach ($certificados as $cert): ?>
                                <tr>
                                    <td><strong><?php echo htmlspecialchars($cert['codigo']); ?></strong></td>
                                    <td>
                                        <?php 
                                        if (isset($cert['participante_nombre'])) {
                                            echo htmlspecialchars($cert['participante_nombre'] . ' ' . $cert['apellido']);
                                        } else {
                                            echo 'ID: ' . $cert['participante_id'];
                                        }
                                        ?>
                                    </td>
                                    <td>
                                        <?php 
                                        if (isset($cert['curso_nombre'])) {
                                            echo htmlspecialchars($cert['curso_nombre']);
                                        } else {
                                            echo 'ID: ' . $cert['curso_id'];
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo $cert['fecha_emision']; ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </table>
                    </div>
                </div>
            </div>
        </div>

        <!-- VERIFICADOR -->
        <div class="section">
            <h2>🔍 Verificar Certificado</h2>
            <form method="GET" action="verificar-certificado.php" target="_blank">
                <div class="form-group">
                    <label>Código del Certificado:</label>
                    <input type="text" name="codigo" placeholder="Ej: CERT-2025-0001" required>
                </div>
                <button type="submit" class="btn btn-secondary">Verificar Certificado</button>
            </form>
        </div>
    </div>
</body>
</html>
