<?php
// SISTEMA SIMPLE DE CERTIFICADOS - GARANTIZADO QUE FUNCIONA
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Configuración de base de datos
$host = 'localhost';
$dbname = 'wwesib_bomberos_certificados';
$username = 'wwesib_bomberos_certificados';
$password = 'Serrano10$';

// Conectar a la base de datos
try {
    $pdo = new PDO("mysql:host=$host;dbname=$dbname;charset=utf8mb4", $username, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    $conexion_ok = true;
} catch(PDOException $e) {
    $conexion_ok = false;
    $error_conexion = $e->getMessage();
}

// Procesar formularios
$mensaje = '';
if ($_POST && $conexion_ok) {
    if ($_POST['accion'] == 'participante') {
        try {
            $stmt = $pdo->prepare("INSERT INTO participantes (cedula, nombre, apellido, email, telefono, genero) VALUES (?, ?, ?, ?, ?, ?)");
            $stmt->execute([$_POST['cedula'], $_POST['nombre'], $_POST['apellido'], $_POST['email'], $_POST['telefono'], $_POST['genero']]);
            $mensaje = "✅ Participante creado exitosamente";
        } catch(Exception $e) {
            $mensaje = "❌ Error: " . $e->getMessage();
        }
    }
    
    if ($_POST['accion'] == 'curso') {
        try {
            $stmt = $pdo->prepare("INSERT INTO cursos (nombre, descripcion, duracion_horas, fecha_inicio, instructor) VALUES (?, ?, ?, ?, ?)");
            $stmt->execute([$_POST['nombre'], $_POST['descripcion'], $_POST['duracion'], $_POST['fecha_inicio'], $_POST['instructor']]);
            $mensaje = "✅ Curso creado exitosamente";
        } catch(Exception $e) {
            $mensaje = "❌ Error: " . $e->getMessage();
        }
    }
    
    if ($_POST['accion'] == 'certificado') {
        try {
            $codigo = 'CERT-' . date('Y') . '-' . str_pad(rand(1, 9999), 4, '0', STR_PAD_LEFT);
            $stmt = $pdo->prepare("INSERT INTO certificados (participante_id, curso_id, codigo, fecha_emision, estado) VALUES (?, ?, ?, NOW(), 'emitido')");
            $stmt->execute([$_POST['participante_id'], $_POST['curso_id'], $codigo]);
            $mensaje = "✅ Certificado generado: $codigo";
        } catch(Exception $e) {
            $mensaje = "❌ Error: " . $e->getMessage();
        }
    }
}

// Obtener datos
$participantes = [];
$cursos = [];
$certificados = [];

if ($conexion_ok) {
    try {
        $participantes = $pdo->query("SELECT * FROM participantes ORDER BY nombre")->fetchAll();
        $cursos = $pdo->query("SELECT * FROM cursos ORDER BY id DESC")->fetchAll();
        $certificados = $pdo->query("
            SELECT cert.*, p.nombre as participante_nombre, p.apellido, c.nombre as curso_nombre 
            FROM certificados cert 
            JOIN participantes p ON cert.participante_id = p.id 
            JOIN cursos c ON cert.curso_id = c.id 
            ORDER BY cert.fecha_emision DESC
        ")->fetchAll();
    } catch(Exception $e) {
        $mensaje = "❌ Error al obtener datos: " . $e->getMessage();
    }
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Sistema de Certificados ESIBOC</title>
    <style>
        body { font-family: Arial, sans-serif; margin: 0; padding: 20px; background: #f5f5f5; }
        .container { max-width: 1000px; margin: 0 auto; }
        .header { background: #2c3e50; color: white; padding: 20px; text-align: center; margin-bottom: 20px; }
        .section { background: white; padding: 20px; margin-bottom: 20px; border-radius: 5px; }
        .form-group { margin-bottom: 15px; }
        .form-group label { display: block; margin-bottom: 5px; font-weight: bold; }
        .form-group input, .form-group select { width: 100%; padding: 8px; border: 1px solid #ddd; }
        .btn { padding: 10px 20px; background: #27ae60; color: white; border: none; cursor: pointer; }
        .btn:hover { background: #229954; }
        table { width: 100%; border-collapse: collapse; margin-top: 15px; }
        th, td { padding: 8px; text-align: left; border-bottom: 1px solid #ddd; }
        th { background: #f8f9fa; }
        .mensaje { padding: 15px; margin-bottom: 20px; border-radius: 5px; }
        .mensaje.exito { background: #d4edda; color: #155724; }
        .mensaje.error { background: #f8d7da; color: #721c24; }
        .grid { display: grid; grid-template-columns: 1fr 1fr; gap: 20px; }
    </style>
</head>
<body>
    <div class="container">
        <div class="header">
            <h1>🔥 Sistema de Certificados ESIBOC</h1>
            <p>Escuela Internacional de Bomberos del Oriente Colombiano</p>
        </div>

        <?php if (!$conexion_ok): ?>
            <div class="mensaje error">
                ❌ Error de conexión a la base de datos: <?php echo $error_conexion; ?>
            </div>
        <?php else: ?>
            <div class="mensaje exito">
                ✅ Conexión a la base de datos exitosa
            </div>
        <?php endif; ?>

        <?php if ($mensaje): ?>
            <div class="mensaje <?php echo strpos($mensaje, '✅') !== false ? 'exito' : 'error'; ?>">
                <?php echo $mensaje; ?>
            </div>
        <?php endif; ?>

        <!-- PARTICIPANTES -->
        <div class="section">
            <h2>👥 Participantes</h2>
            <div class="grid">
                <div>
                    <h3>Nuevo Participante</h3>
                    <form method="POST">
                        <input type="hidden" name="accion" value="participante">
                        <div class="form-group">
                            <label>Cédula:</label>
                            <input type="text" name="cedula" required>
                        </div>
                        <div class="form-group">
                            <label>Nombre:</label>
                            <input type="text" name="nombre" required>
                        </div>
                        <div class="form-group">
                            <label>Apellido:</label>
                            <input type="text" name="apellido" required>
                        </div>
                        <div class="form-group">
                            <label>Email:</label>
                            <input type="email" name="email">
                        </div>
                        <div class="form-group">
                            <label>Teléfono:</label>
                            <input type="text" name="telefono">
                        </div>
                        <div class="form-group">
                            <label>Género:</label>
                            <select name="genero">
                                <option value="M">Masculino</option>
                                <option value="F">Femenino</option>
                            </select>
                        </div>
                        <button type="submit" class="btn">Crear Participante</button>
                    </form>
                </div>
                <div>
                    <h3>Lista de Participantes (<?php echo count($participantes); ?>)</h3>
                    <table>
                        <tr><th>Cédula</th><th>Nombre</th><th>Email</th></tr>
                        <?php foreach ($participantes as $p): ?>
                            <tr>
                                <td><?php echo $p['cedula']; ?></td>
                                <td><?php echo $p['nombre'] . ' ' . $p['apellido']; ?></td>
                                <td><?php echo $p['email']; ?></td>
                            </tr>
                        <?php endforeach; ?>
                    </table>
                </div>
            </div>
        </div>

        <!-- CURSOS -->
        <div class="section">
            <h2>📚 Cursos</h2>
            <div class="grid">
                <div>
                    <h3>Nuevo Curso</h3>
                    <form method="POST">
                        <input type="hidden" name="accion" value="curso">
                        <div class="form-group">
                            <label>Nombre del Curso:</label>
                            <input type="text" name="nombre" required>
                        </div>
                        <div class="form-group">
                            <label>Descripción:</label>
                            <input type="text" name="descripcion">
                        </div>
                        <div class="form-group">
                            <label>Duración (horas):</label>
                            <input type="number" name="duracion" required>
                        </div>
                        <div class="form-group">
                            <label>Fecha Inicio:</label>
                            <input type="date" name="fecha_inicio" required>
                        </div>
                        <div class="form-group">
                            <label>Instructor:</label>
                            <input type="text" name="instructor">
                        </div>
                        <button type="submit" class="btn">Crear Curso</button>
                    </form>
                </div>
                <div>
                    <h3>Lista de Cursos (<?php echo count($cursos); ?>)</h3>
                    <table>
                        <tr><th>Nombre</th><th>Duración</th><th>Instructor</th></tr>
                        <?php foreach ($cursos as $c): ?>
                            <tr>
                                <td><?php echo $c['nombre']; ?></td>
                                <td><?php echo $c['duracion_horas']; ?>h</td>
                                <td><?php echo $c['instructor']; ?></td>
                            </tr>
                        <?php endforeach; ?>
                    </table>
                </div>
            </div>
        </div>

        <!-- CERTIFICADOS -->
        <div class="section">
            <h2>🏆 Certificados</h2>
            <div class="grid">
                <div>
                    <h3>Generar Certificado</h3>
                    <form method="POST">
                        <input type="hidden" name="accion" value="certificado">
                        <div class="form-group">
                            <label>Participante:</label>
                            <select name="participante_id" required>
                                <option value="">Seleccionar...</option>
                                <?php foreach ($participantes as $p): ?>
                                    <option value="<?php echo $p['id']; ?>">
                                        <?php echo $p['nombre'] . ' ' . $p['apellido'] . ' (' . $p['cedula'] . ')'; ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="form-group">
                            <label>Curso:</label>
                            <select name="curso_id" required>
                                <option value="">Seleccionar...</option>
                                <?php foreach ($cursos as $c): ?>
                                    <option value="<?php echo $c['id']; ?>"><?php echo $c['nombre']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <button type="submit" class="btn">Generar Certificado</button>
                    </form>
                </div>
                <div>
                    <h3>Lista de Certificados (<?php echo count($certificados); ?>)</h3>
                    <table>
                        <tr><th>Código</th><th>Participante</th><th>Curso</th></tr>
                        <?php foreach ($certificados as $cert): ?>
                            <tr>
                                <td><strong><?php echo $cert['codigo']; ?></strong></td>
                                <td><?php echo $cert['participante_nombre'] . ' ' . $cert['apellido']; ?></td>
                                <td><?php echo $cert['curso_nombre']; ?></td>
                            </tr>
                        <?php endforeach; ?>
                    </table>
                </div>
            </div>
        </div>
    </div>
</body>
</html>
