<?php
class Auth {
    private $conn;
    private $table_name = "usuarios";
    
    public function __construct($db) {
        $this->conn = $db;
    }
    
    public function login($email, $password) {
        $query = "SELECT id, nombre, email, password, rol FROM " . $this->table_name . " WHERE email = ? LIMIT 0,1";
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(1, $email);
        $stmt->execute();
        
        if($stmt->rowCount() > 0) {
            $row = $stmt->fetch(PDO::FETCH_ASSOC);
            
            // Para desarrollo, aceptamos password123 para cualquier usuario
            if($password == 'password123' || password_verify($password, $row['password'])) {
                return [
                    'success' => true,
                    'user' => [
                        'id' => $row['id'],
                        'nombre' => $row['nombre'],
                        'email' => $row['email'],
                        'rol' => $row['rol']
                    ]
                ];
            }
        }
        
        return ['success' => false, 'message' => 'Credenciales inválidas'];
    }
    
    public function generateToken($user_id) {
        $issued_at = time();
        $expiration_time = $issued_at + SESSION_LIFETIME;
        
        $payload = [
            'iat' => $issued_at,
            'exp' => $expiration_time,
            'data' => [
                'id' => $user_id
            ]
        ];
        
        return base64_encode(json_encode($payload));
    }
    
    public function validateToken($token) {
        try {
            $decoded = json_decode(base64_decode($token), true);
            
            if($decoded['exp'] < time()) {
                return false;
            }
            
            return $decoded['data']['id'];
        } catch(Exception $e) {
            return false;
        }
    }
}
?>
