<?php
class Curso {
    private $conn;
    private $table_name = "cursos";
    
    public $id;
    public $nombre;
    public $descripcion;
    public $tipo;
    public $modalidad;
    public $duracion_horas;
    public $fecha_inicio;
    public $fecha_fin;
    public $instructor;
    public $lugar;
    public $cupo_maximo;
    public $costo;
    public $estado;
    
    public function __construct($db) {
        $this->conn = $db;
    }
    
    public function read() {
        $query = "SELECT * FROM " . $this->table_name . " ORDER BY fecha_inicio DESC";
        $stmt = $this->conn->prepare($query);
        $stmt->execute();
        
        return $stmt;
    }
    
    public function readOne() {
        $query = "SELECT * FROM " . $this->table_name . " WHERE id = ? LIMIT 0,1";
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(1, $this->id);
        $stmt->execute();
        
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if($row) {
            $this->nombre = $row['nombre'];
            $this->descripcion = $row['descripcion'];
            $this->tipo = $row['tipo'];
            $this->modalidad = $row['modalidad'];
            $this->duracion_horas = $row['duracion_horas'];
            $this->fecha_inicio = $row['fecha_inicio'];
            $this->fecha_fin = $row['fecha_fin'];
            $this->instructor = $row['instructor'];
            $this->lugar = $row['lugar'];
            $this->cupo_maximo = $row['cupo_maximo'];
            $this->costo = $row['costo'];
            $this->estado = $row['estado'];
            
            return true;
        }
        
        return false;
    }
    
    public function create() {
        $query = "INSERT INTO " . $this->table_name . " 
                  SET nombre=:nombre, descripcion=:descripcion, tipo=:tipo, 
                      modalidad=:modalidad, duracion_horas=:duracion_horas, 
                      fecha_inicio=:fecha_inicio, fecha_fin=:fecha_fin, 
                      instructor=:instructor, lugar=:lugar, 
                      cupo_maximo=:cupo_maximo, costo=:costo, estado=:estado";
        
        $stmt = $this->conn->prepare($query);
        
        // Sanitizar datos
        $this->nombre = htmlspecialchars(strip_tags($this->nombre));
        $this->descripcion = htmlspecialchars(strip_tags($this->descripcion));
        $this->tipo = htmlspecialchars(strip_tags($this->tipo));
        $this->modalidad = htmlspecialchars(strip_tags($this->modalidad));
        $this->duracion_horas = htmlspecialchars(strip_tags($this->duracion_horas));
        $this->fecha_inicio = htmlspecialchars(strip_tags($this->fecha_inicio));
        $this->fecha_fin = htmlspecialchars(strip_tags($this->fecha_fin));
        $this->instructor = htmlspecialchars(strip_tags($this->instructor));
        $this->lugar = htmlspecialchars(strip_tags($this->lugar));
        $this->cupo_maximo = htmlspecialchars(strip_tags($this->cupo_maximo));
        $this->costo = htmlspecialchars(strip_tags($this->costo));
        $this->estado = htmlspecialchars(strip_tags($this->estado));
        
        // Vincular valores
        $stmt->bindParam(":nombre", $this->nombre);
        $stmt->bindParam(":descripcion", $this->descripcion);
        $stmt->bindParam(":tipo", $this->tipo);
        $stmt->bindParam(":modalidad", $this->modalidad);
        $stmt->bindParam(":duracion_horas", $this->duracion_horas);
        $stmt->bindParam(":fecha_inicio", $this->fecha_inicio);
        $stmt->bindParam(":fecha_fin", $this->fecha_fin);
        $stmt->bindParam(":instructor", $this->instructor);
        $stmt->bindParam(":lugar", $this->lugar);
        $stmt->bindParam(":cupo_maximo", $this->cupo_maximo);
        $stmt->bindParam(":costo", $this->costo);
        $stmt->bindParam(":estado", $this->estado);
        
        if($stmt->execute()) {
            $this->id = $this->conn->lastInsertId();
            return true;
        }
        
        return false;
    }
    
    public function update() {
        $query = "UPDATE " . $this->table_name . " 
                  SET nombre=:nombre, descripcion=:descripcion, tipo=:tipo, 
                      modalidad=:modalidad, duracion_horas=:duracion_horas, 
                      fecha_inicio=:fecha_inicio, fecha_fin=:fecha_fin, 
                      instructor=:instructor, lugar=:lugar, 
                      cupo_maximo=:cupo_maximo, costo=:costo, estado=:estado 
                  WHERE id=:id";
        
        $stmt = $this->conn->prepare($query);
        
        // Sanitizar datos
        $this->id = htmlspecialchars(strip_tags($this->id));
        $this->nombre = htmlspecialchars(strip_tags($this->nombre));
        $this->descripcion = htmlspecialchars(strip_tags($this->descripcion));
        $this->tipo = htmlspecialchars(strip_tags($this->tipo));
        $this->modalidad = htmlspecialchars(strip_tags($this->modalidad));
        $this->duracion_horas = htmlspecialchars(strip_tags($this->duracion_horas));
        $this->fecha_inicio = htmlspecialchars(strip_tags($this->fecha_inicio));
        $this->fecha_fin = htmlspecialchars(strip_tags($this->fecha_fin));
        $this->instructor = htmlspecialchars(strip_tags($this->instructor));
        $this->lugar = htmlspecialchars(strip_tags($this->lugar));
        $this->cupo_maximo = htmlspecialchars(strip_tags($this->cupo_maximo));
        $this->costo = htmlspecialchars(strip_tags($this->costo));
        $this->estado = htmlspecialchars(strip_tags($this->estado));
        
        // Vincular valores
        $stmt->bindParam(":id", $this->id);
        $stmt->bindParam(":nombre", $this->nombre);
        $stmt->bindParam(":descripcion", $this->descripcion);
        $stmt->bindParam(":tipo", $this->tipo);
        $stmt->bindParam(":modalidad", $this->modalidad);
        $stmt->bindParam(":duracion_horas", $this->duracion_horas);
        $stmt->bindParam(":fecha_inicio", $this->fecha_inicio);
        $stmt->bindParam(":fecha_fin", $this->fecha_fin);
        $stmt->bindParam(":instructor", $this->instructor);
        $stmt->bindParam(":lugar", $this->lugar);
        $stmt->bindParam(":cupo_maximo", $this->cupo_maximo);
        $stmt->bindParam(":costo", $this->costo);
        $stmt->bindParam(":estado", $this->estado);
        
        if($stmt->execute()) {
            return true;
        }
        
        return false;
    }
    
    public function delete() {
        $query = "DELETE FROM " . $this->table_name . " WHERE id = ?";
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(1, $this->id);
        
        if($stmt->execute()) {
            return true;
        }
        
        return false;
    }
    
    public function search($keywords) {
        $query = "SELECT * FROM " . $this->table_name . " 
                  WHERE nombre LIKE ? OR descripcion LIKE ? OR instructor LIKE ? OR lugar LIKE ? 
                  ORDER BY fecha_inicio DESC";
        
        $stmt = $this->conn->prepare($query);
        
        $keywords = "%{$keywords}%";
        $stmt->bindParam(1, $keywords);
        $stmt->bindParam(2, $keywords);
        $stmt->bindParam(3, $keywords);
        $stmt->bindParam(4, $keywords);
        
        $stmt->execute();
        
        return $stmt;
    }
    
    public function getActiveCourses() {
        $query = "SELECT * FROM " . $this->table_name . " WHERE estado = 'activo' ORDER BY fecha_inicio DESC";
        $stmt = $this->conn->prepare($query);
        $stmt->execute();
        
        return $stmt;
    }
}
?>
