<?php
class Participante {
    private $conn;
    private $table_name = "participantes";
    
    public $id;
    public $cedula;
    public $nombre;
    public $apellido;
    public $email;
    public $telefono;
    public $genero;
    
    public function __construct($db) {
        $this->conn = $db;
    }
    
    public function read() {
        $query = "SELECT * FROM " . $this->table_name . " ORDER BY apellido, nombre";
        $stmt = $this->conn->prepare($query);
        $stmt->execute();
        
        return $stmt;
    }
    
    public function readOne() {
        $query = "SELECT * FROM " . $this->table_name . " WHERE id = ? LIMIT 0,1";
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(1, $this->id);
        $stmt->execute();
        
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if($row) {
            $this->cedula = $row['cedula'];
            $this->nombre = $row['nombre'];
            $this->apellido = $row['apellido'];
            $this->email = $row['email'];
            $this->telefono = $row['telefono'];
            $this->genero = $row['genero'];
            
            return true;
        }
        
        return false;
    }
    
    public function create() {
        $query = "INSERT INTO " . $this->table_name . " 
                  SET cedula=:cedula, nombre=:nombre, apellido=:apellido, 
                      email=:email, telefono=:telefono, genero=:genero, 
                      fecha_registro=:fecha_registro";
        
        $stmt = $this->conn->prepare($query);
        
        // Sanitizar datos
        $this->cedula = htmlspecialchars(strip_tags($this->cedula));
        $this->nombre = htmlspecialchars(strip_tags($this->nombre));
        $this->apellido = htmlspecialchars(strip_tags($this->apellido));
        $this->email = htmlspecialchars(strip_tags($this->email));
        $this->telefono = htmlspecialchars(strip_tags($this->telefono));
        $this->genero = htmlspecialchars(strip_tags($this->genero));
        
        $fecha_registro = date('Y-m-d H:i:s');
        
        // Vincular valores
        $stmt->bindParam(":cedula", $this->cedula);
        $stmt->bindParam(":nombre", $this->nombre);
        $stmt->bindParam(":apellido", $this->apellido);
        $stmt->bindParam(":email", $this->email);
        $stmt->bindParam(":telefono", $this->telefono);
        $stmt->bindParam(":genero", $this->genero);
        $stmt->bindParam(":fecha_registro", $fecha_registro);
        
        if($stmt->execute()) {
            $this->id = $this->conn->lastInsertId();
            return true;
        }
        
        return false;
    }
    
    public function update() {
        $query = "UPDATE " . $this->table_name . " 
                  SET cedula=:cedula, nombre=:nombre, apellido=:apellido, 
                      email=:email, telefono=:telefono, genero=:genero, 
                      fecha_actualizacion=:fecha_actualizacion 
                  WHERE id=:id";
        
        $stmt = $this->conn->prepare($query);
        
        // Sanitizar datos
        $this->id = htmlspecialchars(strip_tags($this->id));
        $this->cedula = htmlspecialchars(strip_tags($this->cedula));
        $this->nombre = htmlspecialchars(strip_tags($this->nombre));
        $this->apellido = htmlspecialchars(strip_tags($this->apellido));
        $this->email = htmlspecialchars(strip_tags($this->email));
        $this->telefono = htmlspecialchars(strip_tags($this->telefono));
        $this->genero = htmlspecialchars(strip_tags($this->genero));
        
        $fecha_actualizacion = date('Y-m-d H:i:s');
        
        // Vincular valores
        $stmt->bindParam(":id", $this->id);
        $stmt->bindParam(":cedula", $this->cedula);
        $stmt->bindParam(":nombre", $this->nombre);
        $stmt->bindParam(":apellido", $this->apellido);
        $stmt->bindParam(":email", $this->email);
        $stmt->bindParam(":telefono", $this->telefono);
        $stmt->bindParam(":genero", $this->genero);
        $stmt->bindParam(":fecha_actualizacion", $fecha_actualizacion);
        
        if($stmt->execute()) {
            return true;
        }
        
        return false;
    }
    
    public function delete() {
        $query = "DELETE FROM " . $this->table_name . " WHERE id = ?";
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(1, $this->id);
        
        if($stmt->execute()) {
            return true;
        }
        
        return false;
    }
    
    public function search($keywords) {
        $query = "SELECT * FROM " . $this->table_name . " 
                  WHERE cedula LIKE ? OR nombre LIKE ? OR apellido LIKE ? OR email LIKE ? 
                  ORDER BY apellido, nombre";
        
        $stmt = $this->conn->prepare($query);
        
        $keywords = "%{$keywords}%";
        $stmt->bindParam(1, $keywords);
        $stmt->bindParam(2, $keywords);
        $stmt->bindParam(3, $keywords);
        $stmt->bindParam(4, $keywords);
        
        $stmt->execute();
        
        return $stmt;
    }
}
?>
