<?php
// Incluir archivos de configuración
require_once 'config/config.php';
require_once 'config/Database.php';

// Incluir clases
require_once 'classes/Auth.php';
require_once 'classes/Participante.php';
require_once 'classes/Curso.php';
require_once 'classes/Certificado.php';

// Iniciar sesión
session_start();

// Crear conexión a la base de datos
$database = new Database();
$db = $database->getConnection();

// Verificar si hay un usuario autenticado
$auth = new Auth($db);
$user = null;

if(isset($_SESSION['user_id'])) {
    // Obtener información del usuario desde la base de datos
    $query = "SELECT id, nombre, email, rol FROM usuarios WHERE id = ? LIMIT 0,1";
    $stmt = $db->prepare($query);
    $stmt->bindParam(1, $_SESSION['user_id']);
    $stmt->execute();
    
    if($stmt->rowCount() > 0) {
        $user = $stmt->fetch(PDO::FETCH_ASSOC);
    }
}

// Procesar login
if(isset($_POST['action']) && $_POST['action'] == 'login') {
    $email = $_POST['email'] ?? '';
    $password = $_POST['password'] ?? '';
    
    $result = $auth->login($email, $password);
    
    if($result['success']) {
        $_SESSION['user_id'] = $result['user']['id'];
        $_SESSION['user_name'] = $result['user']['nombre'];
        $_SESSION['user_email'] = $result['user']['email'];
        $_SESSION['user_role'] = $result['user']['rol'];
        
        $user = $result['user'];
        
        // Redirigir para evitar reenvío del formulario
        header("Location: " . $_SERVER['PHP_SELF']);
        exit;
    } else {
        $login_error = $result['message'];
    }
}

// Procesar logout
if(isset($_GET['action']) && $_GET['action'] == 'logout') {
    session_destroy();
    header("Location: " . $_SERVER['PHP_SELF']);
    exit;
}

// Inicializar objetos
$participante = new Participante($db);
$curso = new Curso($db);
$certificado = new Certificado($db);

// Procesar acciones de participantes
if(isset($_POST['action']) && $_POST['action'] == 'crear_participante') {
    $participante->cedula = $_POST['cedula'];
    $participante->nombre = $_POST['nombre'];
    $participante->apellido = $_POST['apellido'];
    $participante->email = $_POST['email'];
    $participante->telefono = $_POST['telefono'];
    $participante->genero = $_POST['genero'];
    
    if($participante->create()) {
        $participante_success = "Participante creado exitosamente";
    } else {
        $participante_error = "Error al crear participante";
    }
}

// Procesar acciones de cursos
if(isset($_POST['action']) && $_POST['action'] == 'crear_curso') {
    $curso->nombre = $_POST['nombre'];
    $curso->descripcion = $_POST['descripcion'];
    $curso->tipo = $_POST['tipo'];
    $curso->modalidad = $_POST['modalidad'];
    $curso->duracion_horas = $_POST['duracion_horas'];
    $curso->fecha_inicio = $_POST['fecha_inicio'];
    $curso->fecha_fin = $_POST['fecha_fin'];
    $curso->instructor = $_POST['instructor'];
    $curso->lugar = $_POST['lugar'];
    $curso->cupo_maximo = $_POST['cupo_maximo'];
    $curso->costo = $_POST['costo'];
    $curso->estado = $_POST['estado'];
    
    if($curso->create()) {
        $curso_success = "Curso creado exitosamente";
    } else {
        $curso_error = "Error al crear curso";
    }
}

// Procesar acciones de certificados
if(isset($_POST['action']) && $_POST['action'] == 'crear_certificado') {
    $certificado->participante_id = $_POST['participante_id'];
    $certificado->curso_id = $_POST['curso_id'];
    $certificado->codigo = $certificado->generarCodigo();
    $certificado->estado = 'emitido';
    $certificado->archivo_pdf = '';
    
    if($certificado->create()) {
        $certificado_success = "Certificado creado exitosamente";
    } else {
        $certificado_error = "Error al crear certificado";
    }
}

// Obtener listas
$participantes = $participante->read();
$cursos = $curso->read();
$certificados = $certificado->read();

// Contar registros
$participantes_count = $participantes->rowCount();
$cursos_count = $cursos->rowCount();
$certificados_count = $certificados->rowCount();

// Obtener participantes
$participantes_list = [];
while($row = $participantes->fetch(PDO::FETCH_ASSOC)) {
    $participantes_list[] = $row;
}

// Obtener cursos
$cursos_list = [];
while($row = $cursos->fetch(PDO::FETCH_ASSOC)) {
    $cursos_list[] = $row;
}

// Obtener certificados
$certificados_list = [];
while($row = $certificados->fetch(PDO::FETCH_ASSOC)) {
    $certificados_list[] = $row;
}

// Verificar certificado
$certificado_verificado = null;
if(isset($_GET['verificar'])) {
    $codigo = $_GET['codigo'] ?? '';
    $certificado_verificado = $certificado->verificarPorCodigo($codigo);
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo APP_NAME; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css">
    <style>
        body {
            padding-top: 56px;
            min-height: 100vh;
            display: flex;
            flex-direction: column;
        }
        .content {
            flex: 1;
        }
        .navbar-brand img {
            max-height: 40px;
        }
        .card-dashboard {
            transition: transform 0.3s;
        }
        .card-dashboard:hover {
            transform: translateY(-5px);
        }
        .footer {
            margin-top: auto;
            background-color: #343a40;
            color: white;
        }
        .nav-tabs .nav-link {
            color: #495057;
        }
        .nav-tabs .nav-link.active {
            color: #007bff;
            font-weight: bold;
        }
        .certificate-code {
            font-family: monospace;
            font-size: 1.2rem;
            letter-spacing: 2px;
            background-color: #f8f9fa;
            padding: 10px;
            border-radius: 5px;
            border: 1px dashed #ced4da;
        }
        .verification-result {
            padding: 20px;
            border-radius: 5px;
            margin-top: 20px;
        }
        .verification-success {
            background-color: #d4edda;
            border: 1px solid #c3e6cb;
        }
        .verification-error {
            background-color: #f8d7da;
            border: 1px solid #f5c6cb;
        }
    </style>
</head>
<body>
    <!-- Navbar -->
    <nav class="navbar navbar-expand-lg navbar-dark bg-danger fixed-top">
        <div class="container">
            <a class="navbar-brand" href="#">
                <i class="bi bi-fire"></i> <?php echo APP_NAME; ?>
            </a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav me-auto">
                    <li class="nav-item">
                        <a class="nav-link" href="#dashboard">Inicio</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="#participantes">Participantes</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="#cursos">Cursos</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="#certificados">Certificados</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="#verificar">Verificar</a>
                    </li>
                </ul>
                <div class="d-flex">
                    <?php if($user): ?>
                        <div class="dropdown">
                            <button class="btn btn-light dropdown-toggle" type="button" data-bs-toggle="dropdown">
                                <i class="bi bi-person-circle"></i> <?php echo $user['nombre']; ?>
                            </button>
                            <ul class="dropdown-menu dropdown-menu-end">
                                <li><span class="dropdown-item-text"><?php echo $user['email']; ?></span></li>
                                <li><span class="dropdown-item-text">Rol: <?php echo ucfirst($user['rol']); ?></span></li>
                                <li><hr class="dropdown-divider"></li>
                                <li><a class="dropdown-item" href="?action=logout">Cerrar Sesión</a></li>
                            </ul>
                        </div>
                    <?php else: ?>
                        <button type="button" class="btn btn-light" data-bs-toggle="modal" data-bs-target="#loginModal">
                            <i class="bi bi-box-arrow-in-right"></i> Iniciar Sesión
                        </button>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </nav>

    <!-- Content -->
    <div class="content container py-4">
        <!-- Dashboard -->
        <section id="dashboard" class="mb-5">
            <div class="row">
                <div class="col-md-12">
                    <h2 class="mb-4">Panel de Control</h2>
                </div>
            </div>
            <div class="row">
                <div class="col-md-4 mb-4">
                    <div class="card card-dashboard border-primary h-100">
                        <div class="card-body text-center">
                            <i class="bi bi-people-fill text-primary" style="font-size: 3rem;"></i>
                            <h3 class="mt-3"><?php echo $participantes_count; ?></h3>
                            <h5 class="card-title">Participantes</h5>
                            <p class="card-text">Bomberos y personal registrado en el sistema.</p>
                            <a href="#participantes" class="btn btn-primary">Gestionar</a>
                        </div>
                    </div>
                </div>
                <div class="col-md-4 mb-4">
                    <div class="card card-dashboard border-success h-100">
                        <div class="card-body text-center">
                            <i class="bi bi-book-fill text-success" style="font-size: 3rem;"></i>
                            <h3 class="mt-3"><?php echo $cursos_count; ?></h3>
                            <h5 class="card-title">Cursos</h5>
                            <p class="card-text">Capacitaciones y entrenamientos disponibles.</p>
                            <a href="#cursos" class="btn btn-success">Gestionar</a>
                        </div>
                    </div>
                </div>
                <div class="col-md-4 mb-4">
                    <div class="card card-dashboard border-danger h-100">
                        <div class="card-body text-center">
                            <i class="bi bi-award-fill text-danger" style="font-size: 3rem;"></i>
                            <h3 class="mt-3"><?php echo $certificados_count; ?></h3>
                            <h5 class="card-title">Certificados</h5>
                            <p class="card-text">Certificados emitidos y verificables.</p>
                            <a href="#certificados" class="btn btn-danger">Gestionar</a>
                        </div>
                    </div>
                </div>
            </div>
        </section>

        <!-- Participantes -->
        <section id="participantes" class="mb-5">
            <div class="card">
                <div class="card-header bg-primary text-white">
                    <h3 class="mb-0"><i class="bi bi-people-fill"></i> Participantes</h3>
                </div>
                <div class="card-body">
                    <ul class="nav nav-tabs mb-4" id="participantesTab" role="tablist">
                        <li class="nav-item" role="presentation">
                            <button class="nav-link active" id="lista-participantes-tab" data-bs-toggle="tab" data-bs-target="#lista-participantes" type="button" role="tab">
                                Lista de Participantes
                            </button>
                        </li>
                        <li class="nav-item" role="presentation">
                            <button class="nav-link" id="nuevo-participante-tab" data-bs-toggle="tab" data-bs-target="#nuevo-participante" type="button" role="tab">
                                Nuevo Participante
                            </button>
                        </li>
                    </ul>
                    
                    <div class="tab-content" id="participantesTabContent">
                        <!-- Lista de Participantes -->
                        <div class="tab-pane fade show active" id="lista-participantes" role="tabpanel">
                            <div class="table-responsive">
                                <table class="table table-striped table-hover">
                                    <thead>
                                        <tr>
                                            <th>Cédula</th>
                                            <th>Nombre</th>
                                            <th>Apellido</th>
                                            <th>Email</th>
                                            <th>Teléfono</th>
                                            <th>Género</th>
                                            <th>Acciones</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php if($participantes_count > 0): ?>
                                            <?php foreach($participantes_list as $item): ?>
                                                <tr>
                                                    <td><?php echo $item['cedula']; ?></td>
                                                    <td><?php echo $item['nombre']; ?></td>
                                                    <td><?php echo $item['apellido']; ?></td>
                                                    <td><?php echo $item['email']; ?></td>
                                                    <td><?php echo $item['telefono']; ?></td>
                                                    <td><?php echo $item['genero'] == 'M' ? 'Masculino' : 'Femenino'; ?></td>
                                                    <td>
                                                        <button class="btn btn-sm btn-info" title="Ver detalles">
                                                            <i class="bi bi-eye"></i>
                                                        </button>
                                                        <button class="btn btn-sm btn-warning" title="Editar">
                                                            <i class="bi bi-pencil"></i>
                                                        </button>
                                                        <button class="btn btn-sm btn-danger" title="Eliminar">
                                                            <i class="bi bi-trash"></i>
                                                        </button>
                                                    </td>
                                                </tr>
                                            <?php endforeach; ?>
                                        <?php else: ?>
                                            <tr>
                                                <td colspan="7" class="text-center">No hay participantes registrados</td>
                                            </tr>
                                        <?php endif; ?>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                        
                        <!-- Nuevo Participante -->
                        <div class="tab-pane fade" id="nuevo-participante" role="tabpanel">
                            <?php if(isset($participante_success)): ?>
                                <div class="alert alert-success">
                                    <?php echo $participante_success; ?>
                                </div>
                            <?php endif; ?>
                            
                            <?php if(isset($participante_error)): ?>
                                <div class="alert alert-danger">
                                    <?php echo $participante_error; ?>
                                </div>
                            <?php endif; ?>
                            
                            <form method="post" action="">
                                <input type="hidden" name="action" value="crear_participante">
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="cedula" class="form-label">Cédula</label>
                                        <input type="text" class="form-control" id="cedula" name="cedula" required>
                                    </div>
                                    
                                    <div class="col-md-6 mb-3">
                                        <label for="genero" class="form-label">Género</label>
                                        <select class="form-select" id="genero" name="genero" required>
                                            <option value="">Seleccione...</option>
                                            <option value="M">Masculino</option>
                                            <option value="F">Femenino</option>
                                        </select>
                                    </div>
                                </div>
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="nombre" class="form-label">Nombre</label>
                                        <input type="text" class="form-control" id="nombre" name="nombre" required>
                                    </div>
                                    
                                    <div class="col-md-6 mb-3">
                                        <label for="apellido" class="form-label">Apellido</label>
                                        <input type="text" class="form-control" id="apellido" name="apellido" required>
                                    </div>
                                </div>
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="email" class="form-label">Email</label>
                                        <input type="email" class="form-control" id="email" name="email">
                                    </div>
                                    
                                    <div class="col-md-6 mb-3">
                                        <label for="telefono" class="form-label">Teléfono</label>
                                        <input type="text" class="form-control" id="telefono" name="telefono">
                                    </div>
                                </div>
                                
                                <div class="text-end">
                                    <button type="submit" class="btn btn-primary">
                                        <i class="bi bi-save"></i> Guardar Participante
                                    </button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </section>

        <!-- Cursos -->
        <section id="cursos" class="mb-5">
            <div class="card">
                <div class="card-header bg-success text-white">
                    <h3 class="mb-0"><i class="bi bi-book-fill"></i> Cursos</h3>
                </div>
                <div class="card-body">
                    <ul class="nav nav-tabs mb-4" id="cursosTab" role="tablist">
                        <li class="nav-item" role="presentation">
                            <button class="nav-link active" id="lista-cursos-tab" data-bs-toggle="tab" data-bs-target="#lista-cursos" type="button" role="tab">
                                Lista de Cursos
                            </button>
                        </li>
                        <li class="nav-item" role="presentation">
                            <button class="nav-link" id="nuevo-curso-tab" data-bs-toggle="tab" data-bs-target="#nuevo-curso" type="button" role="tab">
                                Nuevo Curso
                            </button>
                        </li>
                    </ul>
                    
                    <div class="tab-content" id="cursosTabContent">
                        <!-- Lista de Cursos -->
                        <div class="tab-pane fade show active" id="lista-cursos" role="tabpanel">
                            <div class="table-responsive">
                                <table class="table table-striped table-hover">
                                    <thead>
                                        <tr>
                                            <th>Nombre</th>
                                            <th>Tipo</th>
                                            <th>Modalidad</th>
                                            <th>Duración</th>
                                            <th>Fecha Inicio</th>
                                            <th>Instructor</th>
                                            <th>Estado</th>
                                            <th>Acciones</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php if($cursos_count > 0): ?>
                                            <?php foreach($cursos_list as $item): ?>
                                                <tr>
                                                    <td><?php echo $item['nombre']; ?></td>
                                                    <td><?php echo ucfirst($item['tipo']); ?></td>
                                                    <td><?php echo ucfirst($item['modalidad']); ?></td>
                                                    <td><?php echo $item['duracion_horas']; ?> horas</td>
                                                    <td><?php echo date('d/m/Y', strtotime($item['fecha_inicio'])); ?></td>
                                                    <td><?php echo $item['instructor']; ?></td>
                                                    <td>
                                                        <span class="badge bg-<?php echo $item['estado'] == 'activo' ? 'success' : 'secondary'; ?>">
                                                            <?php echo ucfirst($item['estado']); ?>
                                                        </span>
                                                    </td>
                                                    <td>
                                                        <button class="btn btn-sm btn-info" title="Ver detalles">
                                                            <i class="bi bi-eye"></i>
                                                        </button>
                                                        <button class="btn btn-sm btn-warning" title="Editar">
                                                            <i class="bi bi-pencil"></i>
                                                        </button>
                                                        <button class="btn btn-sm btn-danger" title="Eliminar">
                                                            <i class="bi bi-trash"></i>
                                                        </button>
                                                    </td>
                                                </tr>
                                            <?php endforeach; ?>
                                        <?php else: ?>
                                            <tr>
                                                <td colspan="8" class="text-center">No hay cursos registrados</td>
                                            </tr>
                                        <?php endif; ?>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                        
                        <!-- Nuevo Curso -->
                        <div class="tab-pane fade" id="nuevo-curso" role="tabpanel">
                            <?php if(isset($curso_success)): ?>
                                <div class="alert alert-success">
                                    <?php echo $curso_success; ?>
                                </div>
                            <?php endif; ?>
                            
                            <?php if(isset($curso_error)): ?>
                                <div class="alert alert-danger">
                                    <?php echo $curso_error; ?>
                                </div>
                            <?php endif; ?>
                            
                            <form method="post" action="">
                                <input type="hidden" name="action" value="crear_curso">
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="nombre" class="form-label">Nombre del Curso</label>
                                        <input type="text" class="form-control" id="nombre" name="nombre" required>
                                    </div>
                                    
                                    <div class="col-md-6 mb-3">
                                        <label for="tipo" class="form-label">Tipo</label>
                                        <select class="form-select" id="tipo" name="tipo" required>
                                            <option value="">Seleccione...</option>
                                            <option value="capacitacion">Capacitación</option>
                                            <option value="entrenamiento">Entrenamiento</option>
                                            <option value="certificacion">Certificación</option>
                                            <option value="diplomado">Diplomado</option>
                                        </select>
                                    </div>
                                </div>
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="modalidad" class="form-label">Modalidad</label>
                                        <select class="form-select" id="modalidad" name="modalidad" required>
                                            <option value="">Seleccione...</option>
                                            <option value="presencial">Presencial</option>
                                            <option value="virtual">Virtual</option>
                                            <option value="mixta">Mixta</option>
                                        </select>
                                    </div>
                                    
                                    <div class="col-md-6 mb-3">
                                        <label for="duracion_horas" class="form-label">Duración (horas)</label>
                                        <input type="number" class="form-control" id="duracion_horas" name="duracion_horas" required>
                                    </div>
                                </div>
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="fecha_inicio" class="form-label">Fecha Inicio</label>
                                        <input type="date" class="form-control" id="fecha_inicio" name="fecha_inicio" required>
                                    </div>
                                    
                                    <div class="col-md-6 mb-3">
                                        <label for="fecha_fin" class="form-label">Fecha Fin</label>
                                        <input type="date" class="form-control" id="fecha_fin" name="fecha_fin">
                                    </div>
                                </div>
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="instructor" class="form-label">Instructor</label>
                                        <input type="text" class="form-control" id="instructor" name="instructor" required>
                                    </div>
                                    
                                    <div class="col-md-6 mb-3">
                                        <label for="lugar" class="form-label">Lugar</label>
                                        <input type="text" class="form-control" id="lugar" name="lugar">
                                    </div>
                                </div>
                                
                                <div class="row">
                                    <div class="col-md-4 mb-3">
                                        <label for="cupo_maximo" class="form-label">Cupo Máximo</label>
                                        <input type="number" class="form-control" id="cupo_maximo" name="cupo_maximo" value="30">
                                    </div>
                                    
                                    <div class="col-md-4 mb-3">
                                        <label for="costo" class="form-label">Costo</label>
                                        <input type="number" class="form-control" id="costo" name="costo" value="0">
                                    </div>
                                    
                                    <div class="col-md-4 mb-3">
                                        <label for="estado" class="form-label">Estado</label>
                                        <select class="form-select" id="estado" name="estado" required>
                                            <option value="activo">Activo</option>
                                            <option value="inactivo">Inactivo</option>
                                            <option value="finalizado">Finalizado</option>
                                        </select>
                                    </div>
                                </div>
                                
                                <div class="mb-3">
                                    <label for="descripcion" class="form-label">Descripción</label>
                                    <textarea class="form-control" id="descripcion" name="descripcion" rows="3"></textarea>
                                </div>
                                
                                <div class="text-end">
                                    <button type="submit" class="btn btn-success">
                                        <i class="bi bi-save"></i> Guardar Curso
                                    </button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </section>

        <!-- Certificados -->
        <section id="certificados" class="mb-5">
            <div class="card">
                <div class="card-header bg-danger text-white">
                    <h3 class="mb-0"><i class="bi bi-award-fill"></i> Certificados</h3>
                </div>
                <div class="card-body">
                    <ul class="nav nav-tabs mb-4" id="certificadosTab" role="tablist">
                        <li class="nav-item" role="presentation">
                            <button class="nav-link active" id="lista-certificados-tab" data-bs-toggle="tab" data-bs-target="#lista-certificados" type="button" role="tab">
                                Lista de Certificados
                            </button>
                        </li>
                        <li class="nav-item" role="presentation">
                            <button class="nav-link" id="nuevo-certificado-tab" data-bs-toggle="tab" data-bs-target="#nuevo-certificado" type="button" role="tab">
                                Nuevo Certificado
                            </button>
                        </li>
                    </ul>
                    
                    <div class="tab-content" id="certificadosTabContent">
                        <!-- Lista de Certificados -->
                        <div class="tab-pane fade show active" id="lista-certificados" role="tabpanel">
                            <div class="table-responsive">
                                <table class="table table-striped table-hover">
                                    <thead>
                                        <tr>
                                            <th>Código</th>
                                            <th>Participante</th>
                                            <th>Curso</th>
                                            <th>Fecha Emisión</th>
                                            <th>Estado</th>
                                            <th>Acciones</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php if($certificados_count > 0): ?>
                                            <?php foreach($certificados_list as $item): ?>
                                                <tr>
                                                    <td><code><?php echo $item['codigo']; ?></code></td>
                                                    <td><?php echo $item['participante_nombre'] . ' ' . $item['participante_apellido']; ?></td>
                                                    <td><?php echo $item['curso_nombre']; ?></td>
                                                    <td><?php echo date('d/m/Y', strtotime($item['fecha_emision'])); ?></td>
                                                    <td>
                                                        <span class="badge bg-<?php echo $item['estado'] == 'emitido' ? 'success' : 'warning'; ?>">
                                                            <?php echo ucfirst($item['estado']); ?>
                                                        </span>
                                                    </td>
                                                    <td>
                                                        <a href="?verificar&codigo=<?php echo $item['codigo']; ?>#verificar" class="btn btn-sm btn-info" title="Verificar">
                                                            <i class="bi bi-check-circle"></i>
                                                        </a>
                                                        <button class="btn btn-sm btn-primary" title="Descargar PDF">
                                                            <i class="bi bi-file-pdf"></i>
                                                        </button>
                                                        <button class="btn btn-sm btn-danger" title="Revocar">
                                                            <i class="bi bi-x-circle"></i>
                                                        </button>
                                                    </td>
                                                </tr>
                                            <?php endforeach; ?>
                                        <?php else: ?>
                                            <tr>
                                                <td colspan="6" class="text-center">No hay certificados registrados</td>
                                            </tr>
                                        <?php endif; ?>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                        
                        <!-- Nuevo Certificado -->
                        <div class="tab-pane fade" id="nuevo-certificado" role="tabpanel">
                            <?php if(isset($certificado_success)): ?>
                                <div class="alert alert-success">
                                    <?php echo $certificado_success; ?>
                                </div>
                            <?php endif; ?>
                            
                            <?php if(isset($certificado_error)): ?>
                                <div class="alert alert-danger">
                                    <?php echo $certificado_error; ?>
                                </div>
                            <?php endif; ?>
                            
                            <form method="post" action="">
                                <input type="hidden" name="action" value="crear_certificado">
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="participante_id" class="form-label">Participante</label>
                                        <select class="form-select" id="participante_id" name="participante_id" required>
                                            <option value="">Seleccione un participante...</option>
                                            <?php foreach($participantes_list as $participante): ?>
                                                <option value="<?php echo $participante['id']; ?>">
                                                    <?php echo $participante['nombre'] . ' ' . $participante['apellido'] . ' (' . $participante['cedula'] . ')'; ?>
                                                </option>
                                            <?php endforeach; ?>
                                        </select>
                                    </div>
                                    
                                    <div class="col-md-6 mb-3">
                                        <label for="curso_id" class="form-label">Curso</label>
                                        <select class="form-select" id="curso_id" name="curso_id" required>
                                            <option value="">Seleccione un curso...</option>
                                            <?php foreach($cursos_list as $curso): ?>
                                                <option value="<?php echo $curso['id']; ?>">
                                                    <?php echo $curso['nombre'] . ' (' . $curso['duracion_horas'] . ' horas)'; ?>
                                                </option>
                                            <?php endforeach; ?>
                                        </select>
                                    </div>
                                </div>
                                
                                <div class="alert alert-info">
                                    <i class="bi bi-info-circle"></i> El código del certificado se generará automáticamente.
                                </div>
                                
                                <div class="text-end">
                                    <button type="submit" class="btn btn-danger">
                                        <i class="bi bi-award"></i> Generar Certificado
                                    </button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </section>

        <!-- Verificar Certificado -->
        <section id="verificar" class="mb-5">
            <div class="card">
                <div class="card-header bg-info text-white">
                    <h3 class="mb-0"><i class="bi bi-check-circle"></i> Verificar Certificado</h3>
                </div>
                <div class="card-body">
                    <div class="row">
                        <div class="col-md-6 mx-auto">
                            <form method="get" action="#verificar">
                                <input type="hidden" name="verificar" value="1">
                                
                                <div class="mb-3">
                                    <label for="codigo" class="form-label">Código de Certificado</label>
                                    <input type="text" class="form-control" id="codigo" name="codigo" placeholder="Ej: CERT-2025-0001" required>
                                </div>
                                
                                <div class="text-center">
                                    <button type="submit" class="btn btn-info">
                                        <i class="bi bi-search"></i> Verificar Certificado
                                    </button>
                                </div>
                            </form>
                            
                            <?php if(isset($_GET['verificar']) && isset($_GET['codigo'])): ?>
                                <?php if($certificado_verificado): ?>
                                    <div class="verification-result verification-success mt-4">
                                        <h4 class="text-success"><i class="bi bi-check-circle-fill"></i> Certificado Válido</h4>
                                        <hr>
                                        <div class="row">
                                            <div class="col-md-6">
                                                <p><strong>Código:</strong> <code><?php echo $certificado_verificado['codigo']; ?></code></p>
                                                <p><strong>Participante:</strong> <?php echo $certificado_verificado['participante_nombre'] . ' ' . $certificado_verificado['participante_apellido']; ?></p>
                                                <p><strong>Documento:</strong> <?php echo $certificado_verificado['participante_cedula']; ?></p>
                                            </div>
                                            <div class="col-md-6">
                                                <p><strong>Curso:</strong> <?php echo $certificado_verificado['curso_nombre']; ?></p>
                                                <p><strong>Duración:</strong> <?php echo $certificado_verificado['duracion_horas']; ?> horas</p>
                                                <p><strong>Fecha Emisión:</strong> <?php echo date('d/m/Y', strtotime($certificado_verificado['fecha_emision'])); ?></p>
                                            </div>
                                        </div>
                                    </div>
                                <?php else: ?>
                                    <div class="verification-result verification-error mt-4">
                                        <h4 class="text-danger"><i class="bi bi-x-circle-fill"></i> Certificado No Válido</h4>
                                        <p>El código <code><?php echo htmlspecialchars($_GET['codigo']); ?></code> no corresponde a ningún certificado registrado en el sistema.</p>
                                    </div>
                                <?php endif; ?>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </section>
    </div>

    <!-- Footer -->
    <footer class="footer py-4">
        <div class="container">
            <div class="row">
                <div class="col-md-6">
                    <h5>Escuela Internacional de Bomberos del Oriente Colombiano</h5>
                    <p>Sistema de Gestión de Certificados</p>
                </div>
                <div class="col-md-6 text-md-end">
                    <p>Versión <?php echo APP_VERSION; ?></p>
                    <p>&copy; <?php echo date('Y'); ?> ESIBOC. Todos los derechos reservados.</p>
                </div>
            </div>
        </div>
    </footer>

    <!-- Login Modal -->
    <div class="modal fade" id="loginModal" tabindex="-1" aria-labelledby="loginModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header bg-danger text-white">
                    <h5 class="modal-title" id="loginModalLabel">Iniciar Sesión</h5>
                    <button type="button" class="btn-close btn-close-white" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <?php if(isset($login_error)): ?>
                        <div class="alert alert-danger">
                            <?php echo $login_error; ?>
                        </div>
                    <?php endif; ?>
                    
                    <form method="post" action="">
                        <input type="hidden" name="action" value="login">
                        
                        <div class="mb-3">
                            <label for="email" class="form-label">Correo Electrónico</label>
                            <input type="email" class="form-control" id="email" name="email" required>
                        </div>
                        
                        <div class="mb-3">
                            <label for="password" class="form-label">Contraseña</label>
                            <input type="password" class="form-control" id="password" name="password" required>
                        </div>
                        
                        <div class="alert alert-info">
                            <strong>Credenciales de prueba:</strong><br>
                            Email: admin@esiboc.edu.co<br>
                            Contraseña: password123
                        </div>
                        
                        <div class="text-end">
                            <button type="submit" class="btn btn-danger">Iniciar Sesión</button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>

    <!-- Scripts -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
