<?php
class Curso {
    private $conn;
    private $table_name = "cursos";

    public $id;
    public $nombre;
    public $codigo;
    public $descripcion;
    public $coordinador_id;
    public $numero_registro;
    public $fecha_inicio;
    public $fecha_fin;
    public $duracion_horas;
    public $modalidad;
    public $contenido_tematico;
    public $objetivos;
    public $metodologia;
    public $evaluacion;
    public $requisitos;
    public $cupos;
    public $estado;
    public $escuela_id;
    public $fecha_creacion;

    public function __construct($db) {
        $this->conn = $db;
    }

    public function read() {
        $query = "SELECT c.*, 
                         u.nombre as coordinador_nombre,
                         e.nombre as escuela_nombre,
                         COUNT(m.id) as matriculados
                  FROM " . $this->table_name . " c
                  LEFT JOIN usuarios u ON c.coordinador_id = u.id
                  LEFT JOIN escuelas e ON c.escuela_id = e.id
                  LEFT JOIN matriculas m ON c.id = m.curso_id AND m.estado = 'activo'
                  GROUP BY c.id
                  ORDER BY c.fecha_creacion DESC";

        $stmt = $this->conn->prepare($query);
        $stmt->execute();

        return $stmt;
    }

    public function readOne() {
        $query = "SELECT c.*, 
                         u.nombre as coordinador_nombre,
                         e.nombre as escuela_nombre
                  FROM " . $this->table_name . " c
                  LEFT JOIN usuarios u ON c.coordinador_id = u.id
                  LEFT JOIN escuelas e ON c.escuela_id = e.id
                  WHERE c.id = ?";

        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(1, $this->id);
        $stmt->execute();

        $row = $stmt->fetch(PDO::FETCH_ASSOC);

        if ($row) {
            $this->nombre = $row['nombre'];
            $this->codigo = $row['codigo'];
            $this->descripcion = $row['descripcion'];
            $this->coordinador_id = $row['coordinador_id'];
            $this->numero_registro = $row['numero_registro'];
            $this->fecha_inicio = $row['fecha_inicio'];
            $this->fecha_fin = $row['fecha_fin'];
            $this->duracion_horas = $row['duracion_horas'];
            $this->modalidad = $row['modalidad'];
            $this->contenido_tematico = $row['contenido_tematico'];
            $this->objetivos = $row['objetivos'];
            $this->metodologia = $row['metodologia'];
            $this->evaluacion = $row['evaluacion'];
            $this->requisitos = $row['requisitos'];
            $this->cupos = $row['cupos'];
            $this->estado = $row['estado'];
            $this->escuela_id = $row['escuela_id'];
            $this->fecha_creacion = $row['fecha_creacion'];
            return true;
        }

        return false;
    }

    public function create() {
        $query = "INSERT INTO " . $this->table_name . " 
                  (nombre, codigo, descripcion, coordinador_id, numero_registro, 
                   fecha_inicio, fecha_fin, duracion_horas, modalidad, contenido_tematico, 
                   objetivos, metodologia, evaluacion, requisitos, cupos, escuela_id) 
                  VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";

        $stmt = $this->conn->prepare($query);

        $stmt->bindParam(1, $this->nombre);
        $stmt->bindParam(2, $this->codigo);
        $stmt->bindParam(3, $this->descripcion);
        $stmt->bindParam(4, $this->coordinador_id);
        $stmt->bindParam(5, $this->numero_registro);
        $stmt->bindParam(6, $this->fecha_inicio);
        $stmt->bindParam(7, $this->fecha_fin);
        $stmt->bindParam(8, $this->duracion_horas);
        $stmt->bindParam(9, $this->modalidad);
        $stmt->bindParam(10, $this->contenido_tematico);
        $stmt->bindParam(11, $this->objetivos);
        $stmt->bindParam(12, $this->metodologia);
        $stmt->bindParam(13, $this->evaluacion);
        $stmt->bindParam(14, $this->requisitos);
        $stmt->bindParam(15, $this->cupos);
        $stmt->bindParam(16, $this->escuela_id);

        if ($stmt->execute()) {
            $this->id = $this->conn->lastInsertId();
            return true;
        }

        return false;
    }

    public function update() {
        $query = "UPDATE " . $this->table_name . " 
                  SET nombre = ?, codigo = ?, descripcion = ?, coordinador_id = ?, 
                      numero_registro = ?, fecha_inicio = ?, fecha_fin = ?, 
                      duracion_horas = ?, modalidad = ?, contenido_tematico = ?, 
                      objetivos = ?, metodologia = ?, evaluacion = ?, requisitos = ?, 
                      cupos = ?, estado = ?
                  WHERE id = ?";

        $stmt = $this->conn->prepare($query);

        $stmt->bindParam(1, $this->nombre);
        $stmt->bindParam(2, $this->codigo);
        $stmt->bindParam(3, $this->descripcion);
        $stmt->bindParam(4, $this->coordinador_id);
        $stmt->bindParam(5, $this->numero_registro);
        $stmt->bindParam(6, $this->fecha_inicio);
        $stmt->bindParam(7, $this->fecha_fin);
        $stmt->bindParam(8, $this->duracion_horas);
        $stmt->bindParam(9, $this->modalidad);
        $stmt->bindParam(10, $this->contenido_tematico);
        $stmt->bindParam(11, $this->objetivos);
        $stmt->bindParam(12, $this->metodologia);
        $stmt->bindParam(13, $this->evaluacion);
        $stmt->bindParam(14, $this->requisitos);
        $stmt->bindParam(15, $this->cupos);
        $stmt->bindParam(16, $this->estado);
        $stmt->bindParam(17, $this->id);

        return $stmt->execute();
    }

    public function delete() {
        $query = "UPDATE " . $this->table_name . " 
                  SET estado = 'cancelado' 
                  WHERE id = ?";

        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(1, $this->id);

        return $stmt->execute();
    }

    public function search($keywords) {
        $query = "SELECT c.*, 
                         u.nombre as coordinador_nombre,
                         e.nombre as escuela_nombre,
                         COUNT(m.id) as matriculados
                  FROM " . $this->table_name . " c
                  LEFT JOIN usuarios u ON c.coordinador_id = u.id
                  LEFT JOIN escuelas e ON c.escuela_id = e.id
                  LEFT JOIN matriculas m ON c.id = m.curso_id AND m.estado = 'activo'
                  WHERE (c.nombre LIKE ? OR c.codigo LIKE ?) 
                  AND c.estado != 'cancelado'
                  GROUP BY c.id
                  ORDER BY c.fecha_creacion DESC";

        $stmt = $this->conn->prepare($query);
        $keywords = "%{$keywords}%";
        
        $stmt->bindParam(1, $keywords);
        $stmt->bindParam(2, $keywords);
        
        $stmt->execute();

        return $stmt;
    }
}
?>
