<?php
class Participante {
    private $conn;
    private $table_name = "participantes";

    public $id;
    public $nombres;
    public $apellidos;
    public $cedula;
    public $correo;
    public $celular;
    public $genero;
    public $institucion;
    public $fotografia;
    public $estado;
    public $fecha_creacion;

    public function __construct($db) {
        $this->conn = $db;
    }

    public function read() {
        $query = "SELECT * FROM " . $this->table_name . " 
                  WHERE estado = 'activo' 
                  ORDER BY fecha_creacion DESC";

        $stmt = $this->conn->prepare($query);
        $stmt->execute();

        return $stmt;
    }

    public function readOne() {
        $query = "SELECT * FROM " . $this->table_name . " WHERE id = ?";

        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(1, $this->id);
        $stmt->execute();

        $row = $stmt->fetch(PDO::FETCH_ASSOC);

        if ($row) {
            $this->nombres = $row['nombres'];
            $this->apellidos = $row['apellidos'];
            $this->cedula = $row['cedula'];
            $this->correo = $row['correo'];
            $this->celular = $row['celular'];
            $this->genero = $row['genero'];
            $this->institucion = $row['institucion'];
            $this->fotografia = $row['fotografia'];
            $this->estado = $row['estado'];
            $this->fecha_creacion = $row['fecha_creacion'];
            return true;
        }

        return false;
    }

    public function create() {
        $query = "INSERT INTO " . $this->table_name . " 
                  (nombres, apellidos, cedula, correo, celular, genero, institucion, fotografia) 
                  VALUES (?, ?, ?, ?, ?, ?, ?, ?)";

        $stmt = $this->conn->prepare($query);

        $stmt->bindParam(1, $this->nombres);
        $stmt->bindParam(2, $this->apellidos);
        $stmt->bindParam(3, $this->cedula);
        $stmt->bindParam(4, $this->correo);
        $stmt->bindParam(5, $this->celular);
        $stmt->bindParam(6, $this->genero);
        $stmt->bindParam(7, $this->institucion);
        $stmt->bindParam(8, $this->fotografia);

        if ($stmt->execute()) {
            $this->id = $this->conn->lastInsertId();
            return true;
        }

        return false;
    }

    public function update() {
        $query = "UPDATE " . $this->table_name . " 
                  SET nombres = ?, apellidos = ?, cedula = ?, correo = ?, 
                      celular = ?, genero = ?, institucion = ? 
                  WHERE id = ?";

        $stmt = $this->conn->prepare($query);

        $stmt->bindParam(1, $this->nombres);
        $stmt->bindParam(2, $this->apellidos);
        $stmt->bindParam(3, $this->cedula);
        $stmt->bindParam(4, $this->correo);
        $stmt->bindParam(5, $this->celular);
        $stmt->bindParam(6, $this->genero);
        $stmt->bindParam(7, $this->institucion);
        $stmt->bindParam(8, $this->id);

        return $stmt->execute();
    }

    public function delete() {
        $query = "UPDATE " . $this->table_name . " 
                  SET estado = 'inactivo' 
                  WHERE id = ?";

        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(1, $this->id);

        return $stmt->execute();
    }

    public function search($keywords) {
        $query = "SELECT * FROM " . $this->table_name . " 
                  WHERE (nombres LIKE ? OR apellidos LIKE ? OR cedula LIKE ? OR correo LIKE ?) 
                  AND estado = 'activo' 
                  ORDER BY fecha_creacion DESC";

        $stmt = $this->conn->prepare($query);
        $keywords = "%{$keywords}%";
        
        $stmt->bindParam(1, $keywords);
        $stmt->bindParam(2, $keywords);
        $stmt->bindParam(3, $keywords);
        $stmt->bindParam(4, $keywords);
        
        $stmt->execute();

        return $stmt;
    }

    public function bulkCreate($participantes) {
        $this->conn->beginTransaction();
        
        try {
            $query = "INSERT INTO " . $this->table_name . " 
                      (nombres, apellidos, cedula, correo, celular, genero, institucion) 
                      VALUES (?, ?, ?, ?, ?, ?, ?)";
            
            $stmt = $this->conn->prepare($query);
            
            foreach ($participantes as $participante) {
                $stmt->execute([
                    $participante['nombres'],
                    $participante['apellidos'],
                    $participante['cedula'],
                    $participante['correo'],
                    $participante['celular'],
                    $participante['genero'],
                    $participante['institucion']
                ]);
            }
            
            $this->conn->commit();
            return true;
        } catch (Exception $e) {
            $this->conn->rollback();
            return false;
        }
    }
}
?>
