<?php
class Usuario {
    private $conn;
    private $table_name = "usuarios";

    public $id;
    public $nombre;
    public $email;
    public $password;
    public $rol;
    public $activo;

    public function __construct($db) {
        $this->conn = $db;
    }

    public function login($email, $password) {
        $query = "SELECT id, nombre, email, password, rol, activo FROM " . $this->table_name . " WHERE email = ? AND activo = 1";
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(1, $email);
        $stmt->execute();

        if ($stmt->rowCount() > 0) {
            $row = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if (password_verify($password, $row['password'])) {
                // Generar token JWT simple
                $token = base64_encode(json_encode([
                    'id' => $row['id'],
                    'email' => $row['email'],
                    'rol' => $row['rol'],
                    'exp' => time() + (24 * 60 * 60) // 24 horas
                ]));

                return array(
                    "success" => true,
                    "message" => "Login exitoso",
                    "token" => $token,
                    "user" => array(
                        "id" => $row['id'],
                        "nombre" => $row['nombre'],
                        "email" => $row['email'],
                        "rol" => $row['rol']
                    )
                );
            }
        }

        return array(
            "success" => false,
            "message" => "Credenciales inválidas"
        );
    }

    public function verificarToken($token) {
        try {
            $decoded = json_decode(base64_decode($token), true);
            return isset($decoded['exp']) && $decoded['exp'] > time();
        } catch (Exception $e) {
            return false;
        }
    }
}
?>
