<?php
// SISTEMA COMPLETO DE CERTIFICADOS - TODO EN UNO
header('Content-Type: text/html; charset=UTF-8');

// Configuración de base de datos
$host = 'localhost';
$dbname = 'wwesib_bomberos_certificados';
$username = 'wwesib_bomberos_certificados';
$password = 'Serrano10$';

try {
    $pdo = new PDO("mysql:host=$host;dbname=$dbname;charset=utf8mb4", $username, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch(PDOException $e) {
    die("Error de conexión: " . $e->getMessage());
}

// Procesar acciones
$accion = $_GET['accion'] ?? 'inicio';
$mensaje = '';

if ($_POST) {
    switch ($_POST['tipo']) {
        case 'participante':
            $stmt = $pdo->prepare("INSERT INTO participantes (cedula, nombre, apellido, email, telefono, genero) VALUES (?, ?, ?, ?, ?, ?)");
            if ($stmt->execute([$_POST['cedula'], $_POST['nombre'], $_POST['apellido'], $_POST['email'], $_POST['telefono'], $_POST['genero']])) {
                $mensaje = "✅ Participante creado exitosamente";
            }
            break;
            
        case 'curso':
            $stmt = $pdo->prepare("INSERT INTO cursos (nombre, descripcion, duracion_horas, fecha_inicio, fecha_fin, instructor) VALUES (?, ?, ?, ?, ?, ?)");
            if ($stmt->execute([$_POST['nombre'], $_POST['descripcion'], $_POST['duracion'], $_POST['fecha_inicio'], $_POST['fecha_fin'], $_POST['instructor']])) {
                $mensaje = "✅ Curso creado exitosamente";
            }
            break;
            
        case 'matricula':
            $stmt = $pdo->prepare("INSERT INTO matriculas (participante_id, curso_id, fecha_matricula, estado) VALUES (?, ?, NOW(), 'activa')");
            if ($stmt->execute([$_POST['participante_id'], $_POST['curso_id']])) {
                $mensaje = "✅ Matrícula creada exitosamente";
            }
            break;
            
        case 'certificado':
            $codigo = 'CERT-' . date('Y') . '-' . str_pad(rand(1, 9999), 4, '0', STR_PAD_LEFT);
            $stmt = $pdo->prepare("INSERT INTO certificados (participante_id, curso_id, codigo, fecha_emision, estado) VALUES (?, ?, ?, NOW(), 'emitido')");
            if ($stmt->execute([$_POST['participante_id'], $_POST['curso_id'], $codigo])) {
                $mensaje = "✅ Certificado generado: $codigo";
            }
            break;
    }
}

// Obtener datos
$participantes = $pdo->query("SELECT * FROM participantes ORDER BY nombre")->fetchAll();
$cursos = $pdo->query("SELECT * FROM cursos ORDER BY fecha_inicio DESC")->fetchAll();
$matriculas = $pdo->query("
    SELECT m.*, p.nombre as participante_nombre, p.apellido, c.nombre as curso_nombre 
    FROM matriculas m 
    JOIN participantes p ON m.participante_id = p.id 
    JOIN cursos c ON m.curso_id = c.id 
    ORDER BY m.fecha_matricula DESC
")->fetchAll();
$certificados = $pdo->query("
    SELECT cert.*, p.nombre as participante_nombre, p.apellido, c.nombre as curso_nombre 
    FROM certificados cert 
    JOIN participantes p ON cert.participante_id = p.id 
    JOIN cursos c ON cert.curso_id = c.id 
    ORDER BY cert.fecha_emision DESC
")->fetchAll();
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Sistema de Certificados ESIBOC</title>
    <style>
        * { margin: 0; padding: 0; box-sizing: border-box; }
        body { font-family: Arial, sans-serif; background: #f5f5f5; }
        .container { max-width: 1200px; margin: 0 auto; padding: 20px; }
        .header { background: #2c3e50; color: white; padding: 20px; text-align: center; margin-bottom: 30px; }
        .nav { display: flex; gap: 10px; margin-bottom: 30px; }
        .nav button { padding: 10px 20px; background: #3498db; color: white; border: none; cursor: pointer; }
        .nav button.active { background: #2980b9; }
        .section { background: white; padding: 20px; margin-bottom: 20px; border-radius: 5px; box-shadow: 0 2px 5px rgba(0,0,0,0.1); }
        .form-group { margin-bottom: 15px; }
        .form-group label { display: block; margin-bottom: 5px; font-weight: bold; }
        .form-group input, .form-group select, .form-group textarea { width: 100%; padding: 8px; border: 1px solid #ddd; border-radius: 3px; }
        .btn { padding: 10px 20px; background: #27ae60; color: white; border: none; cursor: pointer; border-radius: 3px; }
        .btn:hover { background: #229954; }
        table { width: 100%; border-collapse: collapse; margin-top: 20px; }
        th, td { padding: 10px; text-align: left; border-bottom: 1px solid #ddd; }
        th { background: #f8f9fa; }
        .mensaje { padding: 15px; margin-bottom: 20px; border-radius: 5px; background: #d4edda; color: #155724; border: 1px solid #c3e6cb; }
        .hidden { display: none; }
        .grid { display: grid; grid-template-columns: 1fr 1fr; gap: 20px; }
        .verificar { background: #e74c3c; color: white; padding: 20px; text-align: center; }
        .verificar input { padding: 15px; font-size: 18px; margin: 10px; }
        .verificar button { padding: 15px 30px; font-size: 18px; background: white; color: #e74c3c; border: none; cursor: pointer; }
    </style>
</head>
<body>
    <div class="container">
        <div class="header">
            <h1>🔥 Sistema de Certificados ESIBOC</h1>
            <p>Escuela Internacional de Bomberos del Oriente Colombiano</p>
        </div>

        <?php if ($mensaje): ?>
            <div class="mensaje"><?= $mensaje ?></div>
        <?php endif; ?>

        <div class="nav">
            <button onclick="mostrarSeccion('participantes')" class="active">👥 Participantes</button>
            <button onclick="mostrarSeccion('cursos')">📚 Cursos</button>
            <button onclick="mostrarSeccion('matriculas')">📝 Matrículas</button>
            <button onclick="mostrarSeccion('certificados')">🏆 Certificados</button>
            <button onclick="mostrarSeccion('verificar')">🔍 Verificar</button>
        </div>

        <!-- PARTICIPANTES -->
        <div id="participantes" class="section">
            <h2>👥 Gestión de Participantes</h2>
            <div class="grid">
                <div>
                    <h3>Nuevo Participante</h3>
                    <form method="POST">
                        <input type="hidden" name="tipo" value="participante">
                        <div class="form-group">
                            <label>Cédula:</label>
                            <input type="text" name="cedula" required>
                        </div>
                        <div class="form-group">
                            <label>Nombre:</label>
                            <input type="text" name="nombre" required>
                        </div>
                        <div class="form-group">
                            <label>Apellido:</label>
                            <input type="text" name="apellido" required>
                        </div>
                        <div class="form-group">
                            <label>Email:</label>
                            <input type="email" name="email">
                        </div>
                        <div class="form-group">
                            <label>Teléfono:</label>
                            <input type="text" name="telefono">
                        </div>
                        <div class="form-group">
                            <label>Género:</label>
                            <select name="genero">
                                <option value="M">Masculino</option>
                                <option value="F">Femenino</option>
                            </select>
                        </div>
                        <button type="submit" class="btn">Crear Participante</button>
                    </form>
                </div>
                <div>
                    <h3>Lista de Participantes (<?= count($participantes) ?>)</h3>
                    <table>
                        <tr><th>Cédula</th><th>Nombre</th><th>Email</th></tr>
                        <?php foreach ($participantes as $p): ?>
                            <tr>
                                <td><?= $p['cedula'] ?></td>
                                <td><?= $p['nombre'] . ' ' . $p['apellido'] ?></td>
                                <td><?= $p['email'] ?></td>
                            </tr>
                        <?php endforeach; ?>
                    </table>
                </div>
            </div>
        </div>

        <!-- CURSOS -->
        <div id="cursos" class="section hidden">
            <h2>📚 Gestión de Cursos</h2>
            <div class="grid">
                <div>
                    <h3>Nuevo Curso</h3>
                    <form method="POST">
                        <input type="hidden" name="tipo" value="curso">
                        <div class="form-group">
                            <label>Nombre del Curso:</label>
                            <input type="text" name="nombre" required>
                        </div>
                        <div class="form-group">
                            <label>Descripción:</label>
                            <textarea name="descripcion" rows="3"></textarea>
                        </div>
                        <div class="form-group">
                            <label>Duración (horas):</label>
                            <input type="number" name="duracion" required>
                        </div>
                        <div class="form-group">
                            <label>Fecha Inicio:</label>
                            <input type="date" name="fecha_inicio" required>
                        </div>
                        <div class="form-group">
                            <label>Fecha Fin:</label>
                            <input type="date" name="fecha_fin">
                        </div>
                        <div class="form-group">
                            <label>Instructor:</label>
                            <input type="text" name="instructor">
                        </div>
                        <button type="submit" class="btn">Crear Curso</button>
                    </form>
                </div>
                <div>
                    <h3>Lista de Cursos (<?= count($cursos) ?>)</h3>
                    <table>
                        <tr><th>Nombre</th><th>Duración</th><th>Fecha Inicio</th></tr>
                        <?php foreach ($cursos as $c): ?>
                            <tr>
                                <td><?= $c['nombre'] ?></td>
                                <td><?= $c['duracion_horas'] ?>h</td>
                                <td><?= $c['fecha_inicio'] ?></td>
                            </tr>
                        <?php endforeach; ?>
                    </table>
                </div>
            </div>
        </div>

        <!-- MATRICULAS -->
        <div id="matriculas" class="section hidden">
            <h2>📝 Gestión de Matrículas</h2>
            <div class="grid">
                <div>
                    <h3>Nueva Matrícula</h3>
                    <form method="POST">
                        <input type="hidden" name="tipo" value="matricula">
                        <div class="form-group">
                            <label>Participante:</label>
                            <select name="participante_id" required>
                                <option value="">Seleccionar...</option>
                                <?php foreach ($participantes as $p): ?>
                                    <option value="<?= $p['id'] ?>"><?= $p['nombre'] . ' ' . $p['apellido'] ?> (<?= $p['cedula'] ?>)</option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="form-group">
                            <label>Curso:</label>
                            <select name="curso_id" required>
                                <option value="">Seleccionar...</option>
                                <?php foreach ($cursos as $c): ?>
                                    <option value="<?= $c['id'] ?>"><?= $c['nombre'] ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <button type="submit" class="btn">Crear Matrícula</button>
                    </form>
                </div>
                <div>
                    <h3>Lista de Matrículas (<?= count($matriculas) ?>)</h3>
                    <table>
                        <tr><th>Participante</th><th>Curso</th><th>Fecha</th></tr>
                        <?php foreach ($matriculas as $m): ?>
                            <tr>
                                <td><?= $m['participante_nombre'] . ' ' . $m['apellido'] ?></td>
                                <td><?= $m['curso_nombre'] ?></td>
                                <td><?= $m['fecha_matricula'] ?></td>
                            </tr>
                        <?php endforeach; ?>
                    </table>
                </div>
            </div>
        </div>

        <!-- CERTIFICADOS -->
        <div id="certificados" class="section hidden">
            <h2>🏆 Gestión de Certificados</h2>
            <div class="grid">
                <div>
                    <h3>Generar Certificado</h3>
                    <form method="POST">
                        <input type="hidden" name="tipo" value="certificado">
                        <div class="form-group">
                            <label>Participante:</label>
                            <select name="participante_id" required>
                                <option value="">Seleccionar...</option>
                                <?php foreach ($participantes as $p): ?>
                                    <option value="<?= $p['id'] ?>"><?= $p['nombre'] . ' ' . $p['apellido'] ?> (<?= $p['cedula'] ?>)</option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="form-group">
                            <label>Curso:</label>
                            <select name="curso_id" required>
                                <option value="">Seleccionar...</option>
                                <?php foreach ($cursos as $c): ?>
                                    <option value="<?= $c['id'] ?>"><?= $c['nombre'] ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <button type="submit" class="btn">Generar Certificado</button>
                    </form>
                </div>
                <div>
                    <h3>Lista de Certificados (<?= count($certificados) ?>)</h3>
                    <table>
                        <tr><th>Código</th><th>Participante</th><th>Curso</th><th>Fecha</th></tr>
                        <?php foreach ($certificados as $cert): ?>
                            <tr>
                                <td><strong><?= $cert['codigo'] ?></strong></td>
                                <td><?= $cert['participante_nombre'] . ' ' . $cert['apellido'] ?></td>
                                <td><?= $cert['curso_nombre'] ?></td>
                                <td><?= $cert['fecha_emision'] ?></td>
                            </tr>
                        <?php endforeach; ?>
                    </table>
                </div>
            </div>
        </div>

        <!-- VERIFICAR -->
        <div id="verificar" class="section hidden verificar">
            <h2>🔍 Verificar Certificado</h2>
            <form method="GET" action="verificar-certificado.php">
                <input type="text" name="codigo" placeholder="Ingrese el código del certificado" style="width: 300px;">
                <button type="submit">Verificar</button>
            </form>
            <p style="margin-top: 20px;">Ingrese el código del certificado para verificar su autenticidad</p>
        </div>
    </div>

    <script>
        function mostrarSeccion(seccion) {
            // Ocultar todas las secciones
            document.querySelectorAll('.section').forEach(s => s.classList.add('hidden'));
            // Mostrar la sección seleccionada
            document.getElementById(seccion).classList.remove('hidden');
            // Actualizar botones
            document.querySelectorAll('.nav button').forEach(b => b.classList.remove('active'));
            event.target.classList.add('active');
        }
    </script>
</body>
</html>
