<?php
// Configuración principal del sistema
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Configuración de base de datos - CAMBIAR ESTOS DATOS POR LOS DE SU HOSTING
define('DB_HOST', 'localhost');
define('DB_NAME', 'bomberos_certificados');
define('DB_USER', 'root');
define('DB_PASS', '');

// Configuración de la aplicación
define('APP_NAME', 'Sistema de Certificados ESIBOC');
define('APP_URL', 'http://localhost'); // Cambiar por su dominio
define('APP_VERSION', '1.0.0');

// Configuración de seguridad
define('JWT_SECRET', 'esiboc_secret_key_2025_' . md5(APP_URL));
define('SESSION_LIFETIME', 86400); // 24 horas

// Configuración de archivos
define('UPLOAD_DIR', __DIR__ . '/../uploads/');
define('CERT_TEMPLATE_DIR', __DIR__ . '/../templates/');
define('LOG_DIR', __DIR__ . '/../logs/');

// Crear directorios si no existen
if (!file_exists(UPLOAD_DIR)) {
    mkdir(UPLOAD_DIR, 0777, true);
}
if (!file_exists(CERT_TEMPLATE_DIR)) {
    mkdir(CERT_TEMPLATE_DIR, 0777, true);
}
if (!file_exists(LOG_DIR)) {
    mkdir(LOG_DIR, 0777, true);
}

// Zona horaria
date_default_timezone_set('America/Bogota');

// Configuración de sesión
ini_set('session.cookie_lifetime', SESSION_LIFETIME);
ini_set('session.gc_maxlifetime', SESSION_LIFETIME);

// Headers de seguridad
header('X-Content-Type-Options: nosniff');
header('X-Frame-Options: DENY');
header('X-XSS-Protection: 1; mode=block');

// Función para logging
function logAction($message, $level = 'INFO') {
    $logFile = LOG_DIR . 'system_' . date('Y-m-d') . '.log';
    $timestamp = date('Y-m-d H:i:s');
    $logMessage = "[$timestamp] [$level] $message" . PHP_EOL;
    file_put_contents($logFile, $logMessage, FILE_APPEND | LOCK_EX);
}

// Función para sanitizar datos
function sanitizeInput($data) {
    if (is_array($data)) {
        return array_map('sanitizeInput', $data);
    }
    return htmlspecialchars(strip_tags(trim($data)), ENT_QUOTES, 'UTF-8');
}

// Función para validar email
function validateEmail($email) {
    return filter_var($email, FILTER_VALIDATE_EMAIL);
}

// Función para generar token CSRF
function generateCSRFToken() {
    if (!isset($_SESSION['csrf_token'])) {
        $_SESSION['csrf_token'] = bin2hex(random_bytes(32));
    }
    return $_SESSION['csrf_token'];
}

// Función para validar token CSRF
function validateCSRFToken($token) {
    return isset($_SESSION['csrf_token']) && hash_equals($_SESSION['csrf_token'], $token);
}
?>
