<?php
// Archivo de instalación del sistema
error_reporting(E_ALL);
ini_set('display_errors', 1);

$step = $_GET['step'] ?? 1;
$message = '';
$messageType = '';

// Configuración de base de datos
$dbConfig = [
    'host' => $_POST['db_host'] ?? 'localhost',
    'name' => $_POST['db_name'] ?? 'bomberos_certificados',
    'user' => $_POST['db_user'] ?? 'root',
    'pass' => $_POST['db_pass'] ?? ''
];

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    switch ($_POST['action']) {
        case 'test_db':
            try {
                $dsn = "mysql:host={$dbConfig['host']};charset=utf8mb4";
                $pdo = new PDO($dsn, $dbConfig['user'], $dbConfig['pass']);
                $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
                
                $message = 'Conexión exitosa a la base de datos';
                $messageType = 'success';
                $step = 2;
            } catch (PDOException $e) {
                $message = 'Error de conexión: ' . $e->getMessage();
                $messageType = 'danger';
            }
            break;
            
        case 'create_db':
            try {
                $dsn = "mysql:host={$dbConfig['host']};charset=utf8mb4";
                $pdo = new PDO($dsn, $dbConfig['user'], $dbConfig['pass']);
                $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
                
                // Crear base de datos
                $pdo->exec("CREATE DATABASE IF NOT EXISTS `{$dbConfig['name']}` CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci");
                $pdo->exec("USE `{$dbConfig['name']}`");
                
                // Leer y ejecutar el archivo SQL
                $sqlFile = 'database/schema.sql';
                if (file_exists($sqlFile)) {
                    $sql = file_get_contents($sqlFile);
                    $statements = explode(';', $sql);
                    
                    foreach ($statements as $statement) {
                        $statement = trim($statement);
                        if (!empty($statement)) {
                            $pdo->exec($statement);
                        }
                    }
                }
                
                // Crear archivo de configuración
                $configContent = "<?php
// Configuración generada automáticamente
define('DB_HOST', '{$dbConfig['host']}');
define('DB_NAME', '{$dbConfig['name']}');
define('DB_USER', '{$dbConfig['user']}');
define('DB_PASS', '{$dbConfig['pass']}');

define('APP_NAME', 'Sistema de Certificados ESIBOC');
define('APP_URL', 'http://' . \$_SERVER['HTTP_HOST']);
define('APP_VERSION', '1.0.0');

define('JWT_SECRET', 'esiboc_secret_key_2025_' . md5(APP_URL));
define('SESSION_LIFETIME', 86400);

define('UPLOAD_DIR', __DIR__ . '/../uploads/');
define('CERT_TEMPLATE_DIR', __DIR__ . '/../templates/');
define('LOG_DIR', __DIR__ . '/../logs/');

if (!file_exists(UPLOAD_DIR)) mkdir(UPLOAD_DIR, 0777, true);
if (!file_exists(CERT_TEMPLATE_DIR)) mkdir(CERT_TEMPLATE_DIR, 0777, true);
if (!file_exists(LOG_DIR)) mkdir(LOG_DIR, 0777, true);

date_default_timezone_set('America/Bogota');

function logAction(\$message, \$level = 'INFO') {
    \$logFile = LOG_DIR . 'system_' . date('Y-m-d') . '.log';
    \$timestamp = date('Y-m-d H:i:s');
    \$logMessage = \"[\$timestamp] [\$level] \$message\" . PHP_EOL;
    file_put_contents(\$logFile, \$logMessage, FILE_APPEND | LOCK_EX);
}

function sanitizeInput(\$data) {
    if (is_array(\$data)) {
        return array_map('sanitizeInput', \$data);
    }
    return htmlspecialchars(strip_tags(trim(\$data)), ENT_QUOTES, 'UTF-8');
}
?>";
                
                file_put_contents('config/config.php', $configContent);
                
                $message = 'Base de datos y configuración creadas exitosamente';
                $messageType = 'success';
                $step = 3;
                
            } catch (PDOException $e) {
                $message = 'Error al crear la base de datos: ' . $e->getMessage();
                $messageType = 'danger';
            }
            break;
    }
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Instalación - Sistema de Certificados ESIBOC</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.0/font/bootstrap-icons.css">
</head>
<body class="bg-light">
    <div class="container py-5">
        <div class="row justify-content-center">
            <div class="col-md-8">
                <div class="card shadow">
                    <div class="card-header bg-danger text-white text-center">
                        <h3><i class="bi bi-fire"></i> Instalación del Sistema</h3>
                        <p class="mb-0">Sistema de Certificados ESIBOC</p>
                    </div>
                    <div class="card-body">
                        
                        <!-- Progress Bar -->
                        <div class="progress mb-4">
                            <div class="progress-bar bg-danger" style="width: <?php echo ($step / 3) * 100; ?>%"></div>
                        </div>
                        
                        <?php if ($message): ?>
                        <div class="alert alert-<?php echo $messageType; ?> alert-dismissible fade show">
                            <?php echo htmlspecialchars($message); ?>
                            <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                        </div>
                        <?php endif; ?>
                        
                        <?php if ($step == 1): ?>
                        <!-- Paso 1: Configuración de Base de Datos -->
                        <h4><i class="bi bi-database"></i> Paso 1: Configuración de Base de Datos</h4>
                        <p>Ingrese los datos de conexión a su base de datos MySQL:</p>
                        
                        <form method="post">
                            <input type="hidden" name="action" value="test_db">
                            
                            <div class="mb-3">
                                <label for="db_host" class="form-label">Servidor de Base de Datos</label>
                                <input type="text" class="form-control" id="db_host" name="db_host" 
                                       value="<?php echo htmlspecialchars($dbConfig['host']); ?>" required>
                            </div>
                            
                            <div class="mb-3">
                                <label for="db_name" class="form-label">Nombre de la Base de Datos</label>
                                <input type="text" class="form-control" id="db_name" name="db_name" 
                                       value="<?php echo htmlspecialchars($dbConfig['name']); ?>" required>
                            </div>
                            
                            <div class="mb-3">
                                <label for="db_user" class="form-label">Usuario de Base de Datos</label>
                                <input type="text" class="form-control" id="db_user" name="db_user" 
                                       value="<?php echo htmlspecialchars($dbConfig['user']); ?>" required>
                            </div>
                            
                            <div class="mb-3">
                                <label for="db_pass" class="form-label">Contraseña de Base de Datos</label>
                                <input type="password" class="form-control" id="db_pass" name="db_pass" 
                                       value="<?php echo htmlspecialchars($dbConfig['pass']); ?>">
                            </div>
                            
                            <div class="text-end">
                                <button type="submit" class="btn btn-danger">
                                    <i class="bi bi-check-circle"></i> Probar Conexión
                                </button>
                            </div>
                        </form>
                        
                        <?php elseif ($step == 2): ?>
                        <!-- Paso 2: Crear Base de Datos -->
                        <h4><i class="bi bi-database-check"></i> Paso 2: Crear Base de Datos</h4>
                        <p>La conexión fue exitosa. Ahora crearemos la base de datos y las tablas necesarias:</p>
                        
                        <div class="alert alert-info">
                            <i class="bi bi-info-circle"></i> 
                            Se creará la base de datos <strong><?php echo htmlspecialchars($dbConfig['name']); ?></strong> 
                            con todas las tablas y datos iniciales necesarios.
                        </div>
                        
                        <form method="post">
                            <input type="hidden" name="action" value="create_db">
                            <input type="hidden" name="db_host" value="<?php echo htmlspecialchars($dbConfig['host']); ?>">
                            <input type="hidden" name="db_name" value="<?php echo htmlspecialchars($dbConfig['name']); ?>">
                            <input type="hidden" name="db_user" value="<?php echo htmlspecialchars($dbConfig['user']); ?>">
                            <input type="hidden" name="db_pass" value="<?php echo htmlspecialchars($dbConfig['pass']); ?>">
                            
                            <div class="text-end">
                                <button type="submit" class="btn btn-danger">
                                    <i class="bi bi-database-add"></i> Crear Base de Datos
                                </button>
                            </div>
                        </form>
                        
                        <?php elseif ($step == 3): ?>
                        <!-- Paso 3: Instalación Completada -->
                        <h4><i class="bi bi-check-circle-fill text-success"></i> Instalación Completada</h4>
                        
                        <div class="alert alert-success">
                            <h5><i class="bi bi-check-circle"></i> ¡Instalación Exitosa!</h5>
                            <p>El sistema ha sido instalado correctamente. Ya puede comenzar a usarlo.</p>
                        </div>
                        
                        <div class="card">
                            <div class="card-header">
                                <h5><i class="bi bi-person-check"></i> Credenciales de Acceso</h5>
                            </div>
                            <div class="card-body">
                                <p>Se han creado los siguientes usuarios de prueba:</p>
                                <ul>
                                    <li><strong>Administrador:</strong> admin@esiboc.edu.co / password123</li>
                                    <li><strong>Coordinador:</strong> coordinador@esiboc.edu.co / password123</li>
                                    <li><strong>Instructor:</strong> instructor@esiboc.edu.co / password123</li>
                                    <li><strong>Secretaria:</strong> secretaria@esiboc.edu.co / password123</li>
                                </ul>
                            </div>
                        </div>
                        
                        <div class="alert alert-warning mt-3">
                            <i class="bi bi-exclamation-triangle"></i> 
                            <strong>Importante:</strong> Por seguridad, elimine el archivo <code>install.php</code> 
                            después de completar la instalación.
                        </div>
                        
                        <div class="text-center mt-4">
                            <a href="index.php" class="btn btn-success btn-lg">
                                <i class="bi bi-arrow-right-circle"></i> Ir al Sistema
                            </a>
                        </div>
                        
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
    
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
