#!/bin/bash

echo "=== PREPARANDO ARCHIVOS PARA PRODUCCIÓN ==="

# Crear carpeta de producción
mkdir -p production-files

# Copiar backend
echo "Copiando archivos del backend..."
cp -r backend/* production-files/

# Crear archivo de configuración de producción
cat > production-files/config/database.php << 'EOF'
<?php
class Database {
    private $host = "localhost"; // Tu servidor MySQL
    private $db_name = "tu_base_datos"; // Nombre que te dé tu hosting
    private $username = "tu_usuario"; // Usuario MySQL del hosting
    private $password = "tu_password"; // Password MySQL del hosting
    public $conn;

    public function getConnection() {
        $this->conn = null;
        try {
            $this->conn = new PDO("mysql:host=" . $this->host . ";dbname=" . $this->db_name, $this->username, $this->password);
            $this->conn->exec("set names utf8");
            $this->conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
        } catch(PDOException $exception) {
            echo "Connection error: " . $exception->getMessage();
        }
        return $this->conn;
    }
}
?>
EOF

# Crear .htaccess para el backend
cat > production-files/.htaccess << 'EOF'
RewriteEngine On

# CORS Headers
Header always set Access-Control-Allow-Origin "*"
Header always set Access-Control-Allow-Methods "GET, POST, PUT, DELETE, OPTIONS"
Header always set Access-Control-Allow-Headers "Content-Type, Authorization, X-Requested-With"

# Handle preflight requests
RewriteCond %{REQUEST_METHOD} OPTIONS
RewriteRule ^(.*)$ $1 [R=200,L]

# API Routes
RewriteCond %{REQUEST_FILENAME} !-f
RewriteCond %{REQUEST_FILENAME} !-d
RewriteRule ^api/(.*)$ api/$1.php [L,QSA]
EOF

echo "✅ Archivos preparados en la carpeta 'production-files'"
echo "📁 Sube todo el contenido de 'production-files' a tu hosting"
