-- ===================================
-- SCRIPT PARA ESIBOC - BASE DE DATOS: wwesib_bomberos_certificados
-- ===================================

-- INSTRUCCIONES:
-- 1. En phpMyAdmin, SELECCIONA la base de datos "wwesib_bomberos_certificados" del panel izquierdo
-- 2. Ve a la pestaña "SQL"
-- 3. Copia y pega este script completo

-- Crear tabla de usuarios
CREATE TABLE IF NOT EXISTS usuarios (
    id INT AUTO_INCREMENT PRIMARY KEY,
    nombre VARCHAR(100) NOT NULL,
    email VARCHAR(100) UNIQUE NOT NULL,
    password VARCHAR(255) NOT NULL,
    rol ENUM('admin', 'coordinador', 'director', 'instructor') NOT NULL,
    activo BOOLEAN DEFAULT TRUE,
    fecha_creacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    fecha_actualizacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- Crear tabla de participantes
CREATE TABLE IF NOT EXISTS participantes (
    id INT AUTO_INCREMENT PRIMARY KEY,
    cedula VARCHAR(20) UNIQUE NOT NULL,
    nombre VARCHAR(100) NOT NULL,
    apellido VARCHAR(100) NOT NULL,
    email VARCHAR(100),
    telefono VARCHAR(20),
    direccion TEXT,
    fecha_nacimiento DATE,
    genero ENUM('M', 'F', 'Otro'),
    activo BOOLEAN DEFAULT TRUE,
    fecha_registro TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    fecha_actualizacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- Crear tabla de cursos
CREATE TABLE IF NOT EXISTS cursos (
    id INT AUTO_INCREMENT PRIMARY KEY,
    codigo VARCHAR(20) UNIQUE NOT NULL,
    nombre VARCHAR(200) NOT NULL,
    descripcion TEXT,
    duracion_horas INT NOT NULL,
    fecha_inicio DATE NOT NULL,
    fecha_fin DATE NOT NULL,
    instructor_id INT,
    coordinador_id INT,
    estado ENUM('planificado', 'en_curso', 'finalizado', 'cancelado') DEFAULT 'planificado',
    cupo_maximo INT DEFAULT 30,
    fecha_creacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    fecha_actualizacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (instructor_id) REFERENCES usuarios(id),
    FOREIGN KEY (coordinador_id) REFERENCES usuarios(id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- Crear tabla de matrículas
CREATE TABLE IF NOT EXISTS matriculas (
    id INT AUTO_INCREMENT PRIMARY KEY,
    participante_id INT NOT NULL,
    curso_id INT NOT NULL,
    fecha_matricula TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    estado ENUM('matriculado', 'aprobado', 'reprobado', 'retirado') DEFAULT 'matriculado',
    nota_final DECIMAL(4,2),
    asistencia_porcentaje DECIMAL(5,2),
    observaciones TEXT,
    UNIQUE KEY unique_matricula (participante_id, curso_id),
    FOREIGN KEY (participante_id) REFERENCES participantes(id),
    FOREIGN KEY (curso_id) REFERENCES cursos(id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- Crear tabla de certificados
CREATE TABLE IF NOT EXISTS certificados (
    id INT AUTO_INCREMENT PRIMARY KEY,
    codigo_certificado VARCHAR(50) UNIQUE NOT NULL,
    matricula_id INT NOT NULL,
    fecha_emision DATE NOT NULL,
    fecha_vencimiento DATE,
    estado ENUM('borrador', 'pendiente_firma', 'firmado', 'emitido', 'anulado') DEFAULT 'borrador',
    hash_verificacion VARCHAR(255),
    ruta_archivo VARCHAR(500),
    observaciones TEXT,
    fecha_creacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    fecha_actualizacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (matricula_id) REFERENCES matriculas(id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- Crear tabla de firmas
CREATE TABLE IF NOT EXISTS firmas (
    id INT AUTO_INCREMENT PRIMARY KEY,
    certificado_id INT NOT NULL,
    usuario_id INT NOT NULL,
    tipo_firma ENUM('coordinador', 'director') NOT NULL,
    fecha_firma TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    hash_firma VARCHAR(255),
    observaciones TEXT,
    FOREIGN KEY (certificado_id) REFERENCES certificados(id),
    FOREIGN KEY (usuario_id) REFERENCES usuarios(id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- Crear tabla de calificaciones
CREATE TABLE IF NOT EXISTS calificaciones (
    id INT AUTO_INCREMENT PRIMARY KEY,
    matricula_id INT NOT NULL,
    tipo_evaluacion ENUM('parcial', 'final', 'practica', 'proyecto') NOT NULL,
    nota DECIMAL(4,2) NOT NULL,
    fecha_evaluacion DATE NOT NULL,
    observaciones TEXT,
    evaluador_id INT,
    fecha_registro TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (matricula_id) REFERENCES matriculas(id),
    FOREIGN KEY (evaluador_id) REFERENCES usuarios(id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- Crear tabla de logs de auditoría
CREATE TABLE IF NOT EXISTS logs_auditoria (
    id INT AUTO_INCREMENT PRIMARY KEY,
    usuario_id INT,
    accion VARCHAR(100) NOT NULL,
    tabla_afectada VARCHAR(50),
    registro_id INT,
    datos_anteriores JSON,
    datos_nuevos JSON,
    ip_address VARCHAR(45),
    user_agent TEXT,
    fecha_accion TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (usuario_id) REFERENCES usuarios(id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- Insertar usuarios por defecto
INSERT INTO usuarios (nombre, email, password, rol) VALUES
('Administrador ESIBOC', 'admin@esiboc.edu.co', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', 'admin'),
('Carlos Martínez', 'carlos.martinez@esiboc.edu.co', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', 'coordinador'),
('Laura Gómez', 'laura.gomez@esiboc.edu.co', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', 'director'),
('Miguel Rodríguez', 'miguel.rodriguez@esiboc.edu.co', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', 'instructor');

-- Insertar participantes de ejemplo
INSERT INTO participantes (cedula, nombre, apellido, email, telefono, genero) VALUES
('12345678', 'Juan Carlos', 'Pérez López', 'juan.perez@email.com', '3001234567', 'M'),
('87654321', 'María Elena', 'García Ruiz', 'maria.garcia@email.com', '3007654321', 'F'),
('11223344', 'Pedro Antonio', 'Martínez Silva', 'pedro.martinez@email.com', '3001122334', 'M'),
('44332211', 'Ana Sofía', 'López Herrera', 'ana.lopez@email.com', '3004433221', 'F');

-- Insertar curso de ejemplo
INSERT INTO cursos (codigo, nombre, descripcion, duracion_horas, fecha_inicio, fecha_fin, instructor_id, coordinador_id) VALUES
('BOMB-2024-001', 'Curso Básico de Bomberos', 'Curso introductorio para nuevos bomberos', 120, '2024-01-15', '2024-03-15', 4, 2);

-- Insertar matrículas de ejemplo
INSERT INTO matriculas (participante_id, curso_id, estado, nota_final, asistencia_porcentaje) VALUES
(1, 1, 'aprobado', 85.50, 95.00),
(2, 1, 'aprobado', 92.00, 98.50),
(3, 1, 'matriculado', NULL, NULL),
(4, 1, 'matriculado', NULL, NULL);

-- Mensaje de confirmación
SELECT 'Base de datos configurada correctamente para ESIBOC' as mensaje;
